Method: OryClient::NormalizedProjectRevisionThirdPartyProvider#pkce

Defined in:
lib/ory-client/models/normalized_project_revision_third_party_provider.rb

#pkceObject

PKCE controls if the OpenID Connect OAuth2 flow should use PKCE (Proof Key for Code Exchange). Possible values are: auto (default), never, force. auto: PKCE is used if the provider supports it. Requires setting issuer_url. never: Disable PKCE entirely for this provider, even if the provider advertises support for it. force: Always use PKCE, even if the provider does not advertise support for it. OAuth2 flows will fail if the provider does not support PKCE. IMPORTANT: If you set this to force, you must whitelist a different return URL for your OAuth2 client in the provider’s configuration. Instead of <base-url>/self-service/methods/oidc/callback/<provider>, you must use <base-url>/self-service/methods/oidc/callback (Note the missing <provider> path segment and no trailing slash).



62
63
64
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 62

def pkce
  @pkce
end