Class: OryClient::AccountExperienceConfiguration

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/account_experience_configuration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountExperienceConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/ory-client/models/account_experience_configuration.rb', line 175

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::AccountExperienceConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::AccountExperienceConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'contact_url')
    self.contact_url = attributes[:'contact_url']
  end

  if attributes.key?(:'default_locale')
    self.default_locale = attributes[:'default_locale']
  else
    self.default_locale = nil
  end

  if attributes.key?(:'default_redirect_url')
    self.default_redirect_url = attributes[:'default_redirect_url']
  else
    self.default_redirect_url = nil
  end

  if attributes.key?(:'enabled_locales')
    if (value = attributes[:'enabled_locales']).is_a?(Array)
      self.enabled_locales = value
    end
  else
    self.enabled_locales = nil
  end

  if attributes.key?(:'error_ui_url')
    self.error_ui_url = attributes[:'error_ui_url']
  else
    self.error_ui_url = nil
  end

  if attributes.key?(:'favicon_dark_url')
    self.favicon_dark_url = attributes[:'favicon_dark_url']
  end

  if attributes.key?(:'favicon_light_url')
    self.favicon_light_url = attributes[:'favicon_light_url']
  end

  if attributes.key?(:'hide_ory_branding')
    self.hide_ory_branding = attributes[:'hide_ory_branding']
  else
    self.hide_ory_branding = nil
  end

  if attributes.key?(:'hide_registration_link')
    self.hide_registration_link = attributes[:'hide_registration_link']
  else
    self.hide_registration_link = nil
  end

  if attributes.key?(:'locale_behavior')
    self.locale_behavior = attributes[:'locale_behavior']
  else
    self.locale_behavior = nil
  end

  if attributes.key?(:'login_ui_url')
    self. = attributes[:'login_ui_url']
  else
    self. = nil
  end

  if attributes.key?(:'logo_dark_url')
    self.logo_dark_url = attributes[:'logo_dark_url']
  end

  if attributes.key?(:'logo_light_url')
    self.logo_light_url = attributes[:'logo_light_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'privacy_policy_url')
    self.privacy_policy_url = attributes[:'privacy_policy_url']
  end

  if attributes.key?(:'recovery_enabled')
    self.recovery_enabled = attributes[:'recovery_enabled']
  else
    self.recovery_enabled = nil
  end

  if attributes.key?(:'recovery_ui_url')
    self.recovery_ui_url = attributes[:'recovery_ui_url']
  else
    self.recovery_ui_url = nil
  end

  if attributes.key?(:'registration_enabled')
    self.registration_enabled = attributes[:'registration_enabled']
  else
    self.registration_enabled = nil
  end

  if attributes.key?(:'registration_ui_url')
    self.registration_ui_url = attributes[:'registration_ui_url']
  else
    self.registration_ui_url = nil
  end

  if attributes.key?(:'settings_ui_url')
    self.settings_ui_url = attributes[:'settings_ui_url']
  else
    self.settings_ui_url = nil
  end

  if attributes.key?(:'stylesheet')
    self.stylesheet = attributes[:'stylesheet']
  end

  if attributes.key?(:'terms_of_service_url')
    self.terms_of_service_url = attributes[:'terms_of_service_url']
  end

  if attributes.key?(:'translations')
    if (value = attributes[:'translations']).is_a?(Array)
      self.translations = value
    end
  else
    self.translations = nil
  end

  if attributes.key?(:'verification_enabled')
    self.verification_enabled = attributes[:'verification_enabled']
  else
    self.verification_enabled = nil
  end

  if attributes.key?(:'verification_ui_url')
    self.verification_ui_url = attributes[:'verification_ui_url']
  else
    self.verification_ui_url = nil
  end
end

Instance Attribute Details

#contact_url ⇒ Object

The URL to the project's Contact page.



19
20
21
# File 'lib/ory-client/models/account_experience_configuration.rb', line 19

def contact_url
  @contact_url
end

#default_locale ⇒ Object

Returns the value of attribute default_locale.



21
22
23
# File 'lib/ory-client/models/account_experience_configuration.rb', line 21

def default_locale
  @default_locale
end

#default_redirect_url ⇒ Object

Returns the value of attribute default_redirect_url.



23
24
25
# File 'lib/ory-client/models/account_experience_configuration.rb', line 23

def default_redirect_url
  @default_redirect_url
end

#enabled_locales ⇒ Object

Returns the value of attribute enabled_locales.



25
26
27
# File 'lib/ory-client/models/account_experience_configuration.rb', line 25

def enabled_locales
  @enabled_locales
end

#error_ui_url ⇒ Object

Returns the value of attribute error_ui_url.



27
28
29
# File 'lib/ory-client/models/account_experience_configuration.rb', line 27

def error_ui_url
  @error_ui_url
end

#favicon_dark_url ⇒ Object

Returns the value of attribute favicon_dark_url.



29
30
31
# File 'lib/ory-client/models/account_experience_configuration.rb', line 29

def favicon_dark_url
  @favicon_dark_url
end

#favicon_light_url ⇒ Object

Returns the value of attribute favicon_light_url.



31
32
33
# File 'lib/ory-client/models/account_experience_configuration.rb', line 31

def favicon_light_url
  @favicon_light_url
end

#hide_ory_branding ⇒ Object

Whether to hide the Ory branding badge on the account experience.



34
35
36
# File 'lib/ory-client/models/account_experience_configuration.rb', line 34

def hide_ory_branding
  @hide_ory_branding
end

Returns the value of attribute hide_registration_link.



36
37
38
# File 'lib/ory-client/models/account_experience_configuration.rb', line 36

def hide_registration_link
  @hide_registration_link
end

#locale_behavior ⇒ Object

force_default AccountExperienceLocaleBehaviorForceDefault respect_accept_language AccountExperienceLocaleBehaviorRespectAcceptLanguage



39
40
41
# File 'lib/ory-client/models/account_experience_configuration.rb', line 39

def locale_behavior
  @locale_behavior
end

#login_ui_url ⇒ Object

Returns the value of attribute login_ui_url.



41
42
43
# File 'lib/ory-client/models/account_experience_configuration.rb', line 41

def 
  @login_ui_url
end

#logo_dark_url ⇒ Object

Returns the value of attribute logo_dark_url.



43
44
45
# File 'lib/ory-client/models/account_experience_configuration.rb', line 43

def logo_dark_url
  @logo_dark_url
end

#logo_light_url ⇒ Object

Returns the value of attribute logo_light_url.



45
46
47
# File 'lib/ory-client/models/account_experience_configuration.rb', line 45

def logo_light_url
  @logo_light_url
end

#name ⇒ Object

Returns the value of attribute name.



47
48
49
# File 'lib/ory-client/models/account_experience_configuration.rb', line 47

def name
  @name
end

#privacy_policy_url ⇒ Object

The URL to the project's Privacy Policy page.



50
51
52
# File 'lib/ory-client/models/account_experience_configuration.rb', line 50

def privacy_policy_url
  @privacy_policy_url
end

#recovery_enabled ⇒ Object

Returns the value of attribute recovery_enabled.



52
53
54
# File 'lib/ory-client/models/account_experience_configuration.rb', line 52

def recovery_enabled
  @recovery_enabled
end

#recovery_ui_url ⇒ Object

Returns the value of attribute recovery_ui_url.



54
55
56
# File 'lib/ory-client/models/account_experience_configuration.rb', line 54

def recovery_ui_url
  @recovery_ui_url
end

#registration_enabled ⇒ Object

Returns the value of attribute registration_enabled.



56
57
58
# File 'lib/ory-client/models/account_experience_configuration.rb', line 56

def registration_enabled
  @registration_enabled
end

#registration_ui_url ⇒ Object

Returns the value of attribute registration_ui_url.



58
59
60
# File 'lib/ory-client/models/account_experience_configuration.rb', line 58

def registration_ui_url
  @registration_ui_url
end

#settings_ui_url ⇒ Object

Returns the value of attribute settings_ui_url.



60
61
62
# File 'lib/ory-client/models/account_experience_configuration.rb', line 60

def settings_ui_url
  @settings_ui_url
end

#stylesheet ⇒ Object

Returns the value of attribute stylesheet.



62
63
64
# File 'lib/ory-client/models/account_experience_configuration.rb', line 62

def stylesheet
  @stylesheet
end

#terms_of_service_url ⇒ Object

The URL to the project's Terms of Service page.



65
66
67
# File 'lib/ory-client/models/account_experience_configuration.rb', line 65

def terms_of_service_url
  @terms_of_service_url
end

#translations ⇒ Object

Returns the value of attribute translations.



67
68
69
# File 'lib/ory-client/models/account_experience_configuration.rb', line 67

def translations
  @translations
end

#verification_enabled ⇒ Object

Returns the value of attribute verification_enabled.



69
70
71
# File 'lib/ory-client/models/account_experience_configuration.rb', line 69

def verification_enabled
  @verification_enabled
end

#verification_ui_url ⇒ Object

Returns the value of attribute verification_ui_url.



71
72
73
# File 'lib/ory-client/models/account_experience_configuration.rb', line 71

def verification_ui_url
  @verification_ui_url
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



127
128
129
# File 'lib/ory-client/models/account_experience_configuration.rb', line 127

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



132
133
134
# File 'lib/ory-client/models/account_experience_configuration.rb', line 132

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ory-client/models/account_experience_configuration.rb', line 96

def self.attribute_map
  {
    :'contact_url' => :'contact_url',
    :'default_locale' => :'default_locale',
    :'default_redirect_url' => :'default_redirect_url',
    :'enabled_locales' => :'enabled_locales',
    :'error_ui_url' => :'error_ui_url',
    :'favicon_dark_url' => :'favicon_dark_url',
    :'favicon_light_url' => :'favicon_light_url',
    :'hide_ory_branding' => :'hide_ory_branding',
    :'hide_registration_link' => :'hide_registration_link',
    :'locale_behavior' => :'locale_behavior',
    :'login_ui_url' => :'login_ui_url',
    :'logo_dark_url' => :'logo_dark_url',
    :'logo_light_url' => :'logo_light_url',
    :'name' => :'name',
    :'privacy_policy_url' => :'privacy_policy_url',
    :'recovery_enabled' => :'recovery_enabled',
    :'recovery_ui_url' => :'recovery_ui_url',
    :'registration_enabled' => :'registration_enabled',
    :'registration_ui_url' => :'registration_ui_url',
    :'settings_ui_url' => :'settings_ui_url',
    :'stylesheet' => :'stylesheet',
    :'terms_of_service_url' => :'terms_of_service_url',
    :'translations' => :'translations',
    :'verification_enabled' => :'verification_enabled',
    :'verification_ui_url' => :'verification_ui_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/ory-client/models/account_experience_configuration.rb', line 647

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



168
169
170
171
# File 'lib/ory-client/models/account_experience_configuration.rb', line 168

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/ory-client/models/account_experience_configuration.rb', line 137

def self.openapi_types
  {
    :'contact_url' => :'String',
    :'default_locale' => :'String',
    :'default_redirect_url' => :'String',
    :'enabled_locales' => :'Array<String>',
    :'error_ui_url' => :'String',
    :'favicon_dark_url' => :'String',
    :'favicon_light_url' => :'String',
    :'hide_ory_branding' => :'Boolean',
    :'hide_registration_link' => :'Boolean',
    :'locale_behavior' => :'String',
    :'login_ui_url' => :'String',
    :'logo_dark_url' => :'String',
    :'logo_light_url' => :'String',
    :'name' => :'String',
    :'privacy_policy_url' => :'String',
    :'recovery_enabled' => :'Boolean',
    :'recovery_ui_url' => :'String',
    :'registration_enabled' => :'Boolean',
    :'registration_ui_url' => :'String',
    :'settings_ui_url' => :'String',
    :'stylesheet' => :'String',
    :'terms_of_service_url' => :'String',
    :'translations' => :'Array<RevisionAccountExperienceCustomTranslation>',
    :'verification_enabled' => :'Boolean',
    :'verification_ui_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
# File 'lib/ory-client/models/account_experience_configuration.rb', line 602

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      contact_url == o.contact_url &&
      default_locale == o.default_locale &&
      default_redirect_url == o.default_redirect_url &&
      enabled_locales == o.enabled_locales &&
      error_ui_url == o.error_ui_url &&
      favicon_dark_url == o.favicon_dark_url &&
      favicon_light_url == o.favicon_light_url &&
      hide_ory_branding == o.hide_ory_branding &&
      hide_registration_link == o.hide_registration_link &&
      locale_behavior == o.locale_behavior &&
       == o. &&
      logo_dark_url == o.logo_dark_url &&
      logo_light_url == o.logo_light_url &&
      name == o.name &&
      privacy_policy_url == o.privacy_policy_url &&
      recovery_enabled == o.recovery_enabled &&
      recovery_ui_url == o.recovery_ui_url &&
      registration_enabled == o.registration_enabled &&
      registration_ui_url == o.registration_ui_url &&
      settings_ui_url == o.settings_ui_url &&
      stylesheet == o.stylesheet &&
      terms_of_service_url == o.terms_of_service_url &&
      translations == o.translations &&
      verification_enabled == o.verification_enabled &&
      verification_ui_url == o.verification_ui_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


634
635
636
# File 'lib/ory-client/models/account_experience_configuration.rb', line 634

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



640
641
642
# File 'lib/ory-client/models/account_experience_configuration.rb', line 640

def hash
  [contact_url, default_locale, default_redirect_url, enabled_locales, error_ui_url, favicon_dark_url, favicon_light_url, hide_ory_branding, hide_registration_link, locale_behavior, , logo_dark_url, logo_light_url, name, privacy_policy_url, recovery_enabled, recovery_ui_url, registration_enabled, registration_ui_url, settings_ui_url, stylesheet, terms_of_service_url, translations, verification_enabled, verification_ui_url].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/ory-client/models/account_experience_configuration.rb', line 330

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @default_locale.nil?
    invalid_properties.push('invalid value for "default_locale", default_locale cannot be nil.')
  end

  if @default_redirect_url.nil?
    invalid_properties.push('invalid value for "default_redirect_url", default_redirect_url cannot be nil.')
  end

  if @enabled_locales.nil?
    invalid_properties.push('invalid value for "enabled_locales", enabled_locales cannot be nil.')
  end

  if @error_ui_url.nil?
    invalid_properties.push('invalid value for "error_ui_url", error_ui_url cannot be nil.')
  end

  if @hide_ory_branding.nil?
    invalid_properties.push('invalid value for "hide_ory_branding", hide_ory_branding cannot be nil.')
  end

  if @hide_registration_link.nil?
    invalid_properties.push('invalid value for "hide_registration_link", hide_registration_link cannot be nil.')
  end

  if @locale_behavior.nil?
    invalid_properties.push('invalid value for "locale_behavior", locale_behavior cannot be nil.')
  end

  if @login_ui_url.nil?
    invalid_properties.push('invalid value for "login_ui_url", login_ui_url cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @recovery_enabled.nil?
    invalid_properties.push('invalid value for "recovery_enabled", recovery_enabled cannot be nil.')
  end

  if @recovery_ui_url.nil?
    invalid_properties.push('invalid value for "recovery_ui_url", recovery_ui_url cannot be nil.')
  end

  if @registration_enabled.nil?
    invalid_properties.push('invalid value for "registration_enabled", registration_enabled cannot be nil.')
  end

  if @registration_ui_url.nil?
    invalid_properties.push('invalid value for "registration_ui_url", registration_ui_url cannot be nil.')
  end

  if @settings_ui_url.nil?
    invalid_properties.push('invalid value for "settings_ui_url", settings_ui_url cannot be nil.')
  end

  if @translations.nil?
    invalid_properties.push('invalid value for "translations", translations cannot be nil.')
  end

  if @verification_enabled.nil?
    invalid_properties.push('invalid value for "verification_enabled", verification_enabled cannot be nil.')
  end

  if @verification_ui_url.nil?
    invalid_properties.push('invalid value for "verification_ui_url", verification_ui_url cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



669
670
671
672
673
674
675
676
677
678
679
680
681
# File 'lib/ory-client/models/account_experience_configuration.rb', line 669

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/ory-client/models/account_experience_configuration.rb', line 406

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @default_locale.nil?
  return false if @default_redirect_url.nil?
  return false if @enabled_locales.nil?
  return false if @error_ui_url.nil?
  return false if @hide_ory_branding.nil?
  return false if @hide_registration_link.nil?
  return false if @locale_behavior.nil?
  locale_behavior_validator = EnumAttributeValidator.new('String', ["force_default", "respect_accept_language"])
  return false unless locale_behavior_validator.valid?(@locale_behavior)
  return false if @login_ui_url.nil?
  return false if @name.nil?
  return false if @recovery_enabled.nil?
  return false if @recovery_ui_url.nil?
  return false if @registration_enabled.nil?
  return false if @registration_ui_url.nil?
  return false if @settings_ui_url.nil?
  return false if @translations.nil?
  return false if @verification_enabled.nil?
  return false if @verification_ui_url.nil?
  true
end