Class: OryClient::AdminRotateIssuedAPIKeyBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/admin_rotate_issued_api_key_body.rb

Overview

RotateIssuedAPIKeyRequest is the request for AdminRotateIssuedAPIKey. Rotation is a custom method (AIP-136) that swaps an active key for a new one with a fresh secret and key_id, then revokes the old key. It is not a partial update, so it does not carry an update_mask. Mutable fields use presence-based semantics: an absent field inherits from the old key, while a present field (including an explicitly empty value) overrides.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdminRotateIssuedAPIKeyBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::AdminRotateIssuedAPIKeyBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::AdminRotateIssuedAPIKeyBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ip_restriction')
    self.ip_restriction = attributes[:'ip_restriction']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'rate_limit_policy')
    self.rate_limit_policy = attributes[:'rate_limit_policy']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'visibility')
    self.visibility = attributes[:'visibility']
  else
    self.visibility = 'KEY_VISIBILITY_UNSPECIFIED'
  end
end

Instance Attribute Details

#ip_restrictionObject

Returns the value of attribute ip_restriction.



19
20
21
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 19

def ip_restriction
  @ip_restriction
end

#metadataObject

metadata for the new API key. Absent (nil) inherits from the old key; present (including empty Struct) overrides.



22
23
24
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 22

def 
  @metadata
end

#nameObject

name for the new API key. Absent (HasName() == false) inherits from the old key; present (including empty string) overrides.



25
26
27
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 25

def name
  @name
end

#rate_limit_policyObject

Returns the value of attribute rate_limit_policy.



27
28
29
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 27

def rate_limit_policy
  @rate_limit_policy
end

#scopesObject

scopes for the new API key. Absent (nil slice) inherits from the old key; present (including empty list) overrides.



30
31
32
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 30

def scopes
  @scopes
end

#visibilityObject

Returns the value of attribute visibility.



32
33
34
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 32

def visibility
  @visibility
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 57

def self.attribute_map
  {
    :'ip_restriction' => :'ip_restriction',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'rate_limit_policy' => :'rate_limit_policy',
    :'scopes' => :'scopes',
    :'visibility' => :'visibility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 79

def self.openapi_types
  {
    :'ip_restriction' => :'IPRestriction',
    :'metadata' => :'Object',
    :'name' => :'String',
    :'rate_limit_policy' => :'RateLimitPolicy',
    :'scopes' => :'Array<String>',
    :'visibility' => :'KeyVisibility'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
167
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ip_restriction == o.ip_restriction &&
       == o. &&
      name == o.name &&
      rate_limit_policy == o.rate_limit_policy &&
      scopes == o.scopes &&
      visibility == o.visibility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 177

def hash
  [ip_restriction, , name, rate_limit_policy, scopes, visibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
# File 'lib/ory-client/models/admin_rotate_issued_api_key_body.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end