Class: OryClient::BasicOrganization

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/basic_organization.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BasicOrganization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/ory-client/models/basic_organization.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::BasicOrganization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::BasicOrganization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'default_region')
    self.default_region = attributes[:'default_region']
  end

  if attributes.key?(:'domains')
    if (value = attributes[:'domains']).is_a?(Array)
      self.domains = value
    end
  else
    self.domains = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'session_lifespan')
    self.session_lifespan = attributes[:'session_lifespan']
  end
end

Instance Attribute Details

#default_regionObject

DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global



19
20
21
# File 'lib/ory-client/models/basic_organization.rb', line 19

def default_region
  @default_region
end

#domainsObject

The list of organization’s domains.



22
23
24
# File 'lib/ory-client/models/basic_organization.rb', line 22

def domains
  @domains
end

#idObject

The organization’s ID.



25
26
27
# File 'lib/ory-client/models/basic_organization.rb', line 25

def id
  @id
end

#labelObject

The organization’s human-readable label.



28
29
30
# File 'lib/ory-client/models/basic_organization.rb', line 28

def label
  @label
end

#session_lifespanObject

SessionLifespan overrides the project-level session lifespan for sessions issued for this organization. A Go duration string between 1m and 8760h. A null (or zero) value means the project default applies.



31
32
33
# File 'lib/ory-client/models/basic_organization.rb', line 31

def session_lifespan
  @session_lifespan
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/ory-client/models/basic_organization.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/ory-client/models/basic_organization.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/ory-client/models/basic_organization.rb', line 56

def self.attribute_map
  {
    :'default_region' => :'default_region',
    :'domains' => :'domains',
    :'id' => :'id',
    :'label' => :'label',
    :'session_lifespan' => :'session_lifespan'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/ory-client/models/basic_organization.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/ory-client/models/basic_organization.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/ory-client/models/basic_organization.rb', line 77

def self.openapi_types
  {
    :'default_region' => :'String',
    :'domains' => :'Array<String>',
    :'id' => :'String',
    :'label' => :'String',
    :'session_lifespan' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



233
234
235
236
237
238
239
240
241
# File 'lib/ory-client/models/basic_organization.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default_region == o.default_region &&
      domains == o.domains &&
      id == o.id &&
      label == o.label &&
      session_lifespan == o.session_lifespan
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/ory-client/models/basic_organization.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/ory-client/models/basic_organization.rb', line 251

def hash
  [default_region, domains, id, label, session_lifespan].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/ory-client/models/basic_organization.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @domains.nil?
    invalid_properties.push('invalid value for "domains", domains cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  pattern = Regexp.new(/^[0-9]+(s|m|h)$/)
  if !@session_lifespan.nil? && @session_lifespan !~ pattern
    invalid_properties.push("invalid value for \"session_lifespan\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/ory-client/models/basic_organization.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
# File 'lib/ory-client/models/basic_organization.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  default_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"])
  return false unless default_region_validator.valid?(@default_region)
  return false if @domains.nil?
  return false if @id.nil?
  return false if @label.nil?
  return false if !@session_lifespan.nil? && @session_lifespan !~ Regexp.new(/^[0-9]+(s|m|h)$/)
  true
end