Class: OryClient::CloudAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::CloudAccount
- Defined in:
- lib/ory-client/models/cloud_account.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#email_verified ⇒ Object
Returns the value of attribute email_verified.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CloudAccount
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/ory-client/models/cloud_account.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CloudAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CloudAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] else self.email_verified = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
18 19 20 |
# File 'lib/ory-client/models/cloud_account.rb', line 18 def email @email end |
#email_verified ⇒ Object
Returns the value of attribute email_verified.
20 21 22 |
# File 'lib/ory-client/models/cloud_account.rb', line 20 def email_verified @email_verified end |
#id ⇒ Object
Returns the value of attribute id.
22 23 24 |
# File 'lib/ory-client/models/cloud_account.rb', line 22 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/ory-client/models/cloud_account.rb', line 24 def name @name end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
26 27 28 |
# File 'lib/ory-client/models/cloud_account.rb', line 26 def organization_id @organization_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/ory-client/models/cloud_account.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/ory-client/models/cloud_account.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/ory-client/models/cloud_account.rb', line 29 def self.attribute_map { :'email' => :'email', :'email_verified' => :'email_verified', :'id' => :'id', :'name' => :'name', :'organization_id' => :'organization_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ory-client/models/cloud_account.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 |
# File 'lib/ory-client/models/cloud_account.rb', line 61 def self.openapi_nullable Set.new([ :'organization_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/ory-client/models/cloud_account.rb', line 50 def self.openapi_types { :'email' => :'String', :'email_verified' => :'Boolean', :'id' => :'String', :'name' => :'String', :'organization_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 |
# File 'lib/ory-client/models/cloud_account.rb', line 189 def ==(o) return true if self.equal?(o) self.class == o.class && email == o.email && email_verified == o.email_verified && id == o.id && name == o.name && organization_id == o.organization_id end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/ory-client/models/cloud_account.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/ory-client/models/cloud_account.rb', line 207 def hash [email, email_verified, id, name, organization_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/ory-client/models/cloud_account.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @email_verified.nil? invalid_properties.push('invalid value for "email_verified", email_verified cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/ory-client/models/cloud_account.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 145 |
# File 'lib/ory-client/models/cloud_account.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @email.nil? return false if @email_verified.nil? return false if @id.nil? return false if @name.nil? true end |