Class: OryClient::CreateEventStreamBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::CreateEventStreamBody
- Defined in:
- lib/ory-client/models/create_event_stream_body.rb
Overview
Create Event Stream Request Body
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#https_endpoint ⇒ Object
The HTTPS endpoint URL to send events to.
-
#role_arn ⇒ Object
The AWS IAM role ARN to assume when publishing to the SNS topic.
-
#topic_arn ⇒ Object
The AWS SNS topic ARN.
-
#type ⇒ Object
The type of the event stream (AWS SNS or HTTPS webhook).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEventStreamBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateEventStreamBody
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CreateEventStreamBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CreateEventStreamBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'https_endpoint') self.https_endpoint = attributes[:'https_endpoint'] end if attributes.key?(:'role_arn') self.role_arn = attributes[:'role_arn'] end if attributes.key?(:'topic_arn') self.topic_arn = attributes[:'topic_arn'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#https_endpoint ⇒ Object
The HTTPS endpoint URL to send events to. Required if type is https.
20 21 22 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 20 def https_endpoint @https_endpoint end |
#role_arn ⇒ Object
The AWS IAM role ARN to assume when publishing to the SNS topic. Required if type is sns.
23 24 25 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 23 def role_arn @role_arn end |
#topic_arn ⇒ Object
The AWS SNS topic ARN. Required if type is sns.
26 27 28 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 26 def topic_arn @topic_arn end |
#type ⇒ Object
The type of the event stream (AWS SNS or HTTPS webhook).
29 30 31 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 29 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 54 def self.attribute_map { :'https_endpoint' => :'https_endpoint', :'role_arn' => :'role_arn', :'topic_arn' => :'topic_arn', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 74 def self.openapi_types { :'https_endpoint' => :'String', :'role_arn' => :'String', :'topic_arn' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && https_endpoint == o.https_endpoint && role_arn == o.role_arn && topic_arn == o.topic_arn && type == o.type end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 175 def hash [https_endpoint, role_arn, topic_arn, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 |
# File 'lib/ory-client/models/create_event_stream_body.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["sns", "https"]) return false unless type_validator.valid?(@type) true end |