Class: OryClient::CustomerPortalAvailability
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::CustomerPortalAvailability
- Defined in:
- lib/ory-client/models/customer_portal_availability.rb
Overview
CustomerPortalAvailability describes whether the Stripe customer portal is available for the logged-in user (or a workspace they access).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#available ⇒ Object
Whether the customer portal is available.
-
#reason ⇒ Object
Optional reason why the portal is unavailable.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerPortalAvailability
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerPortalAvailability
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CustomerPortalAvailability` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CustomerPortalAvailability`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'available') self.available = attributes[:'available'] else self.available = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end end |
Instance Attribute Details
#available ⇒ Object
Whether the customer portal is available.
20 21 22 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 20 def available @available end |
#reason ⇒ Object
Optional reason why the portal is unavailable. Populated only when ‘available` is false. For debugging and support purposes — frontend consumers should not parse or depend on specific values. no_stripe_customer CustomerPortalReasonNoStripeCustomer no_subscription CustomerPortalReasonNoSubscription
23 24 25 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 23 def reason @reason end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 48 def self.attribute_map { :'available' => :'available', :'reason' => :'reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 66 def self.openapi_types { :'available' => :'Boolean', :'reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && available == o.available && reason == o.reason end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 165 def hash [available, reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @available.nil? invalid_properties.push('invalid value for "available", available cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 125 126 |
# File 'lib/ory-client/models/customer_portal_availability.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @available.nil? reason_validator = EnumAttributeValidator.new('String', ["no_stripe_customer", "no_subscription"]) return false unless reason_validator.valid?(@reason) true end |