Class: OryClient::DeviceAuthnAndroidAuthorizationList

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/device_authn_android_authorization_list.rb

Overview

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceAuthnAndroidAuthorizationList

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeviceAuthnAndroidAuthorizationList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeviceAuthnAndroidAuthorizationList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_date_time')
    self.active_date_time = attributes[:'active_date_time']
  end

  if attributes.key?(:'algorithm')
    self.algorithm = attributes[:'algorithm']
  end

  if attributes.key?(:'application_id')
    if (value = attributes[:'application_id']).is_a?(Array)
      self.application_id = value
    end
  end

  if attributes.key?(:'attestation_application_id')
    if (value = attributes[:'attestation_application_id']).is_a?(Array)
      self.attestation_application_id = value
    end
  end

  if attributes.key?(:'attestation_id_brand')
    if (value = attributes[:'attestation_id_brand']).is_a?(Array)
      self.attestation_id_brand = value
    end
  end

  if attributes.key?(:'attestation_id_device')
    if (value = attributes[:'attestation_id_device']).is_a?(Array)
      self.attestation_id_device = value
    end
  end

  if attributes.key?(:'attestation_id_imei')
    if (value = attributes[:'attestation_id_imei']).is_a?(Array)
      self.attestation_id_imei = value
    end
  end

  if attributes.key?(:'attestation_id_manufacturer')
    if (value = attributes[:'attestation_id_manufacturer']).is_a?(Array)
      self.attestation_id_manufacturer = value
    end
  end

  if attributes.key?(:'attestation_id_meid')
    if (value = attributes[:'attestation_id_meid']).is_a?(Array)
      self.attestation_id_meid = value
    end
  end

  if attributes.key?(:'attestation_id_model')
    if (value = attributes[:'attestation_id_model']).is_a?(Array)
      self.attestation_id_model = value
    end
  end

  if attributes.key?(:'attestation_id_product')
    if (value = attributes[:'attestation_id_product']).is_a?(Array)
      self.attestation_id_product = value
    end
  end

  if attributes.key?(:'attestation_id_serial')
    if (value = attributes[:'attestation_id_serial']).is_a?(Array)
      self.attestation_id_serial = value
    end
  end

  if attributes.key?(:'auth_timeout')
    self.auth_timeout = attributes[:'auth_timeout']
  end

  if attributes.key?(:'boot_patch_level')
    self.boot_patch_level = attributes[:'boot_patch_level']
  end

  if attributes.key?(:'creation_date_time')
    self.creation_date_time = attributes[:'creation_date_time']
  end

  if attributes.key?(:'digest')
    if (value = attributes[:'digest']).is_a?(Array)
      self.digest = value
    end
  end

  if attributes.key?(:'ec_curve')
    self.ec_curve = attributes[:'ec_curve']
  end

  if attributes.key?(:'key_size')
    self.key_size = attributes[:'key_size']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'origination_expire_date_time')
    self.origination_expire_date_time = attributes[:'origination_expire_date_time']
  end

  if attributes.key?(:'os_patch_level')
    self.os_patch_level = attributes[:'os_patch_level']
  end

  if attributes.key?(:'os_version')
    self.os_version = attributes[:'os_version']
  end

  if attributes.key?(:'purpose')
    if (value = attributes[:'purpose']).is_a?(Array)
      self.purpose = value
    end
  end

  if attributes.key?(:'root_of_trust')
    self.root_of_trust = attributes[:'root_of_trust']
  end

  if attributes.key?(:'usage_expire_date_time')
    self.usage_expire_date_time = attributes[:'usage_expire_date_time']
  end

  if attributes.key?(:'user_auth_type')
    self.user_auth_type = attributes[:'user_auth_type']
  end

  if attributes.key?(:'vendor_patch_level')
    self.vendor_patch_level = attributes[:'vendor_patch_level']
  end
end

Instance Attribute Details

#active_date_timeObject

Returns the value of attribute active_date_time.



19
20
21
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 19

def active_date_time
  @active_date_time
end

#algorithmObject

Returns the value of attribute algorithm.



21
22
23
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 21

def algorithm
  @algorithm
end

#application_idObject

Returns the value of attribute application_id.



23
24
25
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 23

def application_id
  @application_id
end

#attestation_application_idObject

Returns the value of attribute attestation_application_id.



25
26
27
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 25

def attestation_application_id
  @attestation_application_id
end

#attestation_id_brandObject

Returns the value of attribute attestation_id_brand.



27
28
29
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 27

def attestation_id_brand
  @attestation_id_brand
end

#attestation_id_deviceObject

Returns the value of attribute attestation_id_device.



29
30
31
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 29

def attestation_id_device
  @attestation_id_device
end

#attestation_id_imeiObject

Returns the value of attribute attestation_id_imei.



31
32
33
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 31

def attestation_id_imei
  @attestation_id_imei
end

#attestation_id_manufacturerObject

Returns the value of attribute attestation_id_manufacturer.



33
34
35
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 33

def attestation_id_manufacturer
  @attestation_id_manufacturer
end

#attestation_id_meidObject

Returns the value of attribute attestation_id_meid.



35
36
37
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 35

def attestation_id_meid
  @attestation_id_meid
end

#attestation_id_modelObject

Returns the value of attribute attestation_id_model.



37
38
39
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 37

def attestation_id_model
  @attestation_id_model
end

#attestation_id_productObject

Returns the value of attribute attestation_id_product.



39
40
41
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 39

def attestation_id_product
  @attestation_id_product
end

#attestation_id_serialObject

Returns the value of attribute attestation_id_serial.



41
42
43
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 41

def attestation_id_serial
  @attestation_id_serial
end

#auth_timeoutObject

Returns the value of attribute auth_timeout.



43
44
45
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 43

def auth_timeout
  @auth_timeout
end

#boot_patch_levelObject

Returns the value of attribute boot_patch_level.



45
46
47
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 45

def boot_patch_level
  @boot_patch_level
end

#creation_date_timeObject

Returns the value of attribute creation_date_time.



47
48
49
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 47

def creation_date_time
  @creation_date_time
end

#digestObject

Returns the value of attribute digest.



49
50
51
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 49

def digest
  @digest
end

#ec_curveObject

Returns the value of attribute ec_curve.



51
52
53
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 51

def ec_curve
  @ec_curve
end

#key_sizeObject

Returns the value of attribute key_size.



53
54
55
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 53

def key_size
  @key_size
end

#originObject

Returns the value of attribute origin.



55
56
57
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 55

def origin
  @origin
end

#origination_expire_date_timeObject

Returns the value of attribute origination_expire_date_time.



57
58
59
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 57

def origination_expire_date_time
  @origination_expire_date_time
end

#os_patch_levelObject

Returns the value of attribute os_patch_level.



59
60
61
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 59

def os_patch_level
  @os_patch_level
end

#os_versionObject

Returns the value of attribute os_version.



61
62
63
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 61

def os_version
  @os_version
end

#purposeObject

Returns the value of attribute purpose.



63
64
65
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 63

def purpose
  @purpose
end

#root_of_trustObject

Returns the value of attribute root_of_trust.



65
66
67
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 65

def root_of_trust
  @root_of_trust
end

#usage_expire_date_timeObject

Returns the value of attribute usage_expire_date_time.



67
68
69
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 67

def usage_expire_date_time
  @usage_expire_date_time
end

#user_auth_typeObject

Returns the value of attribute user_auth_type.



69
70
71
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 69

def user_auth_type
  @user_auth_type
end

#vendor_patch_levelObject

Returns the value of attribute vendor_patch_level.



71
72
73
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 71

def vendor_patch_level
  @vendor_patch_level
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



107
108
109
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 107

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 112

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 74

def self.attribute_map
  {
    :'active_date_time' => :'active_date_time',
    :'algorithm' => :'algorithm',
    :'application_id' => :'application_id',
    :'attestation_application_id' => :'attestation_application_id',
    :'attestation_id_brand' => :'attestation_id_brand',
    :'attestation_id_device' => :'attestation_id_device',
    :'attestation_id_imei' => :'attestation_id_imei',
    :'attestation_id_manufacturer' => :'attestation_id_manufacturer',
    :'attestation_id_meid' => :'attestation_id_meid',
    :'attestation_id_model' => :'attestation_id_model',
    :'attestation_id_product' => :'attestation_id_product',
    :'attestation_id_serial' => :'attestation_id_serial',
    :'auth_timeout' => :'auth_timeout',
    :'boot_patch_level' => :'boot_patch_level',
    :'creation_date_time' => :'creation_date_time',
    :'digest' => :'digest',
    :'ec_curve' => :'ec_curve',
    :'key_size' => :'key_size',
    :'origin' => :'origin',
    :'origination_expire_date_time' => :'origination_expire_date_time',
    :'os_patch_level' => :'os_patch_level',
    :'os_version' => :'os_version',
    :'purpose' => :'purpose',
    :'root_of_trust' => :'root_of_trust',
    :'usage_expire_date_time' => :'usage_expire_date_time',
    :'user_auth_type' => :'user_auth_type',
    :'vendor_patch_level' => :'vendor_patch_level'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 368

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 150

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 117

def self.openapi_types
  {
    :'active_date_time' => :'Integer',
    :'algorithm' => :'Integer',
    :'application_id' => :'Array<Integer>',
    :'attestation_application_id' => :'Array<Integer>',
    :'attestation_id_brand' => :'Array<Integer>',
    :'attestation_id_device' => :'Array<Integer>',
    :'attestation_id_imei' => :'Array<Integer>',
    :'attestation_id_manufacturer' => :'Array<Integer>',
    :'attestation_id_meid' => :'Array<Integer>',
    :'attestation_id_model' => :'Array<Integer>',
    :'attestation_id_product' => :'Array<Integer>',
    :'attestation_id_serial' => :'Array<Integer>',
    :'auth_timeout' => :'Integer',
    :'boot_patch_level' => :'Integer',
    :'creation_date_time' => :'Integer',
    :'digest' => :'Array<Integer>',
    :'ec_curve' => :'Integer',
    :'key_size' => :'Integer',
    :'origin' => :'Integer',
    :'origination_expire_date_time' => :'Integer',
    :'os_patch_level' => :'Integer',
    :'os_version' => :'Integer',
    :'purpose' => :'Array<Integer>',
    :'root_of_trust' => :'DeviceAuthnAndroidRootOfTrust',
    :'usage_expire_date_time' => :'Integer',
    :'user_auth_type' => :'Integer',
    :'vendor_patch_level' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 321

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_date_time == o.active_date_time &&
      algorithm == o.algorithm &&
      application_id == o.application_id &&
      attestation_application_id == o.attestation_application_id &&
      attestation_id_brand == o.attestation_id_brand &&
      attestation_id_device == o.attestation_id_device &&
      attestation_id_imei == o.attestation_id_imei &&
      attestation_id_manufacturer == o.attestation_id_manufacturer &&
      attestation_id_meid == o.attestation_id_meid &&
      attestation_id_model == o.attestation_id_model &&
      attestation_id_product == o.attestation_id_product &&
      attestation_id_serial == o.attestation_id_serial &&
      auth_timeout == o.auth_timeout &&
      boot_patch_level == o.boot_patch_level &&
      creation_date_time == o.creation_date_time &&
      digest == o.digest &&
      ec_curve == o.ec_curve &&
      key_size == o.key_size &&
      origin == o.origin &&
      origination_expire_date_time == o.origination_expire_date_time &&
      os_patch_level == o.os_patch_level &&
      os_version == o.os_version &&
      purpose == o.purpose &&
      root_of_trust == o.root_of_trust &&
      usage_expire_date_time == o.usage_expire_date_time &&
      user_auth_type == o.user_auth_type &&
      vendor_patch_level == o.vendor_patch_level
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


355
356
357
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 355

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



361
362
363
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 361

def hash
  [active_date_time, algorithm, application_id, attestation_application_id, attestation_id_brand, attestation_id_device, attestation_id_imei, attestation_id_manufacturer, attestation_id_meid, attestation_id_model, attestation_id_product, attestation_id_serial, auth_timeout, boot_patch_level, creation_date_time, digest, ec_curve, key_size, origin, origination_expire_date_time, os_patch_level, os_version, purpose, root_of_trust, usage_expire_date_time, user_auth_type, vendor_patch_level].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



306
307
308
309
310
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 306

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
317
# File 'lib/ory-client/models/device_authn_android_authorization_list.rb', line 314

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end