Class: OryClient::DeviceUserAuthRequest

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/device_user_auth_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceUserAuthRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ory-client/models/device_user_auth_request.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeviceUserAuthRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeviceUserAuthRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'challenge')
    self.challenge = attributes[:'challenge']
  else
    self.challenge = nil
  end

  if attributes.key?(:'client')
    self.client = attributes[:'client']
  end

  if attributes.key?(:'handled_at')
    self.handled_at = attributes[:'handled_at']
  end

  if attributes.key?(:'request_url')
    self.request_url = attributes[:'request_url']
  end

  if attributes.key?(:'requested_access_token_audience')
    if (value = attributes[:'requested_access_token_audience']).is_a?(Array)
      self.requested_access_token_audience = value
    end
  end

  if attributes.key?(:'requested_scope')
    if (value = attributes[:'requested_scope']).is_a?(Array)
      self.requested_scope = value
    end
  end
end

Instance Attribute Details

#challengeObject

ID is the identifier (\“device challenge\”) of the device grant request. It is used to identify the session.



19
20
21
# File 'lib/ory-client/models/device_user_auth_request.rb', line 19

def challenge
  @challenge
end

#clientObject

Returns the value of attribute client.



21
22
23
# File 'lib/ory-client/models/device_user_auth_request.rb', line 21

def client
  @client
end

#handled_atObject

Returns the value of attribute handled_at.



23
24
25
# File 'lib/ory-client/models/device_user_auth_request.rb', line 23

def handled_at
  @handled_at
end

#request_urlObject

RequestURL is the original Device Authorization URL requested.



26
27
28
# File 'lib/ory-client/models/device_user_auth_request.rb', line 26

def request_url
  @request_url
end

#requested_access_token_audienceObject

Returns the value of attribute requested_access_token_audience.



28
29
30
# File 'lib/ory-client/models/device_user_auth_request.rb', line 28

def requested_access_token_audience
  @requested_access_token_audience
end

#requested_scopeObject

Returns the value of attribute requested_scope.



30
31
32
# File 'lib/ory-client/models/device_user_auth_request.rb', line 30

def requested_scope
  @requested_scope
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/ory-client/models/device_user_auth_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/ory-client/models/device_user_auth_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/ory-client/models/device_user_auth_request.rb', line 33

def self.attribute_map
  {
    :'challenge' => :'challenge',
    :'client' => :'client',
    :'handled_at' => :'handled_at',
    :'request_url' => :'request_url',
    :'requested_access_token_audience' => :'requested_access_token_audience',
    :'requested_scope' => :'requested_scope'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/ory-client/models/device_user_auth_request.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/ory-client/models/device_user_auth_request.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/ory-client/models/device_user_auth_request.rb', line 55

def self.openapi_types
  {
    :'challenge' => :'String',
    :'client' => :'OAuth2Client',
    :'handled_at' => :'Time',
    :'request_url' => :'String',
    :'requested_access_token_audience' => :'Array<String>',
    :'requested_scope' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
# File 'lib/ory-client/models/device_user_auth_request.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      challenge == o.challenge &&
      client == o.client &&
      handled_at == o.handled_at &&
      request_url == o.request_url &&
      requested_access_token_audience == o.requested_access_token_audience &&
      requested_scope == o.requested_scope
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/ory-client/models/device_user_auth_request.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/ory-client/models/device_user_auth_request.rb', line 170

def hash
  [challenge, client, handled_at, request_url, requested_access_token_audience, requested_scope].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
# File 'lib/ory-client/models/device_user_auth_request.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @challenge.nil?
    invalid_properties.push('invalid value for "challenge", challenge cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/ory-client/models/device_user_auth_request.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
# File 'lib/ory-client/models/device_user_auth_request.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @challenge.nil?
  true
end