Class: OryClient::ElementsApi
- Inherits:
-
Object
- Object
- OryClient::ElementsApi
- Defined in:
- lib/ory-client/api/elements_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_configuration(opts = {}) ⇒ ElementsConfiguration
Get Ory Elements configuration Returns a subset of the project’s configuration for the given host.
-
#get_configuration_with_http_info(opts = {}) ⇒ Array<(ElementsConfiguration, Integer, Hash)>
Get Ory Elements configuration Returns a subset of the project's configuration for the given host.
-
#initialize(api_client = ApiClient.default) ⇒ ElementsApi
constructor
A new instance of ElementsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ElementsApi
Returns a new instance of ElementsApi.
19 20 21 |
# File 'lib/ory-client/api/elements_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ory-client/api/elements_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_configuration(opts = {}) ⇒ ElementsConfiguration
Get Ory Elements configuration Returns a subset of the project’s configuration for the given host. The response only contains non-sensitive data that is used to customize the behavior of Ory Elements.
26 27 28 29 |
# File 'lib/ory-client/api/elements_api.rb', line 26 def get_configuration(opts = {}) data, _status_code, _headers = get_configuration_with_http_info(opts) data end |
#get_configuration_with_http_info(opts = {}) ⇒ Array<(ElementsConfiguration, Integer, Hash)>
Get Ory Elements configuration Returns a subset of the project's configuration for the given host. The response only contains non-sensitive data that is used to customize the behavior of Ory Elements.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/ory-client/api/elements_api.rb', line 35 def get_configuration_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ElementsApi.get_configuration ...' end # resource path local_var_path = '/elements/configuration' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ElementsConfiguration' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"ElementsApi.get_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ElementsApi#get_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |