Class: OryClient::ElementsConfiguration

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/elements_configuration.rb

Overview

ElementsConfiguration is the subset of a project's configuration that Ory Elements consumes to customize its behavior and appearance. It mirrors the ProjectConfiguration type in @ory/elements-react and intentionally omits account-experience-only fields (stylesheet, locales, translations, favicons).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ElementsConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/ory-client/models/elements_configuration.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ElementsConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ElementsConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'contact_url')
    self.contact_url = attributes[:'contact_url']
  end

  if attributes.key?(:'default_redirect_url')
    self.default_redirect_url = attributes[:'default_redirect_url']
  else
    self.default_redirect_url = nil
  end

  if attributes.key?(:'error_ui_url')
    self.error_ui_url = attributes[:'error_ui_url']
  else
    self.error_ui_url = nil
  end

  if attributes.key?(:'hide_ory_branding')
    self.hide_ory_branding = attributes[:'hide_ory_branding']
  else
    self.hide_ory_branding = nil
  end

  if attributes.key?(:'hide_registration_link')
    self.hide_registration_link = attributes[:'hide_registration_link']
  else
    self.hide_registration_link = nil
  end

  if attributes.key?(:'login_ui_url')
    self. = attributes[:'login_ui_url']
  else
    self. = nil
  end

  if attributes.key?(:'logo_dark_url')
    self.logo_dark_url = attributes[:'logo_dark_url']
  end

  if attributes.key?(:'logo_light_url')
    self.logo_light_url = attributes[:'logo_light_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'privacy_policy_url')
    self.privacy_policy_url = attributes[:'privacy_policy_url']
  end

  if attributes.key?(:'recovery_enabled')
    self.recovery_enabled = attributes[:'recovery_enabled']
  else
    self.recovery_enabled = nil
  end

  if attributes.key?(:'recovery_ui_url')
    self.recovery_ui_url = attributes[:'recovery_ui_url']
  else
    self.recovery_ui_url = nil
  end

  if attributes.key?(:'registration_enabled')
    self.registration_enabled = attributes[:'registration_enabled']
  else
    self.registration_enabled = nil
  end

  if attributes.key?(:'registration_ui_url')
    self.registration_ui_url = attributes[:'registration_ui_url']
  else
    self.registration_ui_url = nil
  end

  if attributes.key?(:'settings_ui_url')
    self.settings_ui_url = attributes[:'settings_ui_url']
  else
    self.settings_ui_url = nil
  end

  if attributes.key?(:'terms_of_service_url')
    self.terms_of_service_url = attributes[:'terms_of_service_url']
  end

  if attributes.key?(:'verification_enabled')
    self.verification_enabled = attributes[:'verification_enabled']
  else
    self.verification_enabled = nil
  end

  if attributes.key?(:'verification_ui_url')
    self.verification_ui_url = attributes[:'verification_ui_url']
  else
    self.verification_ui_url = nil
  end
end

Instance Attribute Details

#contact_urlObject

The URL to the project's Contact page.



20
21
22
# File 'lib/ory-client/models/elements_configuration.rb', line 20

def contact_url
  @contact_url
end

#default_redirect_urlObject

The default redirect URL.



23
24
25
# File 'lib/ory-client/models/elements_configuration.rb', line 23

def default_redirect_url
  @default_redirect_url
end

#error_ui_urlObject

The URL for the error UI.



26
27
28
# File 'lib/ory-client/models/elements_configuration.rb', line 26

def error_ui_url
  @error_ui_url
end

#hide_ory_brandingObject

Whether to hide the Ory branding badge.



29
30
31
# File 'lib/ory-client/models/elements_configuration.rb', line 29

def hide_ory_branding
  @hide_ory_branding
end

Whether to hide the "Sign up" link on the login card footer.



32
33
34
# File 'lib/ory-client/models/elements_configuration.rb', line 32

def hide_registration_link
  @hide_registration_link
end

#login_ui_urlObject

The URL for the login UI.



35
36
37
# File 'lib/ory-client/models/elements_configuration.rb', line 35

def 
  @login_ui_url
end

#logo_dark_urlObject

The URL for the dark logo.



38
39
40
# File 'lib/ory-client/models/elements_configuration.rb', line 38

def logo_dark_url
  @logo_dark_url
end

#logo_light_urlObject

The URL for the light logo on the auth card.



41
42
43
# File 'lib/ory-client/models/elements_configuration.rb', line 41

def logo_light_url
  @logo_light_url
end

#nameObject

The name of the project displayed on the auth card.



44
45
46
# File 'lib/ory-client/models/elements_configuration.rb', line 44

def name
  @name
end

#privacy_policy_urlObject

The URL to the project's Privacy Policy page.



47
48
49
# File 'lib/ory-client/models/elements_configuration.rb', line 47

def privacy_policy_url
  @privacy_policy_url
end

#recovery_enabledObject

Whether recovery is enabled.



50
51
52
# File 'lib/ory-client/models/elements_configuration.rb', line 50

def recovery_enabled
  @recovery_enabled
end

#recovery_ui_urlObject

The URL for the recovery UI.



53
54
55
# File 'lib/ory-client/models/elements_configuration.rb', line 53

def recovery_ui_url
  @recovery_ui_url
end

#registration_enabledObject

Whether registration is enabled.



56
57
58
# File 'lib/ory-client/models/elements_configuration.rb', line 56

def registration_enabled
  @registration_enabled
end

#registration_ui_urlObject

The URL for the registration UI.



59
60
61
# File 'lib/ory-client/models/elements_configuration.rb', line 59

def registration_ui_url
  @registration_ui_url
end

#settings_ui_urlObject

The URL for the settings UI.



62
63
64
# File 'lib/ory-client/models/elements_configuration.rb', line 62

def settings_ui_url
  @settings_ui_url
end

#terms_of_service_urlObject

The URL to the project's Terms of Service page.



65
66
67
# File 'lib/ory-client/models/elements_configuration.rb', line 65

def terms_of_service_url
  @terms_of_service_url
end

#verification_enabledObject

Whether verification is enabled.



68
69
70
# File 'lib/ory-client/models/elements_configuration.rb', line 68

def verification_enabled
  @verification_enabled
end

#verification_ui_urlObject

The URL for the verification UI.



71
72
73
# File 'lib/ory-client/models/elements_configuration.rb', line 71

def verification_ui_url
  @verification_ui_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/ory-client/models/elements_configuration.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/ory-client/models/elements_configuration.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ory-client/models/elements_configuration.rb', line 74

def self.attribute_map
  {
    :'contact_url' => :'contact_url',
    :'default_redirect_url' => :'default_redirect_url',
    :'error_ui_url' => :'error_ui_url',
    :'hide_ory_branding' => :'hide_ory_branding',
    :'hide_registration_link' => :'hide_registration_link',
    :'login_ui_url' => :'login_ui_url',
    :'logo_dark_url' => :'logo_dark_url',
    :'logo_light_url' => :'logo_light_url',
    :'name' => :'name',
    :'privacy_policy_url' => :'privacy_policy_url',
    :'recovery_enabled' => :'recovery_enabled',
    :'recovery_ui_url' => :'recovery_ui_url',
    :'registration_enabled' => :'registration_enabled',
    :'registration_ui_url' => :'registration_ui_url',
    :'settings_ui_url' => :'settings_ui_url',
    :'terms_of_service_url' => :'terms_of_service_url',
    :'verification_enabled' => :'verification_enabled',
    :'verification_ui_url' => :'verification_ui_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/ory-client/models/elements_configuration.rb', line 502

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/ory-client/models/elements_configuration.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/ory-client/models/elements_configuration.rb', line 108

def self.openapi_types
  {
    :'contact_url' => :'String',
    :'default_redirect_url' => :'String',
    :'error_ui_url' => :'String',
    :'hide_ory_branding' => :'Boolean',
    :'hide_registration_link' => :'Boolean',
    :'login_ui_url' => :'String',
    :'logo_dark_url' => :'String',
    :'logo_light_url' => :'String',
    :'name' => :'String',
    :'privacy_policy_url' => :'String',
    :'recovery_enabled' => :'Boolean',
    :'recovery_ui_url' => :'String',
    :'registration_enabled' => :'Boolean',
    :'registration_ui_url' => :'String',
    :'settings_ui_url' => :'String',
    :'terms_of_service_url' => :'String',
    :'verification_enabled' => :'Boolean',
    :'verification_ui_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/ory-client/models/elements_configuration.rb', line 464

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      contact_url == o.contact_url &&
      default_redirect_url == o.default_redirect_url &&
      error_ui_url == o.error_ui_url &&
      hide_ory_branding == o.hide_ory_branding &&
      hide_registration_link == o.hide_registration_link &&
       == o. &&
      logo_dark_url == o.logo_dark_url &&
      logo_light_url == o.logo_light_url &&
      name == o.name &&
      privacy_policy_url == o.privacy_policy_url &&
      recovery_enabled == o.recovery_enabled &&
      recovery_ui_url == o.recovery_ui_url &&
      registration_enabled == o.registration_enabled &&
      registration_ui_url == o.registration_ui_url &&
      settings_ui_url == o.settings_ui_url &&
      terms_of_service_url == o.terms_of_service_url &&
      verification_enabled == o.verification_enabled &&
      verification_ui_url == o.verification_ui_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


489
490
491
# File 'lib/ory-client/models/elements_configuration.rb', line 489

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



495
496
497
# File 'lib/ory-client/models/elements_configuration.rb', line 495

def hash
  [contact_url, default_redirect_url, error_ui_url, hide_ory_branding, hide_registration_link, , logo_dark_url, logo_light_url, name, privacy_policy_url, recovery_enabled, recovery_ui_url, registration_enabled, registration_ui_url, settings_ui_url, terms_of_service_url, verification_enabled, verification_ui_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/ory-client/models/elements_configuration.rb', line 254

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @default_redirect_url.nil?
    invalid_properties.push('invalid value for "default_redirect_url", default_redirect_url cannot be nil.')
  end

  if @error_ui_url.nil?
    invalid_properties.push('invalid value for "error_ui_url", error_ui_url cannot be nil.')
  end

  if @hide_ory_branding.nil?
    invalid_properties.push('invalid value for "hide_ory_branding", hide_ory_branding cannot be nil.')
  end

  if @hide_registration_link.nil?
    invalid_properties.push('invalid value for "hide_registration_link", hide_registration_link cannot be nil.')
  end

  if @login_ui_url.nil?
    invalid_properties.push('invalid value for "login_ui_url", login_ui_url cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @recovery_enabled.nil?
    invalid_properties.push('invalid value for "recovery_enabled", recovery_enabled cannot be nil.')
  end

  if @recovery_ui_url.nil?
    invalid_properties.push('invalid value for "recovery_ui_url", recovery_ui_url cannot be nil.')
  end

  if @registration_enabled.nil?
    invalid_properties.push('invalid value for "registration_enabled", registration_enabled cannot be nil.')
  end

  if @registration_ui_url.nil?
    invalid_properties.push('invalid value for "registration_ui_url", registration_ui_url cannot be nil.')
  end

  if @settings_ui_url.nil?
    invalid_properties.push('invalid value for "settings_ui_url", settings_ui_url cannot be nil.')
  end

  if @verification_enabled.nil?
    invalid_properties.push('invalid value for "verification_enabled", verification_enabled cannot be nil.')
  end

  if @verification_ui_url.nil?
    invalid_properties.push('invalid value for "verification_ui_url", verification_ui_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/ory-client/models/elements_configuration.rb', line 524

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/ory-client/models/elements_configuration.rb', line 314

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @default_redirect_url.nil?
  return false if @error_ui_url.nil?
  return false if @hide_ory_branding.nil?
  return false if @hide_registration_link.nil?
  return false if @login_ui_url.nil?
  return false if @name.nil?
  return false if @recovery_enabled.nil?
  return false if @recovery_ui_url.nil?
  return false if @registration_enabled.nil?
  return false if @registration_ui_url.nil?
  return false if @settings_ui_url.nil?
  return false if @verification_enabled.nil?
  return false if @verification_ui_url.nil?
  true
end