Class: OryClient::FeatureFlagsCatalogEntry

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/feature_flags_catalog_entry.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FeatureFlagsCatalogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::FeatureFlagsCatalogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::FeatureFlagsCatalogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  else
    self.default = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'legacy_json_key')
    self.legacy_json_key = attributes[:'legacy_json_key']
  end

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  else
    self.service = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end
end

Instance Attribute Details

#default ⇒ Object

The effective value while the flag is unset.



19
20
21
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 19

def default
  @default
end

#key ⇒ Object

The API-visible flag key, e.g. kratos.choose_recovery_address.



22
23
24
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 22

def key
  @key
end

#legacy_json_key ⇒ Object

When set, writes must use this normalized config field instead of the feature_flags map.



25
26
27
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 25

def legacy_json_key
  @legacy_json_key
end

#service ⇒ Object

The service the flag configures: kratos, hydra, keto, or account_experience.



28
29
30
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 28

def service
  @service
end

#state ⇒ Object

The lifecycle state: active flags are writable, frozen flags are forced to their final value.



31
32
33
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 31

def state
  @state
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



45
46
47
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 34

def self.attribute_map
  {
    :'default' => :'default',
    :'key' => :'key',
    :'legacy_json_key' => :'legacy_json_key',
    :'service' => :'service',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



66
67
68
69
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 55

def self.openapi_types
  {
    :'default' => :'Boolean',
    :'key' => :'String',
    :'legacy_json_key' => :'String',
    :'service' => :'String',
    :'state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



193
194
195
196
197
198
199
200
201
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default == o.default &&
      key == o.key &&
      legacy_json_key == o.legacy_json_key &&
      service == o.service &&
      state == o.state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 205

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



211
212
213
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 211

def hash
  [default, key, legacy_json_key, service, state].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @default.nil?
    invalid_properties.push('invalid value for "default", default cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @service.nil?
    invalid_properties.push('invalid value for "service", service cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



142
143
144
145
146
147
148
149
# File 'lib/ory-client/models/feature_flags_catalog_entry.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @default.nil?
  return false if @key.nil?
  return false if @service.nil?
  return false if @state.nil?
  true
end