Class: OryClient::IdentityCredentialsWebAuthn

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/identity_credentials_web_authn.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IdentityCredentialsWebAuthn

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::IdentityCredentialsWebAuthn` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::IdentityCredentialsWebAuthn`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'added_at')
    self.added_at = attributes[:'added_at']
  end

  if attributes.key?(:'attestation')
    self.attestation = attributes[:'attestation']
  end

  if attributes.key?(:'attestation_type')
    self.attestation_type = attributes[:'attestation_type']
  end

  if attributes.key?(:'authenticator')
    self.authenticator = attributes[:'authenticator']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'flags')
    self.flags = attributes[:'flags']
  end

  if attributes.key?(:'id')
    if (value = attributes[:'id']).is_a?(Array)
      self.id = value
    end
  end

  if attributes.key?(:'is_passwordless')
    self.is_passwordless = attributes[:'is_passwordless']
  end

  if attributes.key?(:'public_key')
    if (value = attributes[:'public_key']).is_a?(Array)
      self.public_key = value
    end
  end

  if attributes.key?(:'transport')
    if (value = attributes[:'transport']).is_a?(Array)
      self.transport = value
    end
  end
end

Instance Attribute Details

#added_atObject

Returns the value of attribute added_at.



18
19
20
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 18

def added_at
  @added_at
end

#attestationObject

Returns the value of attribute attestation.



20
21
22
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 20

def attestation
  @attestation
end

#attestation_typeObject

Returns the value of attribute attestation_type.



22
23
24
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 22

def attestation_type
  @attestation_type
end

#authenticatorObject

Returns the value of attribute authenticator.



24
25
26
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 24

def authenticator
  @authenticator
end

#display_nameObject

Returns the value of attribute display_name.



26
27
28
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 26

def display_name
  @display_name
end

#flagsObject

Returns the value of attribute flags.



28
29
30
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 28

def flags
  @flags
end

#idObject

Returns the value of attribute id.



30
31
32
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 30

def id
  @id
end

#is_passwordlessObject

Returns the value of attribute is_passwordless.



32
33
34
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 32

def is_passwordless
  @is_passwordless
end

#public_keyObject

Returns the value of attribute public_key.



34
35
36
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 34

def public_key
  @public_key
end

#transportObject

Returns the value of attribute transport.



36
37
38
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 36

def transport
  @transport
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 39

def self.attribute_map
  {
    :'added_at' => :'added_at',
    :'attestation' => :'attestation',
    :'attestation_type' => :'attestation_type',
    :'authenticator' => :'authenticator',
    :'display_name' => :'display_name',
    :'flags' => :'flags',
    :'id' => :'id',
    :'is_passwordless' => :'is_passwordless',
    :'public_key' => :'public_key',
    :'transport' => :'transport'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 65

def self.openapi_types
  {
    :'added_at' => :'Time',
    :'attestation' => :'IdentityCredentialsWebAuthnAttestation',
    :'attestation_type' => :'String',
    :'authenticator' => :'IdentityCredentialsWebAuthnAuthenticator',
    :'display_name' => :'String',
    :'flags' => :'IdentityCredentialsWebAuthnFlags',
    :'id' => :'Array<Integer>',
    :'is_passwordless' => :'Boolean',
    :'public_key' => :'Array<Integer>',
    :'transport' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      added_at == o.added_at &&
      attestation == o.attestation &&
      attestation_type == o.attestation_type &&
      authenticator == o.authenticator &&
      display_name == o.display_name &&
      flags == o.flags &&
      id == o.id &&
      is_passwordless == o.is_passwordless &&
      public_key == o.public_key &&
      transport == o.transport
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 189

def hash
  [added_at, attestation, attestation_type, authenticator, display_name, flags, id, is_passwordless, public_key, transport].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
# File 'lib/ory-client/models/identity_credentials_web_authn.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end