Class: OryClient::IdentityCredentialsWebAuthnAttestation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::IdentityCredentialsWebAuthnAttestation
- Defined in:
- lib/ory-client/models/identity_credentials_web_authn_attestation.rb
Instance Attribute Summary collapse
-
#authenticator_data ⇒ Object
Returns the value of attribute authenticator_data.
-
#client_data_hash ⇒ Object
Returns the value of attribute client_data_hash.
-
#client_data_json ⇒ Object
Returns the value of attribute client_data_json.
-
#object ⇒ Object
Returns the value of attribute object.
-
#public_key_algorithm ⇒ Object
Returns the value of attribute public_key_algorithm.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityCredentialsWebAuthnAttestation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IdentityCredentialsWebAuthnAttestation
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::IdentityCredentialsWebAuthnAttestation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::IdentityCredentialsWebAuthnAttestation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'authenticator_data') if (value = attributes[:'authenticator_data']).is_a?(Array) self.authenticator_data = value end end if attributes.key?(:'client_data_json') if (value = attributes[:'client_data_json']).is_a?(Array) self.client_data_json = value end end if attributes.key?(:'client_data_hash') if (value = attributes[:'client_data_hash']).is_a?(Array) self.client_data_hash = value end end if attributes.key?(:'object') if (value = attributes[:'object']).is_a?(Array) self.object = value end end if attributes.key?(:'public_key_algorithm') self.public_key_algorithm = attributes[:'public_key_algorithm'] end end |
Instance Attribute Details
#authenticator_data ⇒ Object
Returns the value of attribute authenticator_data.
18 19 20 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 18 def authenticator_data @authenticator_data end |
#client_data_hash ⇒ Object
Returns the value of attribute client_data_hash.
22 23 24 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 22 def client_data_hash @client_data_hash end |
#client_data_json ⇒ Object
Returns the value of attribute client_data_json.
20 21 22 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 20 def client_data_json @client_data_json end |
#object ⇒ Object
Returns the value of attribute object.
24 25 26 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 24 def object @object end |
#public_key_algorithm ⇒ Object
Returns the value of attribute public_key_algorithm.
26 27 28 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 26 def public_key_algorithm @public_key_algorithm end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 29 def self.attribute_map { :'authenticator_data' => :'authenticator_data', :'client_data_json' => :'client_dataJSON', :'client_data_hash' => :'client_data_hash', :'object' => :'object', :'public_key_algorithm' => :'public_key_algorithm' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 50 def self.openapi_types { :'authenticator_data' => :'Array<Integer>', :'client_data_json' => :'Array<Integer>', :'client_data_hash' => :'Array<Integer>', :'object' => :'Array<Integer>', :'public_key_algorithm' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 128 def ==(o) return true if self.equal?(o) self.class == o.class && authenticator_data == o.authenticator_data && client_data_json == o.client_data_json && client_data_hash == o.client_data_hash && object == o.object && public_key_algorithm == o.public_key_algorithm end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 146 def hash [authenticator_data, client_data_json, client_data_hash, object, public_key_algorithm].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 |
# File 'lib/ory-client/models/identity_credentials_web_authn_attestation.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |