Class: OryClient::IdentityPatchResponse

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/identity_patch_response.rb

Overview

Response for a single identity patch

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IdentityPatchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/ory-client/models/identity_patch_response.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::IdentityPatchResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::IdentityPatchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'identity')
    self.identity = attributes[:'identity']
  end

  if attributes.key?(:'patch_id')
    self.patch_id = attributes[:'patch_id']
  end
end

Instance Attribute Details

#actionObject

The action for this specific patch create ActionCreate Create this identity. error ActionError Error indicates that the patch failed.



20
21
22
# File 'lib/ory-client/models/identity_patch_response.rb', line 20

def action
  @action
end

#errorObject

From go.dev/wiki/CodeReviewComments#receiver-type: > Can function or methods, either concurrently or when called from this method, be mutating the receiver? A value type creates a copy of the receiver when the method is invoked, so outside updates will not be applied to this receiver. If changes must be visible in the original receiver, the receiver must be a pointer. > If the receiver is a struct, array or slice and any of its elements is a pointer to something that might be mutating, > prefer a pointer receiver, as it will make the intention clearer to the reader. > Don’t mix receiver types. Choose either pointers or struct types for all available methods.



23
24
25
# File 'lib/ory-client/models/identity_patch_response.rb', line 23

def error
  @error
end

#identityObject

The identity ID payload of this patch



26
27
28
# File 'lib/ory-client/models/identity_patch_response.rb', line 26

def identity
  @identity
end

#patch_idObject

The ID of this patch response, if an ID was specified in the patch.



29
30
31
# File 'lib/ory-client/models/identity_patch_response.rb', line 29

def patch_id
  @patch_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/ory-client/models/identity_patch_response.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/ory-client/models/identity_patch_response.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/ory-client/models/identity_patch_response.rb', line 54

def self.attribute_map
  {
    :'action' => :'action',
    :'error' => :'error',
    :'identity' => :'identity',
    :'patch_id' => :'patch_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/ory-client/models/identity_patch_response.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
88
# File 'lib/ory-client/models/identity_patch_response.rb', line 84

def self.openapi_nullable
  Set.new([
    :'error',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/ory-client/models/identity_patch_response.rb', line 74

def self.openapi_types
  {
    :'action' => :'String',
    :'error' => :'Object',
    :'identity' => :'String',
    :'patch_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
# File 'lib/ory-client/models/identity_patch_response.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      error == o.error &&
      identity == o.identity &&
      patch_id == o.patch_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/ory-client/models/identity_patch_response.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/ory-client/models/identity_patch_response.rb', line 169

def hash
  [action, error, identity, patch_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
# File 'lib/ory-client/models/identity_patch_response.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ory-client/models/identity_patch_response.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
# File 'lib/ory-client/models/identity_patch_response.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  action_validator = EnumAttributeValidator.new('String', ["create", "error"])
  return false unless action_validator.valid?(@action)
  true
end