Class: OryClient::IdentityWithCredentialsPasswordConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::IdentityWithCredentialsPasswordConfig
- Defined in:
- lib/ory-client/models/identity_with_credentials_password_config.rb
Overview
Create Identity and Import Password Credentials Configuration
Instance Attribute Summary collapse
-
#hashed_password ⇒ Object
The hashed password in [PHC format](www.ory.sh/docs/kratos/manage-identities/import-user-accounts-identities#hashed-passwords).
-
#password ⇒ Object
The password in plain text if no hash is available.
-
#use_password_migration_hook ⇒ Object
If set to true, the password will be migrated using the password migration hook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityWithCredentialsPasswordConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IdentityWithCredentialsPasswordConfig
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::IdentityWithCredentialsPasswordConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::IdentityWithCredentialsPasswordConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'hashed_password') self.hashed_password = attributes[:'hashed_password'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'use_password_migration_hook') self.use_password_migration_hook = attributes[:'use_password_migration_hook'] end end |
Instance Attribute Details
#hashed_password ⇒ Object
The hashed password in [PHC format](www.ory.sh/docs/kratos/manage-identities/import-user-accounts-identities#hashed-passwords)
20 21 22 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 20 def hashed_password @hashed_password end |
#password ⇒ Object
The password in plain text if no hash is available.
23 24 25 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 23 def password @password end |
#use_password_migration_hook ⇒ Object
If set to true, the password will be migrated using the password migration hook.
26 27 28 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 26 def use_password_migration_hook @use_password_migration_hook end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 29 def self.attribute_map { :'hashed_password' => :'hashed_password', :'password' => :'password', :'use_password_migration_hook' => :'use_password_migration_hook' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 131 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 48 def self.openapi_types { :'hashed_password' => :'String', :'password' => :'String', :'use_password_migration_hook' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && hashed_password == o.hashed_password && password == o.password && use_password_migration_hook == o.use_password_migration_hook end |
#eql?(o) ⇒ Boolean
118 119 120 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 118 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 124 def hash [hashed_password, password, use_password_migration_hook].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
101 102 103 104 |
# File 'lib/ory-client/models/identity_with_credentials_password_config.rb', line 101 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |