Class: OryClient::LineItemV1
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::LineItemV1
- Defined in:
- lib/ory-client/models/line_item_v1.rb
Instance Attribute Summary collapse
-
#amount_in_cent ⇒ Object
Returns the value of attribute amount_in_cent.
-
#description ⇒ Object
Returns the value of attribute description.
-
#items ⇒ Object
Each line item can have sub-items to create a hierarchy.
-
#quantity ⇒ Object
Returns the value of attribute quantity.
-
#title ⇒ Object
Returns the value of attribute title.
-
#unit_price ⇒ Object
Returns the value of attribute unit_price.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LineItemV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LineItemV1
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/ory-client/models/line_item_v1.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::LineItemV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::LineItemV1`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount_in_cent') self.amount_in_cent = attributes[:'amount_in_cent'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'unit_price') self.unit_price = attributes[:'unit_price'] end end |
Instance Attribute Details
#amount_in_cent ⇒ Object
Returns the value of attribute amount_in_cent.
18 19 20 |
# File 'lib/ory-client/models/line_item_v1.rb', line 18 def amount_in_cent @amount_in_cent end |
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/ory-client/models/line_item_v1.rb', line 20 def description @description end |
#items ⇒ Object
Each line item can have sub-items to create a hierarchy.
23 24 25 |
# File 'lib/ory-client/models/line_item_v1.rb', line 23 def items @items end |
#quantity ⇒ Object
Returns the value of attribute quantity.
25 26 27 |
# File 'lib/ory-client/models/line_item_v1.rb', line 25 def quantity @quantity end |
#title ⇒ Object
Returns the value of attribute title.
27 28 29 |
# File 'lib/ory-client/models/line_item_v1.rb', line 27 def title @title end |
#unit_price ⇒ Object
Returns the value of attribute unit_price.
29 30 31 |
# File 'lib/ory-client/models/line_item_v1.rb', line 29 def unit_price @unit_price end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/ory-client/models/line_item_v1.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/ory-client/models/line_item_v1.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/ory-client/models/line_item_v1.rb', line 32 def self.attribute_map { :'amount_in_cent' => :'amount_in_cent', :'description' => :'description', :'items' => :'items', :'quantity' => :'quantity', :'title' => :'title', :'unit_price' => :'unit_price' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/ory-client/models/line_item_v1.rb', line 157 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/ory-client/models/line_item_v1.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/ory-client/models/line_item_v1.rb', line 54 def self.openapi_types { :'amount_in_cent' => :'Integer', :'description' => :'String', :'items' => :'Array<LineItemV1>', :'quantity' => :'Integer', :'title' => :'String', :'unit_price' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 140 |
# File 'lib/ory-client/models/line_item_v1.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && amount_in_cent == o.amount_in_cent && description == o.description && items == o.items && quantity == o.quantity && title == o.title && unit_price == o.unit_price end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/ory-client/models/line_item_v1.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/ory-client/models/line_item_v1.rb', line 150 def hash [amount_in_cent, description, items, quantity, title, unit_price].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/ory-client/models/line_item_v1.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ory-client/models/line_item_v1.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 |
# File 'lib/ory-client/models/line_item_v1.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |