Class: OryClient::ManageSessionsBody

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/manage_sessions_body.rb

Overview

Body for the bulk session management endpoint. Exactly one of ‘identities` or `sessions` must be provided. To operate on every session in the network, pass `identities: ["*"]` — the wildcard must appear alone, never mixed with explicit IDs.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ManageSessionsBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ory-client/models/manage_sessions_body.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ManageSessionsBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ManageSessionsBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'identities')
    if (value = attributes[:'identities']).is_a?(Array)
      self.identities = value
    end
  end

  if attributes.key?(:'sessions')
    if (value = attributes[:'sessions']).is_a?(Array)
      self.sessions = value
    end
  end
end

Instance Attribute Details

#actionObject

Action to perform on the matching sessions. disable ManageSessionsActionDisable delete ManageSessionsActionDelete



20
21
22
# File 'lib/ory-client/models/manage_sessions_body.rb', line 20

def action
  @action
end

#identitiesObject

Identity IDs whose sessions should be disabled or deleted, or ‘["*"]` to operate on every session in the network. Mutually exclusive with `sessions`.



23
24
25
# File 'lib/ory-client/models/manage_sessions_body.rb', line 23

def identities
  @identities
end

#sessionsObject

Session IDs to disable or delete. Mutually exclusive with ‘identities`. The wildcard `["*"]` is not accepted in this field — pass `identities: ["*"]` to scope the operation to every session in the network.



26
27
28
# File 'lib/ory-client/models/manage_sessions_body.rb', line 26

def sessions
  @sessions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/ory-client/models/manage_sessions_body.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/ory-client/models/manage_sessions_body.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/ory-client/models/manage_sessions_body.rb', line 51

def self.attribute_map
  {
    :'action' => :'action',
    :'identities' => :'identities',
    :'sessions' => :'sessions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/ory-client/models/manage_sessions_body.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/ory-client/models/manage_sessions_body.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/ory-client/models/manage_sessions_body.rb', line 70

def self.openapi_types
  {
    :'action' => :'String',
    :'identities' => :'Array<String>',
    :'sessions' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
# File 'lib/ory-client/models/manage_sessions_body.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      identities == o.identities &&
      sessions == o.sessions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/ory-client/models/manage_sessions_body.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/ory-client/models/manage_sessions_body.rb', line 169

def hash
  [action, identities, sessions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
# File 'lib/ory-client/models/manage_sessions_body.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ory-client/models/manage_sessions_body.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
# File 'lib/ory-client/models/manage_sessions_body.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  action_validator = EnumAttributeValidator.new('String', ["disable", "delete"])
  return false unless action_validator.valid?(@action)
  true
end