Class: OryClient::NormalizedProjectRevisionHook
- Inherits:
-
Object
- Object
- OryClient::NormalizedProjectRevisionHook
- Defined in:
- lib/ory-client/models/normalized_project_revision_hook.rb
Instance Attribute Summary collapse
-
#config_key ⇒ Object
The Hooks Config Key.
-
#created_at ⇒ Object
The Project's Revision Creation Date.
-
#hook ⇒ Object
The Hook Type.
-
#id ⇒ Object
Returns the value of attribute id.
-
#project_revision_id ⇒ Object
Returns the value of attribute project_revision_id.
-
#updated_at ⇒ Object
Last Time Project's Revision was Updated.
-
#web_hook_config_auth_api_key_in ⇒ Object
Whether to send the API Key in the HTTP Header or as a HTTP Cookie.
-
#web_hook_config_auth_api_key_name ⇒ Object
The name of the api key.
-
#web_hook_config_auth_api_key_value ⇒ Object
The value of the api key.
-
#web_hook_config_auth_basic_auth_password ⇒ Object
The password to be sent in the HTTP Basic Auth Header.
-
#web_hook_config_auth_basic_auth_user ⇒ Object
The username to be sent in the HTTP Basic Auth Header.
-
#web_hook_config_auth_type ⇒ Object
HTTP Auth Method to use for the Web-Hook.
-
#web_hook_config_body ⇒ Object
URI pointing to the JsonNet template used for Web-Hook payload generation.
-
#web_hook_config_method ⇒ Object
The HTTP method to use (GET, POST, etc) for the Web-Hook.
-
#web_hook_config_response_ignore ⇒ Object
Whether to ignore the Web Hook response.
-
#web_hook_config_url ⇒ Object
The URL the Web-Hook should call.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NormalizedProjectRevisionHook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NormalizedProjectRevisionHook
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::NormalizedProjectRevisionHook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::NormalizedProjectRevisionHook`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'config_key') self.config_key = attributes[:'config_key'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'hook') self.hook = attributes[:'hook'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'project_revision_id') self.project_revision_id = attributes[:'project_revision_id'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'web_hook_config_auth_api_key_in') self.web_hook_config_auth_api_key_in = attributes[:'web_hook_config_auth_api_key_in'] end if attributes.key?(:'web_hook_config_auth_api_key_name') self.web_hook_config_auth_api_key_name = attributes[:'web_hook_config_auth_api_key_name'] end if attributes.key?(:'web_hook_config_auth_api_key_value') self.web_hook_config_auth_api_key_value = attributes[:'web_hook_config_auth_api_key_value'] end if attributes.key?(:'web_hook_config_auth_basic_auth_password') self.web_hook_config_auth_basic_auth_password = attributes[:'web_hook_config_auth_basic_auth_password'] end if attributes.key?(:'web_hook_config_auth_basic_auth_user') self.web_hook_config_auth_basic_auth_user = attributes[:'web_hook_config_auth_basic_auth_user'] end if attributes.key?(:'web_hook_config_auth_type') self.web_hook_config_auth_type = attributes[:'web_hook_config_auth_type'] end if attributes.key?(:'web_hook_config_body') self.web_hook_config_body = attributes[:'web_hook_config_body'] end if attributes.key?(:'web_hook_config_method') self.web_hook_config_method = attributes[:'web_hook_config_method'] end if attributes.key?(:'web_hook_config_response_ignore') self.web_hook_config_response_ignore = attributes[:'web_hook_config_response_ignore'] end if attributes.key?(:'web_hook_config_url') self.web_hook_config_url = attributes[:'web_hook_config_url'] end end |
Instance Attribute Details
#config_key ⇒ Object
The Hooks Config Key
19 20 21 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 19 def config_key @config_key end |
#created_at ⇒ Object
The Project's Revision Creation Date
22 23 24 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 22 def created_at @created_at end |
#hook ⇒ Object
The Hook Type
25 26 27 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 25 def hook @hook end |
#id ⇒ Object
Returns the value of attribute id.
27 28 29 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 27 def id @id end |
#project_revision_id ⇒ Object
Returns the value of attribute project_revision_id.
29 30 31 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 29 def project_revision_id @project_revision_id end |
#updated_at ⇒ Object
Last Time Project's Revision was Updated
32 33 34 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 32 def updated_at @updated_at end |
#web_hook_config_auth_api_key_in ⇒ Object
Whether to send the API Key in the HTTP Header or as a HTTP Cookie
35 36 37 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 35 def web_hook_config_auth_api_key_in @web_hook_config_auth_api_key_in end |
#web_hook_config_auth_api_key_name ⇒ Object
The name of the api key
38 39 40 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 38 def web_hook_config_auth_api_key_name @web_hook_config_auth_api_key_name end |
#web_hook_config_auth_api_key_value ⇒ Object
The value of the api key
41 42 43 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 41 def web_hook_config_auth_api_key_value @web_hook_config_auth_api_key_value end |
#web_hook_config_auth_basic_auth_password ⇒ Object
The password to be sent in the HTTP Basic Auth Header
44 45 46 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 44 def web_hook_config_auth_basic_auth_password @web_hook_config_auth_basic_auth_password end |
#web_hook_config_auth_basic_auth_user ⇒ Object
The username to be sent in the HTTP Basic Auth Header
47 48 49 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 47 def web_hook_config_auth_basic_auth_user @web_hook_config_auth_basic_auth_user end |
#web_hook_config_auth_type ⇒ Object
HTTP Auth Method to use for the Web-Hook
50 51 52 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 50 def web_hook_config_auth_type @web_hook_config_auth_type end |
#web_hook_config_body ⇒ Object
URI pointing to the JsonNet template used for Web-Hook payload generation. Only used for those HTTP methods, which support HTTP body payloads.
53 54 55 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 53 def web_hook_config_body @web_hook_config_body end |
#web_hook_config_method ⇒ Object
The HTTP method to use (GET, POST, etc) for the Web-Hook
56 57 58 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 56 def web_hook_config_method @web_hook_config_method end |
#web_hook_config_response_ignore ⇒ Object
Whether to ignore the Web Hook response
59 60 61 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 59 def web_hook_config_response_ignore @web_hook_config_response_ignore end |
#web_hook_config_url ⇒ Object
The URL the Web-Hook should call
62 63 64 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 62 def web_hook_config_url @web_hook_config_url end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 87 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 65 def self.attribute_map { :'config_key' => :'config_key', :'created_at' => :'created_at', :'hook' => :'hook', :'id' => :'id', :'project_revision_id' => :'project_revision_id', :'updated_at' => :'updated_at', :'web_hook_config_auth_api_key_in' => :'web_hook_config_auth_api_key_in', :'web_hook_config_auth_api_key_name' => :'web_hook_config_auth_api_key_name', :'web_hook_config_auth_api_key_value' => :'web_hook_config_auth_api_key_value', :'web_hook_config_auth_basic_auth_password' => :'web_hook_config_auth_basic_auth_password', :'web_hook_config_auth_basic_auth_user' => :'web_hook_config_auth_basic_auth_user', :'web_hook_config_auth_type' => :'web_hook_config_auth_type', :'web_hook_config_body' => :'web_hook_config_body', :'web_hook_config_method' => :'web_hook_config_method', :'web_hook_config_response_ignore' => :'web_hook_config_response_ignore', :'web_hook_config_url' => :'web_hook_config_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 260 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 92 def self.openapi_types { :'config_key' => :'String', :'created_at' => :'Time', :'hook' => :'String', :'id' => :'String', :'project_revision_id' => :'String', :'updated_at' => :'Time', :'web_hook_config_auth_api_key_in' => :'String', :'web_hook_config_auth_api_key_name' => :'String', :'web_hook_config_auth_api_key_value' => :'String', :'web_hook_config_auth_basic_auth_password' => :'String', :'web_hook_config_auth_basic_auth_user' => :'String', :'web_hook_config_auth_type' => :'String', :'web_hook_config_body' => :'String', :'web_hook_config_method' => :'String', :'web_hook_config_response_ignore' => :'Boolean', :'web_hook_config_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && config_key == o.config_key && created_at == o.created_at && hook == o.hook && id == o.id && project_revision_id == o.project_revision_id && updated_at == o.updated_at && web_hook_config_auth_api_key_in == o.web_hook_config_auth_api_key_in && web_hook_config_auth_api_key_name == o.web_hook_config_auth_api_key_name && web_hook_config_auth_api_key_value == o.web_hook_config_auth_api_key_value && web_hook_config_auth_basic_auth_password == o.web_hook_config_auth_basic_auth_password && web_hook_config_auth_basic_auth_user == o.web_hook_config_auth_basic_auth_user && web_hook_config_auth_type == o.web_hook_config_auth_type && web_hook_config_body == o.web_hook_config_body && web_hook_config_method == o.web_hook_config_method && web_hook_config_response_ignore == o.web_hook_config_response_ignore && web_hook_config_url == o.web_hook_config_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 290 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OryClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 267 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 253 def hash [config_key, created_at, hook, id, project_revision_id, updated_at, web_hook_config_auth_api_key_in, web_hook_config_auth_api_key_name, web_hook_config_auth_api_key_value, web_hook_config_auth_basic_auth_password, web_hook_config_auth_basic_auth_user, web_hook_config_auth_type, web_hook_config_body, web_hook_config_method, web_hook_config_response_ignore, web_hook_config_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 201 def list_invalid_properties invalid_properties = Array.new if @config_key.nil? invalid_properties.push('invalid value for "config_key", config_key cannot be nil.') end if @hook.nil? invalid_properties.push('invalid value for "hook", hook cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
337 338 339 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 337 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 331 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
216 217 218 219 220 |
# File 'lib/ory-client/models/normalized_project_revision_hook.rb', line 216 def valid? return false if @config_key.nil? return false if @hook.nil? true end |