Class: OryClient::NormalizedProjectRevisionIdentitySchema

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/normalized_project_revision_identity_schema.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NormalizedProjectRevisionIdentitySchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::NormalizedProjectRevisionIdentitySchema` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::NormalizedProjectRevisionIdentitySchema`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'identity_schema')
    self.identity_schema = attributes[:'identity_schema']
  end

  if attributes.key?(:'identity_schema_id')
    self.identity_schema_id = attributes[:'identity_schema_id']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'import_url')
    self.import_url = attributes[:'import_url']
  end

  if attributes.key?(:'is_default')
    self.is_default = attributes[:'is_default']
  end

  if attributes.key?(:'preset')
    self.preset = attributes[:'preset']
  end

  if attributes.key?(:'project_revision_id')
    self.project_revision_id = attributes[:'project_revision_id']
  end

  if attributes.key?(:'selfservice_selectable')
    self.selfservice_selectable = attributes[:'selfservice_selectable']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

The Project’s Revision Creation Date



19
20
21
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 19

def created_at
  @created_at
end

#idObject

The unique ID of this entry.



22
23
24
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 22

def id
  @id
end

#identity_schemaObject

Returns the value of attribute identity_schema.



24
25
26
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 24

def identity_schema
  @identity_schema
end

#identity_schema_idObject

Returns the value of attribute identity_schema_id.



26
27
28
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 26

def identity_schema_id
  @identity_schema_id
end

#import_idObject

The imported (named) ID of the Identity Schema referenced in the Ory Kratos config.



29
30
31
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 29

def import_id
  @import_id
end

#import_urlObject

The ImportURL can be used to import an Identity Schema from a bse64 encoded string. In the future, this key also support HTTPS and other sources! If you import an Ory Kratos configuration, this would be akin to the ‘identity.schemas.#.url` key. The configuration will always return the import URL when you fetch it from the API.



32
33
34
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 32

def import_url
  @import_url
end

#is_defaultObject

If true sets the default schema for identities Only one schema can ever be the default schema. If you try to add two schemas with default to true, the request will fail.



35
36
37
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 35

def is_default
  @is_default
end

#presetObject

Use a preset instead of a custom identity schema.



38
39
40
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 38

def preset
  @preset
end

#project_revision_idObject

The Revision’s ID this schema belongs to



41
42
43
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 41

def project_revision_id
  @project_revision_id
end

#selfservice_selectableObject

Returns the value of attribute selfservice_selectable.



43
44
45
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 43

def selfservice_selectable
  @selfservice_selectable
end

#updated_atObject

Last Time Project’s Revision was Updated



46
47
48
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 46

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 49

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'identity_schema' => :'identity_schema',
    :'identity_schema_id' => :'identity_schema_id',
    :'import_id' => :'import_id',
    :'import_url' => :'import_url',
    :'is_default' => :'is_default',
    :'preset' => :'preset',
    :'project_revision_id' => :'project_revision_id',
    :'selfservice_selectable' => :'selfservice_selectable',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 93

def self.openapi_nullable
  Set.new([
    :'identity_schema_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 76

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'id' => :'String',
    :'identity_schema' => :'ManagedIdentitySchema',
    :'identity_schema_id' => :'String',
    :'import_id' => :'String',
    :'import_url' => :'String',
    :'is_default' => :'Boolean',
    :'preset' => :'String',
    :'project_revision_id' => :'String',
    :'selfservice_selectable' => :'Boolean',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      id == o.id &&
      identity_schema == o.identity_schema &&
      identity_schema_id == o.identity_schema_id &&
      import_id == o.import_id &&
      import_url == o.import_url &&
      is_default == o.is_default &&
      preset == o.preset &&
      project_revision_id == o.project_revision_id &&
      selfservice_selectable == o.selfservice_selectable &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 201

def hash
  [created_at, id, identity_schema, identity_schema_id, import_id, import_url, is_default, preset, project_revision_id, selfservice_selectable, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
# File 'lib/ory-client/models/normalized_project_revision_identity_schema.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end