Class: OryClient::OAuth2ConsentSession

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/o_auth2_consent_session.rb

Overview

A completed OAuth 2.0 Consent Session.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OAuth2ConsentSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OAuth2ConsentSession` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OAuth2ConsentSession`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'consent_request')
    self.consent_request = attributes[:'consent_request']
  end

  if attributes.key?(:'consent_request_id')
    self.consent_request_id = attributes[:'consent_request_id']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'grant_access_token_audience')
    if (value = attributes[:'grant_access_token_audience']).is_a?(Array)
      self.grant_access_token_audience = value
    end
  end

  if attributes.key?(:'grant_scope')
    if (value = attributes[:'grant_scope']).is_a?(Array)
      self.grant_scope = value
    end
  end

  if attributes.key?(:'handled_at')
    self.handled_at = attributes[:'handled_at']
  end

  if attributes.key?(:'remember')
    self.remember = attributes[:'remember']
  end

  if attributes.key?(:'remember_for')
    self.remember_for = attributes[:'remember_for']
  end

  if attributes.key?(:'session')
    self.session = attributes[:'session']
  end
end

Instance Attribute Details

Returns the value of attribute consent_request.



19
20
21
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 19

def consent_request
  @consent_request
end

ConsentRequestID is the identifier of the consent request that initiated this consent session.



22
23
24
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 22

def consent_request_id
  @consent_request_id
end

#contextObject

Returns the value of attribute context.



24
25
26
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 24

def context
  @context
end

#grant_access_token_audienceObject

Audience Granted GrantedAudience sets the audience the user authorized the client to use. Should be a subset of ‘requested_access_token_audience`.



27
28
29
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 27

def grant_access_token_audience
  @grant_access_token_audience
end

#grant_scopeObject

Scope Granted GrantScope sets the scope the user authorized the client to use. Should be a subset of ‘requested_scope`.



30
31
32
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 30

def grant_scope
  @grant_scope
end

#handled_atObject

Returns the value of attribute handled_at.



32
33
34
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 32

def handled_at
  @handled_at
end

#rememberObject

Remember Consent Remember, if set to true, tells ORY Hydra to remember this consent authorization and reuse it if the same client asks the same user for the same, or a subset of, scope.



35
36
37
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 35

def remember
  @remember
end

#remember_forObject

Remember Consent For RememberFor sets how long the consent authorization should be remembered for in seconds. If set to ‘0`, the authorization will be remembered indefinitely.



38
39
40
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 38

def remember_for
  @remember_for
end

#sessionObject

Returns the value of attribute session.



40
41
42
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 40

def session
  @session
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 43

def self.attribute_map
  {
    :'consent_request' => :'consent_request',
    :'consent_request_id' => :'consent_request_id',
    :'context' => :'context',
    :'grant_access_token_audience' => :'grant_access_token_audience',
    :'grant_scope' => :'grant_scope',
    :'handled_at' => :'handled_at',
    :'remember' => :'remember',
    :'remember_for' => :'remember_for',
    :'session' => :'session'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 68

def self.openapi_types
  {
    :'consent_request' => :'OAuth2ConsentRequest',
    :'consent_request_id' => :'String',
    :'context' => :'Object',
    :'grant_access_token_audience' => :'Array<String>',
    :'grant_scope' => :'Array<String>',
    :'handled_at' => :'Time',
    :'remember' => :'Boolean',
    :'remember_for' => :'Integer',
    :'session' => :'AcceptOAuth2ConsentRequestSession'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      consent_request == o.consent_request &&
      consent_request_id == o.consent_request_id &&
      context == o.context &&
      grant_access_token_audience == o.grant_access_token_audience &&
      grant_scope == o.grant_scope &&
      handled_at == o.handled_at &&
      remember == o.remember &&
      remember_for == o.remember_for &&
      session == o.session
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 184

def hash
  [consent_request, consent_request_id, context, grant_access_token_audience, grant_scope, handled_at, remember, remember_for, session].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end