Class: OryClient::ProjectMetadata

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/project_metadata.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/ory-client/models/project_metadata.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ProjectMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ProjectMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  else
    self.environment = nil
  end

  if attributes.key?(:'home_region')
    self.home_region = attributes[:'home_region']
  else
    self.home_region = nil
  end

  if attributes.key?(:'hosts')
    if (value = attributes[:'hosts']).is_a?(Array)
      self.hosts = value
    end
  else
    self.hosts = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'subscription_plan')
    self.subscription_plan = attributes[:'subscription_plan']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'workspace')
    self.workspace = attributes[:'workspace']
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end
end

Instance Attribute Details

#created_atObject

The Project’s Creation Date



19
20
21
# File 'lib/ory-client/models/project_metadata.rb', line 19

def created_at
  @created_at
end

#environmentObject

The environment of the project. prod Production stage Staging dev Development



22
23
24
# File 'lib/ory-client/models/project_metadata.rb', line 22

def environment
  @environment
end

#home_regionObject

The project’s data home region eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest us US global Global



25
26
27
# File 'lib/ory-client/models/project_metadata.rb', line 25

def home_region
  @home_region
end

#hostsObject

The FQDN hostnames this project listens on



28
29
30
# File 'lib/ory-client/models/project_metadata.rb', line 28

def hosts
  @hosts
end

#idObject

The project’s ID.



31
32
33
# File 'lib/ory-client/models/project_metadata.rb', line 31

def id
  @id
end

#nameObject

The project’s name if set



34
35
36
# File 'lib/ory-client/models/project_metadata.rb', line 34

def name
  @name
end

#slugObject

The project’s slug



37
38
39
# File 'lib/ory-client/models/project_metadata.rb', line 37

def slug
  @slug
end

#stateObject

The state of the project. running Running halted Halted deleted Deleted



40
41
42
# File 'lib/ory-client/models/project_metadata.rb', line 40

def state
  @state
end

#subscription_idObject

Returns the value of attribute subscription_id.



42
43
44
# File 'lib/ory-client/models/project_metadata.rb', line 42

def subscription_id
  @subscription_id
end

#subscription_planObject

Returns the value of attribute subscription_plan.



44
45
46
# File 'lib/ory-client/models/project_metadata.rb', line 44

def subscription_plan
  @subscription_plan
end

#updated_atObject

Last Time Project was Updated



47
48
49
# File 'lib/ory-client/models/project_metadata.rb', line 47

def updated_at
  @updated_at
end

#workspaceObject

Returns the value of attribute workspace.



49
50
51
# File 'lib/ory-client/models/project_metadata.rb', line 49

def workspace
  @workspace
end

#workspace_idObject

Returns the value of attribute workspace_id.



51
52
53
# File 'lib/ory-client/models/project_metadata.rb', line 51

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/ory-client/models/project_metadata.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/ory-client/models/project_metadata.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/ory-client/models/project_metadata.rb', line 76

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'environment' => :'environment',
    :'home_region' => :'home_region',
    :'hosts' => :'hosts',
    :'id' => :'id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'state' => :'state',
    :'subscription_id' => :'subscription_id',
    :'subscription_plan' => :'subscription_plan',
    :'updated_at' => :'updated_at',
    :'workspace' => :'workspace',
    :'workspace_id' => :'workspace_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/ory-client/models/project_metadata.rb', line 412

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
128
129
130
# File 'lib/ory-client/models/project_metadata.rb', line 124

def self.openapi_nullable
  Set.new([
    :'subscription_id',
    :'subscription_plan',
    :'workspace_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/ory-client/models/project_metadata.rb', line 105

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'environment' => :'String',
    :'home_region' => :'String',
    :'hosts' => :'Array<String>',
    :'id' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'state' => :'String',
    :'subscription_id' => :'String',
    :'subscription_plan' => :'String',
    :'updated_at' => :'Time',
    :'workspace' => :'Workspace',
    :'workspace_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/ory-client/models/project_metadata.rb', line 379

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      environment == o.environment &&
      home_region == o.home_region &&
      hosts == o.hosts &&
      id == o.id &&
      name == o.name &&
      slug == o.slug &&
      state == o.state &&
      subscription_id == o.subscription_id &&
      subscription_plan == o.subscription_plan &&
      updated_at == o.updated_at &&
      workspace == o.workspace &&
      workspace_id == o.workspace_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


399
400
401
# File 'lib/ory-client/models/project_metadata.rb', line 399

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



405
406
407
# File 'lib/ory-client/models/project_metadata.rb', line 405

def hash
  [created_at, environment, home_region, hosts, id, name, slug, state, subscription_id, subscription_plan, updated_at, workspace, workspace_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ory-client/models/project_metadata.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @environment.nil?
    invalid_properties.push('invalid value for "environment", environment cannot be nil.')
  end

  if @home_region.nil?
    invalid_properties.push('invalid value for "home_region", home_region cannot be nil.')
  end

  if @hosts.nil?
    invalid_properties.push('invalid value for "hosts", hosts cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/ory-client/models/project_metadata.rb', line 434

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/ory-client/models/project_metadata.rb', line 267

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @environment.nil?
  environment_validator = EnumAttributeValidator.new('String', ["prod", "stage", "dev"])
  return false unless environment_validator.valid?(@environment)
  return false if @home_region.nil?
  home_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "us", "global"])
  return false unless home_region_validator.valid?(@home_region)
  return false if @hosts.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["running", "halted", "deleted"])
  return false unless state_validator.valid?(@state)
  return false if @updated_at.nil?
  true
end