Class: OryClient::ProjectOidcConfig
- Inherits:
-
Object
- Object
- OryClient::ProjectOidcConfig
- Defined in:
- lib/ory-client/models/project_oidc_config.rb
Instance Attribute Summary collapse
-
#auth_url ⇒ Object
AuthURL is the authorize url, typically something like: example.org/oauth2/auth Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when `provider` is set to `generic`.
-
#client_id ⇒ Object
ClientID is the application's Client ID.
-
#client_secret ⇒ Object
ClientSecret is the application's secret.
-
#id ⇒ Object
ID is the provider's ID.
-
#issuer_url ⇒ Object
IssuerURL is the OpenID Connect Server URL.
-
#label ⇒ Object
Label represents an optional label which can be used in the UI generation.
-
#mapper_url ⇒ Object
Mapper specifies the JSONNet code snippet which uses the OpenID Connect Provider's data (e.g. GitHub or Google profile information) to hydrate the identity's data.
-
#provider ⇒ Object
Provider is either "generic" for a generic OAuth 2.0 / OpenID Connect Provider or one of: generic google github gitlab microsoft discord slack facebook vk yandex.
-
#requested_claims ⇒ Object
RequestedClaims string encoded json object that specifies claims and optionally their properties which should be included in the id_token or returned from the UserInfo Endpoint.
-
#scope ⇒ Object
Scope specifies optional requested permissions.
-
#string ⇒ Object
Returns the value of attribute string.
-
#tenant ⇒ Object
Tenant is the Azure AD Tenant to use for authentication, and must be set when `provider` is set to `microsoft`.
-
#token_url ⇒ Object
TokenURL is the token url, typically something like: example.org/oauth2/token Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when `provider` is set to `generic`.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProjectOidcConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProjectOidcConfig
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ProjectOidcConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ProjectOidcConfig`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auth_url') self.auth_url = attributes[:'auth_url'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'issuer_url') self.issuer_url = attributes[:'issuer_url'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'mapper_url') self.mapper_url = attributes[:'mapper_url'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'requested_claims') self.requested_claims = attributes[:'requested_claims'] end if attributes.key?(:'scope') if (value = attributes[:'scope']).is_a?(Array) self.scope = value end end if attributes.key?(:'string') self.string = attributes[:'string'] end if attributes.key?(:'tenant') self.tenant = attributes[:'tenant'] end if attributes.key?(:'token_url') self.token_url = attributes[:'token_url'] end end |
Instance Attribute Details
#auth_url ⇒ Object
AuthURL is the authorize url, typically something like: example.org/oauth2/auth Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when `provider` is set to `generic`.
19 20 21 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 19 def auth_url @auth_url end |
#client_id ⇒ Object
ClientID is the application's Client ID.
22 23 24 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 22 def client_id @client_id end |
#client_secret ⇒ Object
ClientSecret is the application's secret.
25 26 27 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 25 def client_secret @client_secret end |
#id ⇒ Object
ID is the provider's ID
28 29 30 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 28 def id @id end |
#issuer_url ⇒ Object
IssuerURL is the OpenID Connect Server URL. You can leave this empty if `provider` is not set to `generic`. If set, neither `auth_url` nor `token_url` are required.
31 32 33 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 31 def issuer_url @issuer_url end |
#label ⇒ Object
Label represents an optional label which can be used in the UI generation.
34 35 36 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 34 def label @label end |
#mapper_url ⇒ Object
Mapper specifies the JSONNet code snippet which uses the OpenID Connect Provider's data (e.g. GitHub or Google profile information) to hydrate the identity's data. It can be either a URL (file://, http(s)://, base64://) or an inline JSONNet code snippet.
37 38 39 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 37 def mapper_url @mapper_url end |
#provider ⇒ Object
Provider is either "generic" for a generic OAuth 2.0 / OpenID Connect Provider or one of: generic google github gitlab microsoft discord slack facebook vk yandex
40 41 42 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 40 def provider @provider end |
#requested_claims ⇒ Object
RequestedClaims string encoded json object that specifies claims and optionally their properties which should be included in the id_token or returned from the UserInfo Endpoint. More information: openid.net/specs/openid-connect-core-1_0.html#ClaimsParameter
43 44 45 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 43 def requested_claims @requested_claims end |
#scope ⇒ Object
Scope specifies optional requested permissions.
46 47 48 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 46 def scope @scope end |
#string ⇒ Object
Returns the value of attribute string.
48 49 50 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 48 def string @string end |
#tenant ⇒ Object
Tenant is the Azure AD Tenant to use for authentication, and must be set when `provider` is set to `microsoft`. Can be either `common`, `organizations`, `consumers` for a multitenant application or a specific tenant like `8eaef023-2b34-4da1-9baa-8bc8c9d6a490` or `contoso.onmicrosoft.com`.
51 52 53 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 51 def tenant @tenant end |
#token_url ⇒ Object
TokenURL is the token url, typically something like: example.org/oauth2/token Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when `provider` is set to `generic`.
54 55 56 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 54 def token_url @token_url end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 57 def self.attribute_map { :'auth_url' => :'auth_url', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'id' => :'id', :'issuer_url' => :'issuer_url', :'label' => :'label', :'mapper_url' => :'mapper_url', :'provider' => :'provider', :'requested_claims' => :'requested_claims', :'scope' => :'scope', :'string' => :'string', :'tenant' => :'tenant', :'token_url' => :'token_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 223 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 81 def self.openapi_types { :'auth_url' => :'String', :'client_id' => :'String', :'client_secret' => :'String', :'id' => :'String', :'issuer_url' => :'String', :'label' => :'String', :'mapper_url' => :'String', :'provider' => :'String', :'requested_claims' => :'Object', :'scope' => :'Array<String>', :'string' => :'String', :'tenant' => :'String', :'token_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && auth_url == o.auth_url && client_id == o.client_id && client_secret == o.client_secret && id == o.id && issuer_url == o.issuer_url && label == o.label && mapper_url == o.mapper_url && provider == o.provider && requested_claims == o.requested_claims && scope == o.scope && string == o.string && tenant == o.tenant && token_url == o.token_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 253 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OryClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 324 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 216 def hash [auth_url, client_id, client_secret, id, issuer_url, label, mapper_url, provider, requested_claims, scope, string, tenant, token_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 177 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
300 301 302 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 300 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
294 295 296 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 294 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 |
# File 'lib/ory-client/models/project_oidc_config.rb', line 184 def valid? true end |