Class: OryClient::ProjectRevision

Inherits:
Object
  • Object
show all
Defined in:
lib/ory-client/models/project_revision.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProjectRevision

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/ory-client/models/project_revision.rb', line 176

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ProjectRevision` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ProjectRevision`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'api_url')
    self.api_url = attributes[:'api_url']
  end

  if attributes.key?(:'application_url')
    self.application_url = attributes[:'application_url']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'default_identity_schema_url')
    self.default_identity_schema_url = attributes[:'default_identity_schema_url']
  end

  if attributes.key?(:'error_ui_url')
    self.error_ui_url = attributes[:'error_ui_url']
  end

  if attributes.key?(:'hosts')
    if (value = attributes[:'hosts']).is_a?(Array)
      self.hosts = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'kratos_config_version')
    self.kratos_config_version = attributes[:'kratos_config_version']
  end

  if attributes.key?(:'kratos_custom_schema_id')
    self.kratos_custom_schema_id = attributes[:'kratos_custom_schema_id']
  end

  if attributes.key?(:'login_ui_url')
    self. = attributes[:'login_ui_url']
  end

  if attributes.key?(:'lookup_secret')
    self.lookup_secret = attributes[:'lookup_secret']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oidc_providers')
    if (value = attributes[:'oidc_providers']).is_a?(Array)
      self.oidc_providers = value
    end
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'recovery')
    self.recovery = attributes[:'recovery']
  end

  if attributes.key?(:'recovery_ui_url')
    self.recovery_ui_url = attributes[:'recovery_ui_url']
  end

  if attributes.key?(:'redirection_config')
    self.redirection_config = attributes[:'redirection_config']
  end

  if attributes.key?(:'registration_ui_url')
    self.registration_ui_url = attributes[:'registration_ui_url']
  end

  if attributes.key?(:'session_after_sign_up')
    self. = attributes[:'session_after_sign_up']
  end

  if attributes.key?(:'session_soft_2fa')
    self.session_soft_2fa = attributes[:'session_soft_2fa']
  end

  if attributes.key?(:'settings_privileged_session_max_age_seconds')
    self.settings_privileged_session_max_age_seconds = attributes[:'settings_privileged_session_max_age_seconds']
  end

  if attributes.key?(:'settings_soft_2fa')
    self.settings_soft_2fa = attributes[:'settings_soft_2fa']
  end

  if attributes.key?(:'settings_ui_url')
    self.settings_ui_url = attributes[:'settings_ui_url']
  end

  if attributes.key?(:'totp')
    self.totp = attributes[:'totp']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'verification')
    self.verification = attributes[:'verification']
  end

  if attributes.key?(:'verification_ui_url')
    self.verification_ui_url = attributes[:'verification_ui_url']
  end

  if attributes.key?(:'webauthn')
    self.webauthn = attributes[:'webauthn']
  end
end

Instance Attribute Details

#api_urlObject

The Project API URL The URL where the Project's APIs are available.



19
20
21
# File 'lib/ory-client/models/project_revision.rb', line 19

def api_url
  @api_url
end

#application_urlObject

Your Application URL The URL where your application is available. Your users will be redirected to this URL when they successfully complete a login, logout, verification, recovery, or registration flow. More fine-grained redirection patterns are available for the individual flows.



22
23
24
# File 'lib/ory-client/models/project_revision.rb', line 22

def application_url
  @application_url
end

#created_atObject

The Project's Revision Creation Date



25
26
27
# File 'lib/ory-client/models/project_revision.rb', line 25

def created_at
  @created_at
end

#default_identity_schema_urlObject

Default Identity Schema URL This represents your Ory Kratos Default Identity Schema. It is your identity's default schema. This allows setting custom fields such as "address", specifying whether you want to log in using email or a username, and more. For more information on this topic, please check out the identity documentation. The value of this field can be either any "https://" URL - for example a file hosted at GitHub, or a `preset://`-prefixed string. Available profiles are: profile://email profile://username



28
29
30
# File 'lib/ory-client/models/project_revision.rb', line 28

def default_identity_schema_url
  @default_identity_schema_url
end

#error_ui_urlObject

Self-Service Error UI URL Sets the UI URL for the error UI. If left empty, this will use Ory's hosted pages.



31
32
33
# File 'lib/ory-client/models/project_revision.rb', line 31

def error_ui_url
  @error_ui_url
end

#hostsObject

Returns the value of attribute hosts.



33
34
35
# File 'lib/ory-client/models/project_revision.rb', line 33

def hosts
  @hosts
end

#idObject

Returns the value of attribute id.



35
36
37
# File 'lib/ory-client/models/project_revision.rb', line 35

def id
  @id
end

#kratos_config_versionObject

The Project's Kratos Config Version



38
39
40
# File 'lib/ory-client/models/project_revision.rb', line 38

def kratos_config_version
  @kratos_config_version
end

#kratos_custom_schema_idObject

Returns the value of attribute kratos_custom_schema_id.



40
41
42
# File 'lib/ory-client/models/project_revision.rb', line 40

def kratos_custom_schema_id
  @kratos_custom_schema_id
end

#login_ui_urlObject

Self-Service Login UI URL Sets the UI URL for the login UI. If left empty, this will use Ory's hosted pages.



43
44
45
# File 'lib/ory-client/models/project_revision.rb', line 43

def 
  @login_ui_url
end

#lookup_secretObject

Returns the value of attribute lookup_secret.



45
46
47
# File 'lib/ory-client/models/project_revision.rb', line 45

def lookup_secret
  @lookup_secret
end

#nameObject

The project's name.



48
49
50
# File 'lib/ory-client/models/project_revision.rb', line 48

def name
  @name
end

#oidc_providersObject

Returns the value of attribute oidc_providers.



50
51
52
# File 'lib/ory-client/models/project_revision.rb', line 50

def oidc_providers
  @oidc_providers
end

#passwordObject

Returns the value of attribute password.



52
53
54
# File 'lib/ory-client/models/project_revision.rb', line 52

def password
  @password
end

#project_idObject

Returns the value of attribute project_id.



54
55
56
# File 'lib/ory-client/models/project_revision.rb', line 54

def project_id
  @project_id
end

#recoveryObject

Returns the value of attribute recovery.



56
57
58
# File 'lib/ory-client/models/project_revision.rb', line 56

def recovery
  @recovery
end

#recovery_ui_urlObject

Self-Service Login UI URL Sets the UI URL for the recovery UI. If left empty, this will use Ory's hosted pages.



59
60
61
# File 'lib/ory-client/models/project_revision.rb', line 59

def recovery_ui_url
  @recovery_ui_url
end

#redirection_configObject

Returns the value of attribute redirection_config.



61
62
63
# File 'lib/ory-client/models/project_revision.rb', line 61

def redirection_config
  @redirection_config
end

#registration_ui_urlObject

Self-Service Login UI URL Sets the UI URL for the registration UI. If left empty, this will use Ory's hosted pages.



64
65
66
# File 'lib/ory-client/models/project_revision.rb', line 64

def registration_ui_url
  @registration_ui_url
end

#session_after_sign_upObject

Issue Session after Sign Up If set to true, users will receive a session after they successfully signed up. Enabling this option allows account enumeration during registration flows. Read more: www.ory.sh/kratos/docs/self-service/flows/user-registration#successful-registration



67
68
69
# File 'lib/ory-client/models/project_revision.rb', line 67

def 
  @session_after_sign_up
end

#session_soft_2faObject

Enable Soft 2FA for Login Sessions



70
71
72
# File 'lib/ory-client/models/project_revision.rb', line 70

def session_soft_2fa
  @session_soft_2fa
end

#settings_privileged_session_max_age_secondsObject

Duration in Seconds of how long a Session is Privileged Defines how long a session is considered privileged in seconds. If the session's authenticated_at is older than the value specified here, the user needs to re-authenticate to perform certain actions (e.g. password change).



73
74
75
# File 'lib/ory-client/models/project_revision.rb', line 73

def settings_privileged_session_max_age_seconds
  @settings_privileged_session_max_age_seconds
end

#settings_soft_2faObject

Enable Soft 2FA for Self-Service Settings Flows



76
77
78
# File 'lib/ory-client/models/project_revision.rb', line 76

def settings_soft_2fa
  @settings_soft_2fa
end

#settings_ui_urlObject

Self-Service Settings UI URL Sets the UI URL for the settings UI. If left empty, this will use Ory's hosted pages.



79
80
81
# File 'lib/ory-client/models/project_revision.rb', line 79

def settings_ui_url
  @settings_ui_url
end

#totpObject

Returns the value of attribute totp.



81
82
83
# File 'lib/ory-client/models/project_revision.rb', line 81

def totp
  @totp
end

#updated_atObject

Last Time Project's Revision was Updated



84
85
86
# File 'lib/ory-client/models/project_revision.rb', line 84

def updated_at
  @updated_at
end

#verificationObject

Returns the value of attribute verification.



86
87
88
# File 'lib/ory-client/models/project_revision.rb', line 86

def verification
  @verification
end

#verification_ui_urlObject

Self-Service Login UI URL Sets the UI URL for the verification UI. If left empty, this will use Ory's hosted pages.



89
90
91
# File 'lib/ory-client/models/project_revision.rb', line 89

def verification_ui_url
  @verification_ui_url
end

#webauthnObject

Returns the value of attribute webauthn.



91
92
93
# File 'lib/ory-client/models/project_revision.rb', line 91

def webauthn
  @webauthn
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



129
130
131
# File 'lib/ory-client/models/project_revision.rb', line 129

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/ory-client/models/project_revision.rb', line 94

def self.attribute_map
  {
    :'api_url' => :'api_url',
    :'application_url' => :'application_url',
    :'created_at' => :'created_at',
    :'default_identity_schema_url' => :'default_identity_schema_url',
    :'error_ui_url' => :'error_ui_url',
    :'hosts' => :'hosts',
    :'id' => :'id',
    :'kratos_config_version' => :'kratos_config_version',
    :'kratos_custom_schema_id' => :'kratos_custom_schema_id',
    :'login_ui_url' => :'login_ui_url',
    :'lookup_secret' => :'lookup_secret',
    :'name' => :'name',
    :'oidc_providers' => :'oidc_providers',
    :'password' => :'password',
    :'project_id' => :'project_id',
    :'recovery' => :'recovery',
    :'recovery_ui_url' => :'recovery_ui_url',
    :'redirection_config' => :'redirection_config',
    :'registration_ui_url' => :'registration_ui_url',
    :'session_after_sign_up' => :'session_after_sign_up',
    :'session_soft_2fa' => :'session_soft_2fa',
    :'settings_privileged_session_max_age_seconds' => :'settings_privileged_session_max_age_seconds',
    :'settings_soft_2fa' => :'settings_soft_2fa',
    :'settings_ui_url' => :'settings_ui_url',
    :'totp' => :'totp',
    :'updated_at' => :'updated_at',
    :'verification' => :'verification',
    :'verification_ui_url' => :'verification_ui_url',
    :'webauthn' => :'webauthn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



424
425
426
# File 'lib/ory-client/models/project_revision.rb', line 424

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



169
170
171
172
# File 'lib/ory-client/models/project_revision.rb', line 169

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ory-client/models/project_revision.rb', line 134

def self.openapi_types
  {
    :'api_url' => :'String',
    :'application_url' => :'String',
    :'created_at' => :'Time',
    :'default_identity_schema_url' => :'String',
    :'error_ui_url' => :'String',
    :'hosts' => :'Array<String>',
    :'id' => :'String',
    :'kratos_config_version' => :'String',
    :'kratos_custom_schema_id' => :'String',
    :'login_ui_url' => :'String',
    :'lookup_secret' => :'ProjectLookupSecretConfig',
    :'name' => :'String',
    :'oidc_providers' => :'Array<ProjectOidcConfig>',
    :'password' => :'ProjectPasswordConfig',
    :'project_id' => :'String',
    :'recovery' => :'ProjectRecoveryConfig',
    :'recovery_ui_url' => :'String',
    :'redirection_config' => :'RedirectionConfig',
    :'registration_ui_url' => :'String',
    :'session_after_sign_up' => :'Boolean',
    :'session_soft_2fa' => :'Boolean',
    :'settings_privileged_session_max_age_seconds' => :'Integer',
    :'settings_soft_2fa' => :'Boolean',
    :'settings_ui_url' => :'String',
    :'totp' => :'ProjectTotpConfig',
    :'updated_at' => :'Time',
    :'verification' => :'ProjectVerificationConfig',
    :'verification_ui_url' => :'String',
    :'webauthn' => :'ProjectWebAuthnConfig'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/ory-client/models/project_revision.rb', line 375

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      api_url == o.api_url &&
      application_url == o.application_url &&
      created_at == o.created_at &&
      default_identity_schema_url == o.default_identity_schema_url &&
      error_ui_url == o.error_ui_url &&
      hosts == o.hosts &&
      id == o.id &&
      kratos_config_version == o.kratos_config_version &&
      kratos_custom_schema_id == o.kratos_custom_schema_id &&
       == o. &&
      lookup_secret == o.lookup_secret &&
      name == o.name &&
      oidc_providers == o.oidc_providers &&
      password == o.password &&
      project_id == o.project_id &&
      recovery == o.recovery &&
      recovery_ui_url == o.recovery_ui_url &&
      redirection_config == o.redirection_config &&
      registration_ui_url == o.registration_ui_url &&
       == o. &&
      session_soft_2fa == o.session_soft_2fa &&
      settings_privileged_session_max_age_seconds == o.settings_privileged_session_max_age_seconds &&
      settings_soft_2fa == o.settings_soft_2fa &&
      settings_ui_url == o.settings_ui_url &&
      totp == o.totp &&
      updated_at == o.updated_at &&
      verification == o.verification &&
      verification_ui_url == o.verification_ui_url &&
      webauthn == o.webauthn
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/ory-client/models/project_revision.rb', line 454

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OryClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/ory-client/models/project_revision.rb', line 525

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/ory-client/models/project_revision.rb', line 431

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


411
412
413
# File 'lib/ory-client/models/project_revision.rb', line 411

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



417
418
419
# File 'lib/ory-client/models/project_revision.rb', line 417

def hash
  [api_url, application_url, created_at, default_identity_schema_url, error_ui_url, hosts, id, kratos_config_version, kratos_custom_schema_id, , lookup_secret, name, oidc_providers, password, project_id, recovery, recovery_ui_url, redirection_config, registration_ui_url, , session_soft_2fa, settings_privileged_session_max_age_seconds, settings_soft_2fa, settings_ui_url, totp, updated_at, verification, verification_ui_url, webauthn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/ory-client/models/project_revision.rb', line 312

def list_invalid_properties
  invalid_properties = Array.new
  if @api_url.nil?
    invalid_properties.push('invalid value for "api_url", api_url cannot be nil.')
  end

  if @application_url.nil?
    invalid_properties.push('invalid value for "application_url", application_url cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @default_identity_schema_url.nil?
    invalid_properties.push('invalid value for "default_identity_schema_url", default_identity_schema_url cannot be nil.')
  end

  if @hosts.nil?
    invalid_properties.push('invalid value for "hosts", hosts cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if @session_after_sign_up.nil?
    invalid_properties.push('invalid value for "session_after_sign_up", session_after_sign_up cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



501
502
503
# File 'lib/ory-client/models/project_revision.rb', line 501

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



507
508
509
510
511
512
513
514
515
516
517
518
519
# File 'lib/ory-client/models/project_revision.rb', line 507

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



495
496
497
# File 'lib/ory-client/models/project_revision.rb', line 495

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/ory-client/models/project_revision.rb', line 359

def valid?
  return false if @api_url.nil?
  return false if @application_url.nil?
  return false if @created_at.nil?
  return false if @default_identity_schema_url.nil?
  return false if @hosts.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if @project_id.nil?
  return false if @session_after_sign_up.nil?
  return false if @updated_at.nil?
  true
end