Class: OryClient::RecoveryFlow

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/recovery_flow.rb

Overview

This request is used when an identity wants to recover their account. We recommend reading the Account Recovery Documentation

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RecoveryFlow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/ory-client/models/recovery_flow.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::RecoveryFlow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::RecoveryFlow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'continue_with')
    if (value = attributes[:'continue_with']).is_a?(Array)
      self.continue_with = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'issued_at')
    self.issued_at = attributes[:'issued_at']
  else
    self.issued_at = nil
  end

  if attributes.key?(:'request_url')
    self.request_url = attributes[:'request_url']
  else
    self.request_url = nil
  end

  if attributes.key?(:'return_to')
    self.return_to = attributes[:'return_to']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'transient_payload')
    self.transient_payload = attributes[:'transient_payload']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'ui')
    self.ui = attributes[:'ui']
  else
    self.ui = nil
  end
end

Instance Attribute Details

#active ⇒ Object

Active, if set, contains the recovery method that is being used. It is initially not set.



20
21
22
# File 'lib/ory-client/models/recovery_flow.rb', line 20

def active
  @active
end

#continue_with ⇒ Object

Contains possible actions that could follow this flow



23
24
25
# File 'lib/ory-client/models/recovery_flow.rb', line 23

def continue_with
  @continue_with
end

#expires_at ⇒ Object

ExpiresAt is the time (UTC) when the request expires. If the user still wishes to update the setting, a new request has to be initiated.



26
27
28
# File 'lib/ory-client/models/recovery_flow.rb', line 26

def expires_at
  @expires_at
end

#id ⇒ Object

ID represents the request's unique ID. When performing the recovery flow, this represents the id in the recovery ui's query parameter: http://<selfservice.flows.recovery.ui_url>?request=



29
30
31
# File 'lib/ory-client/models/recovery_flow.rb', line 29

def id
  @id
end

#issued_at ⇒ Object

IssuedAt is the time (UTC) when the request occurred.



32
33
34
# File 'lib/ory-client/models/recovery_flow.rb', line 32

def issued_at
  @issued_at
end

#request_url ⇒ Object

RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL's path or query for example.



35
36
37
# File 'lib/ory-client/models/recovery_flow.rb', line 35

def request_url
  @request_url
end

#return_to ⇒ Object

ReturnTo contains the requested return_to URL.



38
39
40
# File 'lib/ory-client/models/recovery_flow.rb', line 38

def return_to
  @return_to
end

#state ⇒ Object

Returns the value of attribute state.



40
41
42
# File 'lib/ory-client/models/recovery_flow.rb', line 40

def state
  @state
end

#transient_payload ⇒ Object

TransientPayload is used to pass data from the recovery flow to hooks and email templates



43
44
45
# File 'lib/ory-client/models/recovery_flow.rb', line 43

def transient_payload
  @transient_payload
end

#type ⇒ Object

The flow type can either be api or browser.



46
47
48
# File 'lib/ory-client/models/recovery_flow.rb', line 46

def type
  @type
end

#ui ⇒ Object

Returns the value of attribute ui.



48
49
50
# File 'lib/ory-client/models/recovery_flow.rb', line 48

def ui
  @ui
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



90
91
92
# File 'lib/ory-client/models/recovery_flow.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/ory-client/models/recovery_flow.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/ory-client/models/recovery_flow.rb', line 73

def self.attribute_map
  {
    :'active' => :'active',
    :'continue_with' => :'continue_with',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'issued_at' => :'issued_at',
    :'request_url' => :'request_url',
    :'return_to' => :'return_to',
    :'state' => :'state',
    :'transient_payload' => :'transient_payload',
    :'type' => :'type',
    :'ui' => :'ui'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/ory-client/models/recovery_flow.rb', line 352

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



117
118
119
120
# File 'lib/ory-client/models/recovery_flow.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/ory-client/models/recovery_flow.rb', line 100

def self.openapi_types
  {
    :'active' => :'String',
    :'continue_with' => :'Array<ContinueWith>',
    :'expires_at' => :'Time',
    :'id' => :'String',
    :'issued_at' => :'Time',
    :'request_url' => :'String',
    :'return_to' => :'String',
    :'state' => :'RecoveryFlowState',
    :'transient_payload' => :'Object',
    :'type' => :'String',
    :'ui' => :'UiContainer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ory-client/models/recovery_flow.rb', line 321

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      continue_with == o.continue_with &&
      expires_at == o.expires_at &&
      id == o.id &&
      issued_at == o.issued_at &&
      request_url == o.request_url &&
      return_to == o.return_to &&
      state == o.state &&
      transient_payload == o.transient_payload &&
      type == o.type &&
      ui == o.ui
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/ory-client/models/recovery_flow.rb', line 339

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



345
346
347
# File 'lib/ory-client/models/recovery_flow.rb', line 345

def hash
  [active, continue_with, expires_at, id, issued_at, request_url, return_to, state, transient_payload, type, ui].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/ory-client/models/recovery_flow.rb', line 201

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @issued_at.nil?
    invalid_properties.push('invalid value for "issued_at", issued_at cannot be nil.')
  end

  if @request_url.nil?
    invalid_properties.push('invalid value for "request_url", request_url cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @ui.nil?
    invalid_properties.push('invalid value for "ui", ui cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/ory-client/models/recovery_flow.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



237
238
239
240
241
242
243
244
245
246
247
# File 'lib/ory-client/models/recovery_flow.rb', line 237

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expires_at.nil?
  return false if @id.nil?
  return false if @issued_at.nil?
  return false if @request_url.nil?
  return false if @state.nil?
  return false if @type.nil?
  return false if @ui.nil?
  true
end