Class: OryClient::RecoveryIdentityAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::RecoveryIdentityAddress
- Defined in:
- lib/ory-client/models/recovery_identity_address.rb
Instance Attribute Summary collapse
-
#break_glass_for_organization ⇒ Object
Returns the value of attribute break_glass_for_organization.
-
#created_at ⇒ Object
CreatedAt is a helper struct field for gobuffalo.pop.
-
#id ⇒ Object
Returns the value of attribute id.
-
#updated_at ⇒ Object
UpdatedAt is a helper struct field for gobuffalo.pop.
-
#value ⇒ Object
Returns the value of attribute value.
-
#via ⇒ Object
Returns the value of attribute via.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecoveryIdentityAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RecoveryIdentityAddress
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::RecoveryIdentityAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::RecoveryIdentityAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'break_glass_for_organization') self.break_glass_for_organization = attributes[:'break_glass_for_organization'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'via') self.via = attributes[:'via'] else self.via = nil end end |
Instance Attribute Details
#break_glass_for_organization ⇒ Object
Returns the value of attribute break_glass_for_organization.
18 19 20 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 18 def break_glass_for_organization @break_glass_for_organization end |
#created_at ⇒ Object
CreatedAt is a helper struct field for gobuffalo.pop.
21 22 23 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 21 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
23 24 25 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 23 def id @id end |
#updated_at ⇒ Object
UpdatedAt is a helper struct field for gobuffalo.pop.
26 27 28 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 26 def updated_at @updated_at end |
#value ⇒ Object
Returns the value of attribute value.
28 29 30 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 28 def value @value end |
#via ⇒ Object
Returns the value of attribute via.
30 31 32 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 30 def via @via end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 33 def self.attribute_map { :'break_glass_for_organization' => :'break_glass_for_organization', :'created_at' => :'created_at', :'id' => :'id', :'updated_at' => :'updated_at', :'value' => :'value', :'via' => :'via' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 67 def self.openapi_nullable Set.new([ :'break_glass_for_organization', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 55 def self.openapi_types { :'break_glass_for_organization' => :'String', :'created_at' => :'Time', :'id' => :'String', :'updated_at' => :'Time', :'value' => :'String', :'via' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 165 def ==(o) return true if self.equal?(o) self.class == o.class && break_glass_for_organization == o.break_glass_for_organization && created_at == o.created_at && id == o.id && updated_at == o.updated_at && value == o.value && via == o.via end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 184 def hash [break_glass_for_organization, created_at, id, updated_at, value, via].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @via.nil? invalid_properties.push('invalid value for "via", via cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 |
# File 'lib/ory-client/models/recovery_identity_address.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @value.nil? return false if @via.nil? true end |