Class: OryClient::RegistrationFlow

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/registration_flow.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RegistrationFlow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/ory-client/models/registration_flow.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::RegistrationFlow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::RegistrationFlow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'identity_schema')
    self.identity_schema = attributes[:'identity_schema']
  end

  if attributes.key?(:'issued_at')
    self.issued_at = attributes[:'issued_at']
  else
    self.issued_at = nil
  end

  if attributes.key?(:'oauth2_login_challenge')
    self. = attributes[:'oauth2_login_challenge']
  end

  if attributes.key?(:'oauth2_login_request')
    self. = attributes[:'oauth2_login_request']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'request_url')
    self.request_url = attributes[:'request_url']
  else
    self.request_url = nil
  end

  if attributes.key?(:'return_to')
    self.return_to = attributes[:'return_to']
  end

  if attributes.key?(:'session_token_exchange_code')
    self.session_token_exchange_code = attributes[:'session_token_exchange_code']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'transient_payload')
    self.transient_payload = attributes[:'transient_payload']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'ui')
    self.ui = attributes[:'ui']
  else
    self.ui = nil
  end
end

Instance Attribute Details

#active ⇒ Object

Active, if set, contains the registration method that is being used. It is initially not set. password CredentialsTypePassword oidc CredentialsTypeOIDC totp CredentialsTypeTOTP lookup_secret CredentialsTypeLookup webauthn CredentialsTypeWebAuthn code CredentialsTypeCodeAuth passkey CredentialsTypePasskey profile CredentialsTypeProfile saml CredentialsTypeSAML deviceauthn CredentialsTypeDeviceAuthn identifier_first CredentialsTypeIdentifierFirst link_recovery CredentialsTypeRecoveryLink is a special credential type linked to the link strategy (recovery flow). It is not used within the credentials object itself. code_recovery CredentialsTypeRecoveryCode



19
20
21
# File 'lib/ory-client/models/registration_flow.rb', line 19

def active
  @active
end

#expires_at ⇒ Object

ExpiresAt is the time (UTC) when the flow expires. If the user still wishes to log in, a new flow has to be initiated.



22
23
24
# File 'lib/ory-client/models/registration_flow.rb', line 22

def expires_at
  @expires_at
end

#id ⇒ Object

ID represents the flow's unique ID. When performing the registration flow, this represents the id in the registration ui's query parameter: http://<selfservice.flows.registration.ui_url>/?flow=



25
26
27
# File 'lib/ory-client/models/registration_flow.rb', line 25

def id
  @id
end

#identity_schema ⇒ Object

IdentitySchema optionally holds the ID of the identity schema that is used for this flow. This value can be set by the user when creating the flow and should be retained when the flow is saved or converted to another flow.



28
29
30
# File 'lib/ory-client/models/registration_flow.rb', line 28

def identity_schema
  @identity_schema
end

#issued_at ⇒ Object

IssuedAt is the time (UTC) when the flow occurred.



31
32
33
# File 'lib/ory-client/models/registration_flow.rb', line 31

def issued_at
  @issued_at
end

#oauth2_login_challenge ⇒ Object

Ory OAuth 2.0 Login Challenge. This value is set using the login_challenge query parameter of the registration and login endpoints. If set will cooperate with Ory OAuth2 and OpenID to act as an OAuth2 server / OpenID Provider.



34
35
36
# File 'lib/ory-client/models/registration_flow.rb', line 34

def 
  @oauth2_login_challenge
end

#oauth2_login_request ⇒ Object

Returns the value of attribute oauth2_login_request.



36
37
38
# File 'lib/ory-client/models/registration_flow.rb', line 36

def 
  @oauth2_login_request
end

#organization_id ⇒ Object

Returns the value of attribute organization_id.



38
39
40
# File 'lib/ory-client/models/registration_flow.rb', line 38

def organization_id
  @organization_id
end

#request_url ⇒ Object

RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL's path or query for example.



41
42
43
# File 'lib/ory-client/models/registration_flow.rb', line 41

def request_url
  @request_url
end

#return_to ⇒ Object

ReturnTo contains the requested return_to URL.



44
45
46
# File 'lib/ory-client/models/registration_flow.rb', line 44

def return_to
  @return_to
end

#session_token_exchange_code ⇒ Object

SessionTokenExchangeCode holds the secret code that the client can use to retrieve a session token after the flow has been completed. This is only set if the client has requested a session token exchange code, and if the flow is of type "api", and only on creating the flow.



47
48
49
# File 'lib/ory-client/models/registration_flow.rb', line 47

def session_token_exchange_code
  @session_token_exchange_code
end

#state ⇒ Object

Returns the value of attribute state.



49
50
51
# File 'lib/ory-client/models/registration_flow.rb', line 49

def state
  @state
end

#transient_payload ⇒ Object

TransientPayload is used to pass data from the registration to a webhook



52
53
54
# File 'lib/ory-client/models/registration_flow.rb', line 52

def transient_payload
  @transient_payload
end

#type ⇒ Object

The flow type can either be api or browser.



55
56
57
# File 'lib/ory-client/models/registration_flow.rb', line 55

def type
  @type
end

#ui ⇒ Object

Returns the value of attribute ui.



57
58
59
# File 'lib/ory-client/models/registration_flow.rb', line 57

def ui
  @ui
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



103
104
105
# File 'lib/ory-client/models/registration_flow.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/ory-client/models/registration_flow.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/ory-client/models/registration_flow.rb', line 82

def self.attribute_map
  {
    :'active' => :'active',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'identity_schema' => :'identity_schema',
    :'issued_at' => :'issued_at',
    :'oauth2_login_challenge' => :'oauth2_login_challenge',
    :'oauth2_login_request' => :'oauth2_login_request',
    :'organization_id' => :'organization_id',
    :'request_url' => :'request_url',
    :'return_to' => :'return_to',
    :'session_token_exchange_code' => :'session_token_exchange_code',
    :'state' => :'state',
    :'transient_payload' => :'transient_payload',
    :'type' => :'type',
    :'ui' => :'ui'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/ory-client/models/registration_flow.rb', line 400

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



134
135
136
137
138
# File 'lib/ory-client/models/registration_flow.rb', line 134

def self.openapi_nullable
  Set.new([
    :'organization_id',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/ory-client/models/registration_flow.rb', line 113

def self.openapi_types
  {
    :'active' => :'String',
    :'expires_at' => :'Time',
    :'id' => :'String',
    :'identity_schema' => :'String',
    :'issued_at' => :'Time',
    :'oauth2_login_challenge' => :'String',
    :'oauth2_login_request' => :'OAuth2LoginRequest',
    :'organization_id' => :'String',
    :'request_url' => :'String',
    :'return_to' => :'String',
    :'session_token_exchange_code' => :'String',
    :'state' => :'RegistrationFlowState',
    :'transient_payload' => :'Object',
    :'type' => :'String',
    :'ui' => :'UiContainer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/ory-client/models/registration_flow.rb', line 365

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      expires_at == o.expires_at &&
      id == o.id &&
      identity_schema == o.identity_schema &&
      issued_at == o.issued_at &&
       == o. &&
       == o. &&
      organization_id == o.organization_id &&
      request_url == o.request_url &&
      return_to == o.return_to &&
      session_token_exchange_code == o.session_token_exchange_code &&
      state == o.state &&
      transient_payload == o.transient_payload &&
      type == o.type &&
      ui == o.ui
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


387
388
389
# File 'lib/ory-client/models/registration_flow.rb', line 387

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



393
394
395
# File 'lib/ory-client/models/registration_flow.rb', line 393

def hash
  [active, expires_at, id, identity_schema, issued_at, , , organization_id, request_url, return_to, session_token_exchange_code, state, transient_payload, type, ui].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/ory-client/models/registration_flow.rb', line 233

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @issued_at.nil?
    invalid_properties.push('invalid value for "issued_at", issued_at cannot be nil.')
  end

  if @request_url.nil?
    invalid_properties.push('invalid value for "request_url", request_url cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @ui.nil?
    invalid_properties.push('invalid value for "ui", ui cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/ory-client/models/registration_flow.rb', line 422

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/ory-client/models/registration_flow.rb', line 269

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  active_validator = EnumAttributeValidator.new('String', ["password", "oidc", "totp", "lookup_secret", "webauthn", "code", "passkey", "profile", "saml", "deviceauthn", "identifier_first", "link_recovery", "code_recovery"])
  return false unless active_validator.valid?(@active)
  return false if @expires_at.nil?
  return false if @id.nil?
  return false if @issued_at.nil?
  return false if @request_url.nil?
  return false if @state.nil?
  return false if @type.nil?
  return false if @ui.nil?
  true
end