Class: OryClient::SessionAuthenticationMethod

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/session_authentication_method.rb

Overview

A singular authenticator used during authentication / login.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SessionAuthenticationMethod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/ory-client/models/session_authentication_method.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::SessionAuthenticationMethod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::SessionAuthenticationMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aal')
    self.aal = attributes[:'aal']
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'upstream_acr')
    self.upstream_acr = attributes[:'upstream_acr']
  end

  if attributes.key?(:'upstream_amr')
    if (value = attributes[:'upstream_amr']).is_a?(Array)
      self.upstream_amr = value
    end
  end
end

Instance Attribute Details

#aal ⇒ Object

Returns the value of attribute aal.



19
20
21
# File 'lib/ory-client/models/session_authentication_method.rb', line 19

def aal
  @aal
end

#channel ⇒ Object

Returns the value of attribute channel.



21
22
23
# File 'lib/ory-client/models/session_authentication_method.rb', line 21

def channel
  @channel
end

#completed_at ⇒ Object

When the authentication challenge was completed.



24
25
26
# File 'lib/ory-client/models/session_authentication_method.rb', line 24

def completed_at
  @completed_at
end

#method ⇒ Object

The method used in this authenticator. password CredentialsTypePassword oidc CredentialsTypeOIDC totp CredentialsTypeTOTP lookup_secret CredentialsTypeLookup webauthn CredentialsTypeWebAuthn code CredentialsTypeCodeAuth passkey CredentialsTypePasskey profile CredentialsTypeProfile saml CredentialsTypeSAML deviceauthn CredentialsTypeDeviceAuthn identifier_first CredentialsTypeIdentifierFirst link_recovery CredentialsTypeRecoveryLink is a special credential type linked to the link strategy (recovery flow). It is not used within the credentials object itself. code_recovery CredentialsTypeRecoveryCode



27
28
29
# File 'lib/ory-client/models/session_authentication_method.rb', line 27

def method
  @method
end

#organization ⇒ Object

The Organization id used for authentication



30
31
32
# File 'lib/ory-client/models/session_authentication_method.rb', line 30

def organization
  @organization
end

#provider ⇒ Object

OIDC or SAML provider id used for authentication



33
34
35
# File 'lib/ory-client/models/session_authentication_method.rb', line 33

def provider
  @provider
end

#upstream_acr ⇒ Object

UpstreamACR is the acr claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an acr claim.



36
37
38
# File 'lib/ory-client/models/session_authentication_method.rb', line 36

def upstream_acr
  @upstream_acr
end

#upstream_amr ⇒ Object

UpstreamAMR is the amr claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an amr claim.



39
40
41
# File 'lib/ory-client/models/session_authentication_method.rb', line 39

def upstream_amr
  @upstream_amr
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



78
79
80
# File 'lib/ory-client/models/session_authentication_method.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/ory-client/models/session_authentication_method.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/ory-client/models/session_authentication_method.rb', line 64

def self.attribute_map
  {
    :'aal' => :'aal',
    :'channel' => :'channel',
    :'completed_at' => :'completed_at',
    :'method' => :'method',
    :'organization' => :'organization',
    :'provider' => :'provider',
    :'upstream_acr' => :'upstream_acr',
    :'upstream_amr' => :'upstream_amr'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/ory-client/models/session_authentication_method.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



102
103
104
105
# File 'lib/ory-client/models/session_authentication_method.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/ory-client/models/session_authentication_method.rb', line 88

def self.openapi_types
  {
    :'aal' => :'AuthenticatorAssuranceLevel',
    :'channel' => :'String',
    :'completed_at' => :'Time',
    :'method' => :'String',
    :'organization' => :'String',
    :'provider' => :'String',
    :'upstream_acr' => :'String',
    :'upstream_amr' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/ory-client/models/session_authentication_method.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aal == o.aal &&
      channel == o.channel &&
      completed_at == o.completed_at &&
      method == o.method &&
      organization == o.organization &&
      provider == o.provider &&
      upstream_acr == o.upstream_acr &&
      upstream_amr == o.upstream_amr
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/ory-client/models/session_authentication_method.rb', line 202

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



208
209
210
# File 'lib/ory-client/models/session_authentication_method.rb', line 208

def hash
  [aal, channel, completed_at, method, organization, provider, upstream_acr, upstream_amr].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
# File 'lib/ory-client/models/session_authentication_method.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/ory-client/models/session_authentication_method.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



168
169
170
171
172
173
# File 'lib/ory-client/models/session_authentication_method.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  method_validator = EnumAttributeValidator.new('String', ["password", "oidc", "totp", "lookup_secret", "webauthn", "code", "passkey", "profile", "saml", "deviceauthn", "identifier_first", "link_recovery", "code_recovery"])
  return false unless method_validator.valid?(@method)
  true
end