Class: OryClient::SetOrganizationFromOnboardingPortalLinkBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::SetOrganizationFromOnboardingPortalLinkBody
- Defined in:
- lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb
Instance Attribute Summary collapse
-
#kratos_selfservice_methods_oidc_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_oidc_config_providers.
-
#kratos_selfservice_methods_saml_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_saml_config_providers.
-
#revision_id ⇒ Object
Returns the value of attribute revision_id.
-
#scim_clients ⇒ Object
Returns the value of attribute scim_clients.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SetOrganizationFromOnboardingPortalLinkBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SetOrganizationFromOnboardingPortalLinkBody
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::SetOrganizationFromOnboardingPortalLinkBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::SetOrganizationFromOnboardingPortalLinkBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'kratos_selfservice_methods_oidc_config_providers') if (value = attributes[:'kratos_selfservice_methods_oidc_config_providers']).is_a?(Array) self.kratos_selfservice_methods_oidc_config_providers = value end end if attributes.key?(:'kratos_selfservice_methods_saml_config_providers') if (value = attributes[:'kratos_selfservice_methods_saml_config_providers']).is_a?(Array) self.kratos_selfservice_methods_saml_config_providers = value end end if attributes.key?(:'revision_id') self.revision_id = attributes[:'revision_id'] else self.revision_id = nil end if attributes.key?(:'scim_clients') if (value = attributes[:'scim_clients']).is_a?(Array) self.scim_clients = value end end end |
Instance Attribute Details
#kratos_selfservice_methods_oidc_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_oidc_config_providers.
18 19 20 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 18 def kratos_selfservice_methods_oidc_config_providers @kratos_selfservice_methods_oidc_config_providers end |
#kratos_selfservice_methods_saml_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_saml_config_providers.
20 21 22 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 20 def kratos_selfservice_methods_saml_config_providers @kratos_selfservice_methods_saml_config_providers end |
#revision_id ⇒ Object
Returns the value of attribute revision_id.
22 23 24 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 22 def revision_id @revision_id end |
#scim_clients ⇒ Object
Returns the value of attribute scim_clients.
24 25 26 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 24 def scim_clients @scim_clients end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 27 def self.attribute_map { :'kratos_selfservice_methods_oidc_config_providers' => :'kratos_selfservice_methods_oidc_config_providers', :'kratos_selfservice_methods_saml_config_providers' => :'kratos_selfservice_methods_saml_config_providers', :'revision_id' => :'revision_id', :'scim_clients' => :'scim_clients' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 47 def self.openapi_types { :'kratos_selfservice_methods_oidc_config_providers' => :'Array<NormalizedProjectRevisionThirdPartyProvider>', :'kratos_selfservice_methods_saml_config_providers' => :'Array<NormalizedProjectRevisionSAMLProvider>', :'revision_id' => :'String', :'scim_clients' => :'Array<NormalizedProjectRevisionScimClient>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && kratos_selfservice_methods_oidc_config_providers == o.kratos_selfservice_methods_oidc_config_providers && kratos_selfservice_methods_saml_config_providers == o.kratos_selfservice_methods_saml_config_providers && revision_id == o.revision_id && scim_clients == o.scim_clients end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 152 def hash [kratos_selfservice_methods_oidc_config_providers, kratos_selfservice_methods_saml_config_providers, revision_id, scim_clients].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @revision_id.nil? invalid_properties.push('invalid value for "revision_id", revision_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 |
# File 'lib/ory-client/models/set_organization_from_onboarding_portal_link_body.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @revision_id.nil? true end |