Class: OryClient::SyntaxApi
- Inherits:
-
Object
- Object
- OryClient::SyntaxApi
- Defined in:
- lib/ory-client/api/syntax_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#check_opl_syntax(body, opts = {}) ⇒ PostCheckOplSyntaxResponse
Check the syntax of an OPL file The OPL file is expected in the body of the request.
-
#check_opl_syntax_with_http_info(body, opts = {}) ⇒ Array<(PostCheckOplSyntaxResponse, Integer, Hash)>
Check the syntax of an OPL file The OPL file is expected in the body of the request.
-
#initialize(api_client = ApiClient.default) ⇒ SyntaxApi
constructor
A new instance of SyntaxApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ory-client/api/syntax_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#check_opl_syntax(body, opts = {}) ⇒ PostCheckOplSyntaxResponse
Check the syntax of an OPL file The OPL file is expected in the body of the request.
27 28 29 30 |
# File 'lib/ory-client/api/syntax_api.rb', line 27 def check_opl_syntax(body, opts = {}) data, _status_code, _headers = check_opl_syntax_with_http_info(body, opts) data end |
#check_opl_syntax_with_http_info(body, opts = {}) ⇒ Array<(PostCheckOplSyntaxResponse, Integer, Hash)>
Check the syntax of an OPL file The OPL file is expected in the body of the request.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/ory-client/api/syntax_api.rb', line 37 def check_opl_syntax_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SyntaxApi.check_opl_syntax ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SyntaxApi.check_opl_syntax" end # resource path local_var_path = '/opl/syntax/check' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['text/plain']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PostCheckOplSyntaxResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"SyntaxApi.check_opl_syntax", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SyntaxApi#check_opl_syntax\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |