Class: OryClient::TrustOAuth2JwtGrantIssuer

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb

Overview

Trust OAuth2 JWT Bearer Grant Type Issuer Request Body

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TrustOAuth2JwtGrantIssuer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::TrustOAuth2JwtGrantIssuer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::TrustOAuth2JwtGrantIssuer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_any_subject')
    self.allow_any_subject = attributes[:'allow_any_subject']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  else
    self.issuer = nil
  end

  if attributes.key?(:'jwk')
    self.jwk = attributes[:'jwk']
  else
    self.jwk = nil
  end

  if attributes.key?(:'scope')
    if (value = attributes[:'scope']).is_a?(Array)
      self.scope = value
    end
  else
    self.scope = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end
end

Instance Attribute Details

#allow_any_subjectObject

The "allow_any_subject" indicates that the issuer is allowed to have any principal as the subject of the JWT.



20
21
22
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 20

def allow_any_subject
  @allow_any_subject
end

#expires_atObject

The "expires_at" indicates, when grant will expire, so we will reject assertion from "issuer" targeting "subject".



23
24
25
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 23

def expires_at
  @expires_at
end

#issuerObject

The "issuer" identifies the principal that issued the JWT assertion (same as "iss" claim in JWT).



26
27
28
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 26

def issuer
  @issuer
end

#jwkObject

Returns the value of attribute jwk.



28
29
30
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 28

def jwk
  @jwk
end

#scopeObject

The "scope" contains list of scope values (as described in Section 3.3 of OAuth 2.0 [RFC6749])



31
32
33
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 31

def scope
  @scope
end

#subjectObject

The "subject" identifies the principal that is the subject of the JWT.



34
35
36
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 34

def subject
  @subject
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 37

def self.attribute_map
  {
    :'allow_any_subject' => :'allow_any_subject',
    :'expires_at' => :'expires_at',
    :'issuer' => :'issuer',
    :'jwk' => :'jwk',
    :'scope' => :'scope',
    :'subject' => :'subject'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 230

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 59

def self.openapi_types
  {
    :'allow_any_subject' => :'Boolean',
    :'expires_at' => :'Time',
    :'issuer' => :'String',
    :'jwk' => :'JsonWebKey',
    :'scope' => :'Array<String>',
    :'subject' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_any_subject == o.allow_any_subject &&
      expires_at == o.expires_at &&
      issuer == o.issuer &&
      jwk == o.jwk &&
      scope == o.scope &&
      subject == o.subject
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 223

def hash
  [allow_any_subject, expires_at, issuer, jwk, scope, subject].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @issuer.nil?
    invalid_properties.push('invalid value for "issuer", issuer cannot be nil.')
  end

  if @jwk.nil?
    invalid_properties.push('invalid value for "jwk", jwk cannot be nil.')
  end

  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
# File 'lib/ory-client/models/trust_o_auth2_jwt_grant_issuer.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expires_at.nil?
  return false if @issuer.nil?
  return false if @jwk.nil?
  return false if @scope.nil?
  true
end