Class: OryClient::UpdateIdentityBody

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/update_identity_body.rb

Overview

Update Identity Body

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateIdentityBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ory-client/models/update_identity_body.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateIdentityBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateIdentityBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'credentials')
    self.credentials = attributes[:'credentials']
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'metadata_admin')
    self. = attributes[:'metadata_admin']
  end

  if attributes.key?(:'metadata_public')
    self. = attributes[:'metadata_public']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'schema_id')
    self.schema_id = attributes[:'schema_id']
  else
    self.schema_id = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'traits')
    self.traits = attributes[:'traits']
  else
    self.traits = nil
  end
end

Instance Attribute Details

#credentialsObject

Returns the value of attribute credentials.



19
20
21
# File 'lib/ory-client/models/update_identity_body.rb', line 19

def credentials
  @credentials
end

#external_idObject

ExternalID is an optional external ID of the identity. This is used to link the identity to an external system. If set, the external ID must be unique across all identities.



22
23
24
# File 'lib/ory-client/models/update_identity_body.rb', line 22

def external_id
  @external_id
end

#metadata_adminObject

Store metadata about the user which is only accessible through admin APIs such as ‘GET /admin/identities/<id>`.



25
26
27
# File 'lib/ory-client/models/update_identity_body.rb', line 25

def 
  @metadata_admin
end

#metadata_publicObject

Store metadata about the identity which the identity itself can see when calling for example the session endpoint. Do not store sensitive information (e.g. credit score) about the identity in this field.



28
29
30
# File 'lib/ory-client/models/update_identity_body.rb', line 28

def 
  @metadata_public
end

#regionObject

Region is the Ory Network region this identity is homed in. Optional; omit to leave the current region unchanged. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global



31
32
33
# File 'lib/ory-client/models/update_identity_body.rb', line 31

def region
  @region
end

#schema_idObject

SchemaID is the ID of the JSON Schema to be used for validating the identity’s traits. If set will update the Identity’s SchemaID.



34
35
36
# File 'lib/ory-client/models/update_identity_body.rb', line 34

def schema_id
  @schema_id
end

#stateObject

State is the identity’s state. active StateActive inactive StateInactive



37
38
39
# File 'lib/ory-client/models/update_identity_body.rb', line 37

def state
  @state
end

#traitsObject

Traits represent an identity’s traits. The identity is able to create, modify, and delete traits in a self-service manner. The input will always be validated against the JSON Schema defined in ‘schema_id`.



40
41
42
# File 'lib/ory-client/models/update_identity_body.rb', line 40

def traits
  @traits
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/ory-client/models/update_identity_body.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/ory-client/models/update_identity_body.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/ory-client/models/update_identity_body.rb', line 65

def self.attribute_map
  {
    :'credentials' => :'credentials',
    :'external_id' => :'external_id',
    :'metadata_admin' => :'metadata_admin',
    :'metadata_public' => :'metadata_public',
    :'region' => :'region',
    :'schema_id' => :'schema_id',
    :'state' => :'state',
    :'traits' => :'traits'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/ory-client/models/update_identity_body.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
108
# File 'lib/ory-client/models/update_identity_body.rb', line 103

def self.openapi_nullable
  Set.new([
    :'metadata_admin',
    :'metadata_public',
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/ory-client/models/update_identity_body.rb', line 89

def self.openapi_types
  {
    :'credentials' => :'IdentityWithCredentials',
    :'external_id' => :'String',
    :'metadata_admin' => :'Object',
    :'metadata_public' => :'Object',
    :'region' => :'String',
    :'schema_id' => :'String',
    :'state' => :'String',
    :'traits' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/ory-client/models/update_identity_body.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      credentials == o.credentials &&
      external_id == o.external_id &&
       == o. &&
       == o. &&
      region == o.region &&
      schema_id == o.schema_id &&
      state == o.state &&
      traits == o.traits
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/ory-client/models/update_identity_body.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/ory-client/models/update_identity_body.rb', line 262

def hash
  [credentials, external_id, , , region, schema_id, state, traits].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/ory-client/models/update_identity_body.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @schema_id.nil?
    invalid_properties.push('invalid value for "schema_id", schema_id cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @traits.nil?
    invalid_properties.push('invalid value for "traits", traits cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/ory-client/models/update_identity_body.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
194
195
196
197
# File 'lib/ory-client/models/update_identity_body.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"])
  return false unless region_validator.valid?(@region)
  return false if @schema_id.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["active", "inactive"])
  return false unless state_validator.valid?(@state)
  return false if @traits.nil?
  true
end