Class: OryClient::UpdateLoginFlowWithCodeMethod
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::UpdateLoginFlowWithCodeMethod
- Defined in:
- lib/ory-client/models/update_login_flow_with_code_method.rb
Overview
Update Login flow using the code method
Instance Attribute Summary collapse
-
#address ⇒ Object
Address is the address to send the code to, in case that there are multiple addresses.
-
#code ⇒ Object
Code is the 6 digits code sent to the user.
-
#csrf_token ⇒ Object
CSRFToken is the anti-CSRF token.
-
#identifier ⇒ Object
Identifier is the code identifier The identifier requires that the user has already completed the registration or settings with code flow.
-
#method ⇒ Object
Method should be set to \“code\” when logging in using the code strategy.
-
#resend ⇒ Object
Resend is set when the user wants to resend the code.
-
#transient_payload ⇒ Object
Transient data to pass along to any webhooks.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLoginFlowWithCodeMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLoginFlowWithCodeMethod
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateLoginFlowWithCodeMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateLoginFlowWithCodeMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'csrf_token') self.csrf_token = attributes[:'csrf_token'] else self.csrf_token = nil end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end if attributes.key?(:'resend') self.resend = attributes[:'resend'] end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end end |
Instance Attribute Details
#address ⇒ Object
Address is the address to send the code to, in case that there are multiple addresses. This field is only used in two-factor flows and is ineffective for passwordless flows.
20 21 22 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 20 def address @address end |
#code ⇒ Object
Code is the 6 digits code sent to the user
23 24 25 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 23 def code @code end |
#csrf_token ⇒ Object
CSRFToken is the anti-CSRF token
26 27 28 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 26 def csrf_token @csrf_token end |
#identifier ⇒ Object
Identifier is the code identifier The identifier requires that the user has already completed the registration or settings with code flow.
29 30 31 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 29 def identifier @identifier end |
#method ⇒ Object
Method should be set to \“code\” when logging in using the code strategy.
32 33 34 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 32 def method @method end |
#resend ⇒ Object
Resend is set when the user wants to resend the code
35 36 37 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 35 def resend @resend end |
#transient_payload ⇒ Object
Transient data to pass along to any webhooks
38 39 40 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 38 def transient_payload @transient_payload end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 41 def self.attribute_map { :'address' => :'address', :'code' => :'code', :'csrf_token' => :'csrf_token', :'identifier' => :'identifier', :'method' => :'method', :'resend' => :'resend', :'transient_payload' => :'transient_payload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 64 def self.openapi_types { :'address' => :'String', :'code' => :'String', :'csrf_token' => :'String', :'identifier' => :'String', :'method' => :'String', :'resend' => :'String', :'transient_payload' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && code == o.code && csrf_token == o.csrf_token && identifier == o.identifier && method == o.method && resend == o.resend && transient_payload == o.transient_payload end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 198 def hash [address, code, csrf_token, identifier, method, resend, transient_payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @csrf_token.nil? invalid_properties.push('invalid value for "csrf_token", csrf_token cannot be nil.') end if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/ory-client/models/update_login_flow_with_code_method.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @csrf_token.nil? return false if @method.nil? true end |