Class: OryClient::UpdateLoginFlowWithPasswordMethod
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::UpdateLoginFlowWithPasswordMethod
- Defined in:
- lib/ory-client/models/update_login_flow_with_password_method.rb
Overview
Update Login Flow with Password Method
Instance Attribute Summary collapse
-
#csrf_token ⇒ Object
Sending the anti-csrf token is only required for browser login flows.
-
#identifier ⇒ Object
Identifier is the email or username of the user trying to log in.
-
#method ⇒ Object
Method should be set to \“password\” when logging in using the identifier and password strategy.
-
#password ⇒ Object
The user’s password.
-
#password_identifier ⇒ Object
Identifier is the email or username of the user trying to log in.
-
#transient_payload ⇒ Object
Transient data to pass along to any webhooks.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLoginFlowWithPasswordMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLoginFlowWithPasswordMethod
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateLoginFlowWithPasswordMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateLoginFlowWithPasswordMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'csrf_token') self.csrf_token = attributes[:'csrf_token'] end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end if attributes.key?(:'password') self.password = attributes[:'password'] else self.password = nil end if attributes.key?(:'password_identifier') self.password_identifier = attributes[:'password_identifier'] end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end end |
Instance Attribute Details
#csrf_token ⇒ Object
Sending the anti-csrf token is only required for browser login flows.
20 21 22 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 20 def csrf_token @csrf_token end |
#identifier ⇒ Object
Identifier is the email or username of the user trying to log in.
23 24 25 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 23 def identifier @identifier end |
#method ⇒ Object
Method should be set to \“password\” when logging in using the identifier and password strategy.
26 27 28 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 26 def method @method end |
#password ⇒ Object
The user’s password.
29 30 31 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 29 def password @password end |
#password_identifier ⇒ Object
Identifier is the email or username of the user trying to log in. This field is deprecated!
32 33 34 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 32 def password_identifier @password_identifier end |
#transient_payload ⇒ Object
Transient data to pass along to any webhooks
35 36 37 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 35 def transient_payload @transient_payload end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 38 def self.attribute_map { :'csrf_token' => :'csrf_token', :'identifier' => :'identifier', :'method' => :'method', :'password' => :'password', :'password_identifier' => :'password_identifier', :'transient_payload' => :'transient_payload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 212 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 60 def self.openapi_types { :'csrf_token' => :'String', :'identifier' => :'String', :'method' => :'String', :'password' => :'String', :'password_identifier' => :'String', :'transient_payload' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && csrf_token == o.csrf_token && identifier == o.identifier && method == o.method && password == o.password && password_identifier == o.password_identifier && transient_payload == o.transient_payload end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 205 def hash [csrf_token, identifier, method, password, password_identifier, transient_payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end if @password.nil? invalid_properties.push('invalid value for "password", password cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 |
# File 'lib/ory-client/models/update_login_flow_with_password_method.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @identifier.nil? return false if @method.nil? return false if @password.nil? true end |