Class: OryClient::UpdateOAuth2ClientLifespans
- Inherits:
-
Object
- Object
- OryClient::UpdateOAuth2ClientLifespans
- Defined in:
- lib/ory-client/models/update_o_auth2_client_lifespans.rb
Overview
The OIDC Hybrid grant type inherits token lifespan configuration from the implicit grant.
Instance Attribute Summary collapse
-
#authorization_code_grant_access_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_access_token_lifespan.
-
#authorization_code_grant_id_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_id_token_lifespan.
-
#authorization_code_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_refresh_token_lifespan.
-
#client_credentials_grant_access_token_lifespan ⇒ Object
Returns the value of attribute client_credentials_grant_access_token_lifespan.
-
#implicit_grant_access_token_lifespan ⇒ Object
Returns the value of attribute implicit_grant_access_token_lifespan.
-
#implicit_grant_id_token_lifespan ⇒ Object
Returns the value of attribute implicit_grant_id_token_lifespan.
-
#jwt_bearer_grant_access_token_lifespan ⇒ Object
Returns the value of attribute jwt_bearer_grant_access_token_lifespan.
-
#password_grant_access_token_lifespan ⇒ Object
Returns the value of attribute password_grant_access_token_lifespan.
-
#password_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute password_grant_refresh_token_lifespan.
-
#refresh_token_grant_access_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_access_token_lifespan.
-
#refresh_token_grant_id_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_id_token_lifespan.
-
#refresh_token_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_refresh_token_lifespan.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOAuth2ClientLifespans
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOAuth2ClientLifespans
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateOAuth2ClientLifespans` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateOAuth2ClientLifespans`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'authorization_code_grant_access_token_lifespan') self. = attributes[:'authorization_code_grant_access_token_lifespan'] end if attributes.key?(:'authorization_code_grant_id_token_lifespan') self. = attributes[:'authorization_code_grant_id_token_lifespan'] end if attributes.key?(:'authorization_code_grant_refresh_token_lifespan') self. = attributes[:'authorization_code_grant_refresh_token_lifespan'] end if attributes.key?(:'client_credentials_grant_access_token_lifespan') self.client_credentials_grant_access_token_lifespan = attributes[:'client_credentials_grant_access_token_lifespan'] end if attributes.key?(:'implicit_grant_access_token_lifespan') self.implicit_grant_access_token_lifespan = attributes[:'implicit_grant_access_token_lifespan'] end if attributes.key?(:'implicit_grant_id_token_lifespan') self.implicit_grant_id_token_lifespan = attributes[:'implicit_grant_id_token_lifespan'] end if attributes.key?(:'jwt_bearer_grant_access_token_lifespan') self.jwt_bearer_grant_access_token_lifespan = attributes[:'jwt_bearer_grant_access_token_lifespan'] end if attributes.key?(:'password_grant_access_token_lifespan') self.password_grant_access_token_lifespan = attributes[:'password_grant_access_token_lifespan'] end if attributes.key?(:'password_grant_refresh_token_lifespan') self.password_grant_refresh_token_lifespan = attributes[:'password_grant_refresh_token_lifespan'] end if attributes.key?(:'refresh_token_grant_access_token_lifespan') self.refresh_token_grant_access_token_lifespan = attributes[:'refresh_token_grant_access_token_lifespan'] end if attributes.key?(:'refresh_token_grant_id_token_lifespan') self.refresh_token_grant_id_token_lifespan = attributes[:'refresh_token_grant_id_token_lifespan'] end if attributes.key?(:'refresh_token_grant_refresh_token_lifespan') self.refresh_token_grant_refresh_token_lifespan = attributes[:'refresh_token_grant_refresh_token_lifespan'] end end |
Instance Attribute Details
#authorization_code_grant_access_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_access_token_lifespan.
19 20 21 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 19 def @authorization_code_grant_access_token_lifespan end |
#authorization_code_grant_id_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_id_token_lifespan.
21 22 23 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 21 def @authorization_code_grant_id_token_lifespan end |
#authorization_code_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute authorization_code_grant_refresh_token_lifespan.
23 24 25 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 23 def @authorization_code_grant_refresh_token_lifespan end |
#client_credentials_grant_access_token_lifespan ⇒ Object
Returns the value of attribute client_credentials_grant_access_token_lifespan.
25 26 27 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 25 def client_credentials_grant_access_token_lifespan @client_credentials_grant_access_token_lifespan end |
#implicit_grant_access_token_lifespan ⇒ Object
Returns the value of attribute implicit_grant_access_token_lifespan.
27 28 29 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 27 def implicit_grant_access_token_lifespan @implicit_grant_access_token_lifespan end |
#implicit_grant_id_token_lifespan ⇒ Object
Returns the value of attribute implicit_grant_id_token_lifespan.
29 30 31 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 29 def implicit_grant_id_token_lifespan @implicit_grant_id_token_lifespan end |
#jwt_bearer_grant_access_token_lifespan ⇒ Object
Returns the value of attribute jwt_bearer_grant_access_token_lifespan.
31 32 33 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 31 def jwt_bearer_grant_access_token_lifespan @jwt_bearer_grant_access_token_lifespan end |
#password_grant_access_token_lifespan ⇒ Object
Returns the value of attribute password_grant_access_token_lifespan.
33 34 35 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 33 def password_grant_access_token_lifespan @password_grant_access_token_lifespan end |
#password_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute password_grant_refresh_token_lifespan.
35 36 37 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 35 def password_grant_refresh_token_lifespan @password_grant_refresh_token_lifespan end |
#refresh_token_grant_access_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_access_token_lifespan.
37 38 39 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 37 def refresh_token_grant_access_token_lifespan @refresh_token_grant_access_token_lifespan end |
#refresh_token_grant_id_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_id_token_lifespan.
39 40 41 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 39 def refresh_token_grant_id_token_lifespan @refresh_token_grant_id_token_lifespan end |
#refresh_token_grant_refresh_token_lifespan ⇒ Object
Returns the value of attribute refresh_token_grant_refresh_token_lifespan.
41 42 43 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 41 def refresh_token_grant_refresh_token_lifespan @refresh_token_grant_refresh_token_lifespan end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 44 def self.attribute_map { :'authorization_code_grant_access_token_lifespan' => :'authorization_code_grant_access_token_lifespan', :'authorization_code_grant_id_token_lifespan' => :'authorization_code_grant_id_token_lifespan', :'authorization_code_grant_refresh_token_lifespan' => :'authorization_code_grant_refresh_token_lifespan', :'client_credentials_grant_access_token_lifespan' => :'client_credentials_grant_access_token_lifespan', :'implicit_grant_access_token_lifespan' => :'implicit_grant_access_token_lifespan', :'implicit_grant_id_token_lifespan' => :'implicit_grant_id_token_lifespan', :'jwt_bearer_grant_access_token_lifespan' => :'jwt_bearer_grant_access_token_lifespan', :'password_grant_access_token_lifespan' => :'password_grant_access_token_lifespan', :'password_grant_refresh_token_lifespan' => :'password_grant_refresh_token_lifespan', :'refresh_token_grant_access_token_lifespan' => :'refresh_token_grant_access_token_lifespan', :'refresh_token_grant_id_token_lifespan' => :'refresh_token_grant_id_token_lifespan', :'refresh_token_grant_refresh_token_lifespan' => :'refresh_token_grant_refresh_token_lifespan' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
417 418 419 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 417 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 85 def self.openapi_nullable Set.new([ :'authorization_code_grant_access_token_lifespan', :'authorization_code_grant_id_token_lifespan', :'authorization_code_grant_refresh_token_lifespan', :'client_credentials_grant_access_token_lifespan', :'implicit_grant_access_token_lifespan', :'implicit_grant_id_token_lifespan', :'jwt_bearer_grant_access_token_lifespan', :'password_grant_access_token_lifespan', :'password_grant_refresh_token_lifespan', :'refresh_token_grant_access_token_lifespan', :'refresh_token_grant_id_token_lifespan', :'refresh_token_grant_refresh_token_lifespan' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 67 def self.openapi_types { :'authorization_code_grant_access_token_lifespan' => :'String', :'authorization_code_grant_id_token_lifespan' => :'String', :'authorization_code_grant_refresh_token_lifespan' => :'String', :'client_credentials_grant_access_token_lifespan' => :'String', :'implicit_grant_access_token_lifespan' => :'String', :'implicit_grant_id_token_lifespan' => :'String', :'jwt_bearer_grant_access_token_lifespan' => :'String', :'password_grant_access_token_lifespan' => :'String', :'password_grant_refresh_token_lifespan' => :'String', :'refresh_token_grant_access_token_lifespan' => :'String', :'refresh_token_grant_id_token_lifespan' => :'String', :'refresh_token_grant_refresh_token_lifespan' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 385 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && == o. && == o. && client_credentials_grant_access_token_lifespan == o.client_credentials_grant_access_token_lifespan && implicit_grant_access_token_lifespan == o.implicit_grant_access_token_lifespan && implicit_grant_id_token_lifespan == o.implicit_grant_id_token_lifespan && jwt_bearer_grant_access_token_lifespan == o.jwt_bearer_grant_access_token_lifespan && password_grant_access_token_lifespan == o.password_grant_access_token_lifespan && password_grant_refresh_token_lifespan == o.password_grant_refresh_token_lifespan && refresh_token_grant_access_token_lifespan == o.refresh_token_grant_access_token_lifespan && refresh_token_grant_id_token_lifespan == o.refresh_token_grant_id_token_lifespan && refresh_token_grant_refresh_token_lifespan == o.refresh_token_grant_refresh_token_lifespan end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 448 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OryClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 519 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 424 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
404 405 406 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 404 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 410 def hash [, , , client_credentials_grant_access_token_lifespan, implicit_grant_access_token_lifespan, implicit_grant_id_token_lifespan, jwt_bearer_grant_access_token_lifespan, password_grant_access_token_lifespan, password_grant_refresh_token_lifespan, refresh_token_grant_access_token_lifespan, refresh_token_grant_id_token_lifespan, refresh_token_grant_refresh_token_lifespan].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 168 def list_invalid_properties invalid_properties = Array.new pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@authorization_code_grant_access_token_lifespan.nil? && @authorization_code_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"authorization_code_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@authorization_code_grant_id_token_lifespan.nil? && @authorization_code_grant_id_token_lifespan !~ pattern invalid_properties.push("invalid value for \"authorization_code_grant_id_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@authorization_code_grant_refresh_token_lifespan.nil? && @authorization_code_grant_refresh_token_lifespan !~ pattern invalid_properties.push("invalid value for \"authorization_code_grant_refresh_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@client_credentials_grant_access_token_lifespan.nil? && @client_credentials_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"client_credentials_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@implicit_grant_access_token_lifespan.nil? && @implicit_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"implicit_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@implicit_grant_id_token_lifespan.nil? && @implicit_grant_id_token_lifespan !~ pattern invalid_properties.push("invalid value for \"implicit_grant_id_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@jwt_bearer_grant_access_token_lifespan.nil? && @jwt_bearer_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"jwt_bearer_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@password_grant_access_token_lifespan.nil? && @password_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"password_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@password_grant_refresh_token_lifespan.nil? && @password_grant_refresh_token_lifespan !~ pattern invalid_properties.push("invalid value for \"password_grant_refresh_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@refresh_token_grant_access_token_lifespan.nil? && @refresh_token_grant_access_token_lifespan !~ pattern invalid_properties.push("invalid value for \"refresh_token_grant_access_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@refresh_token_grant_id_token_lifespan.nil? && @refresh_token_grant_id_token_lifespan !~ pattern invalid_properties.push("invalid value for \"refresh_token_grant_id_token_lifespan\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) if !@refresh_token_grant_refresh_token_lifespan.nil? && @refresh_token_grant_refresh_token_lifespan !~ pattern invalid_properties.push("invalid value for \"refresh_token_grant_refresh_token_lifespan\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
495 496 497 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 495 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 501 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
489 490 491 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 489 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ory-client/models/update_o_auth2_client_lifespans.rb', line 235 def valid? return false if !@authorization_code_grant_access_token_lifespan.nil? && @authorization_code_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@authorization_code_grant_id_token_lifespan.nil? && @authorization_code_grant_id_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@authorization_code_grant_refresh_token_lifespan.nil? && @authorization_code_grant_refresh_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@client_credentials_grant_access_token_lifespan.nil? && @client_credentials_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@implicit_grant_access_token_lifespan.nil? && @implicit_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@implicit_grant_id_token_lifespan.nil? && @implicit_grant_id_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@jwt_bearer_grant_access_token_lifespan.nil? && @jwt_bearer_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@password_grant_access_token_lifespan.nil? && @password_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@password_grant_refresh_token_lifespan.nil? && @password_grant_refresh_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@refresh_token_grant_access_token_lifespan.nil? && @refresh_token_grant_access_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@refresh_token_grant_id_token_lifespan.nil? && @refresh_token_grant_id_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) return false if !@refresh_token_grant_refresh_token_lifespan.nil? && @refresh_token_grant_refresh_token_lifespan !~ Regexp.new(/^[0-9]+(ns|us|ms|s|m|h)$/) true end |