Class: OryClient::UpdateSettingsFlowWithDeviceAuthnMethod

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/update_settings_flow_with_device_authn_method.rb

Overview

Update Settings Flow with DeviceAuthn Method

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSettingsFlowWithDeviceAuthnMethod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateSettingsFlowWithDeviceAuthnMethod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateSettingsFlowWithDeviceAuthnMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'add')
    self.add = attributes[:'add']
  end

  if attributes.key?(:'csrf_token')
    self.csrf_token = attributes[:'csrf_token']
  end

  if attributes.key?(:'delete')
    self.delete = attributes[:'delete']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'rotate_secret')
    self.rotate_secret = attributes[:'rotate_secret']
  end

  if attributes.key?(:'transient_payload')
    self.transient_payload = attributes[:'transient_payload']
  end
end

Instance Attribute Details

#addObject

Returns the value of attribute add.



19
20
21
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 19

def add
  @add
end

#csrf_tokenObject

CSRFToken is the anti-CSRF token It only is required to remove a key from the browser.



22
23
24
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 22

def csrf_token
  @csrf_token
end

#deleteObject

Returns the value of attribute delete.



24
25
26
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 24

def delete
  @delete
end

#methodObject

Method Should be set to "deviceauthn" when trying to add or remove a DeviceAuthn key.



27
28
29
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 27

def method
  @method
end

#rotate_secretObject

Returns the value of attribute rotate_secret.



29
30
31
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 29

def rotate_secret
  @rotate_secret
end

#transient_payloadObject

Transient data to pass along to any webhooks



32
33
34
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 32

def transient_payload
  @transient_payload
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 35

def self.attribute_map
  {
    :'add' => :'add',
    :'csrf_token' => :'csrf_token',
    :'delete' => :'delete',
    :'method' => :'method',
    :'rotate_secret' => :'rotate_secret',
    :'transient_payload' => :'transient_payload'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 57

def self.openapi_types
  {
    :'add' => :'UpdateSettingsFlowWithDeviceAuthnMethodAdd',
    :'csrf_token' => :'String',
    :'delete' => :'UpdateSettingsFlowWithDeviceAuthnMethodDelete',
    :'method' => :'String',
    :'rotate_secret' => :'UpdateSettingsFlowWithDeviceAuthnMethodRotateSecret',
    :'transient_payload' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
157
158
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      add == o.add &&
      csrf_token == o.csrf_token &&
      delete == o.delete &&
      method == o.method &&
      rotate_secret == o.rotate_secret &&
      transient_payload == o.transient_payload
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 168

def hash
  [add, csrf_token, delete, method, rotate_secret, transient_payload].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
# File 'lib/ory-client/models/update_settings_flow_with_device_authn_method.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @method.nil?
  true
end