Class: OryClient::UpdateSettingsFlowWithOidcMethod

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/update_settings_flow_with_oidc_method.rb

Overview

Update Settings Flow with OpenID Connect Method

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSettingsFlowWithOidcMethod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateSettingsFlowWithOidcMethod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateSettingsFlowWithOidcMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow')
    self.flow = attributes[:'flow']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'traits')
    self.traits = attributes[:'traits']
  end

  if attributes.key?(:'transient_payload')
    self.transient_payload = attributes[:'transient_payload']
  end

  if attributes.key?(:'unlink')
    self.unlink = attributes[:'unlink']
  end

  if attributes.key?(:'upstream_parameters')
    self.upstream_parameters = attributes[:'upstream_parameters']
  end
end

Instance Attribute Details

#flowObject

Flow ID is the flow’s ID. in: query



20
21
22
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 20

def flow
  @flow
end

Link this provider Either this or unlink must be set. type: string in: body



23
24
25
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 23

def link
  @link
end

#methodObject

Method Should be set to profile when trying to update a profile.



26
27
28
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 26

def method
  @method
end

#traitsObject

The identity’s traits in: body



29
30
31
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 29

def traits
  @traits
end

#transient_payloadObject

Transient data to pass along to any webhooks



32
33
34
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 32

def transient_payload
  @transient_payload
end

Unlink this provider Either this or link must be set. type: string in: body



35
36
37
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 35

def unlink
  @unlink
end

#upstream_parametersObject

UpstreamParameters are the parameters that are passed to the upstream identity provider. These parameters are optional and depend on what the upstream identity provider supports. Supported parameters are: login_hint (string): The login_hint parameter suppresses the account chooser and either pre-fills the email box on the sign-in form, or selects the proper session. hd (string): The hd parameter limits the login/registration process to a Google Organization, e.g. mycollege.edu. prompt (string): The prompt specifies whether the Authorization Server prompts the End-User for reauthentication and consent, e.g. select_account. acr_values (string): The acr_values specifies the Authentication Context Class Reference values for the authorization request.



38
39
40
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 38

def upstream_parameters
  @upstream_parameters
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 41

def self.attribute_map
  {
    :'flow' => :'flow',
    :'link' => :'link',
    :'method' => :'method',
    :'traits' => :'traits',
    :'transient_payload' => :'transient_payload',
    :'unlink' => :'unlink',
    :'upstream_parameters' => :'upstream_parameters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 64

def self.openapi_types
  {
    :'flow' => :'String',
    :'link' => :'String',
    :'method' => :'String',
    :'traits' => :'Object',
    :'transient_payload' => :'Object',
    :'unlink' => :'String',
    :'upstream_parameters' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow == o.flow &&
      link == o.link &&
      method == o.method &&
      traits == o.traits &&
      transient_payload == o.transient_payload &&
      unlink == o.unlink &&
      upstream_parameters == o.upstream_parameters
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 181

def hash
  [flow, link, method, traits, transient_payload, unlink, upstream_parameters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @method.nil?
  true
end