Class: OryClient::VerifiableIdentityAddress

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/verifiable_identity_address.rb

Overview

VerifiableAddress is an identity’s verifiable address

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VerifiableIdentityAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::VerifiableIdentityAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::VerifiableIdentityAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  else
    self.verified = nil
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  end

  if attributes.key?(:'via')
    self.via = attributes[:'via']
  else
    self.via = nil
  end
end

Instance Attribute Details

#created_atObject

When this entry was created



20
21
22
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 20

def created_at
  @created_at
end

#idObject

The ID



23
24
25
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 23

def id
  @id
end

#statusObject

VerifiableAddressStatus must not exceed 16 characters as that is the limitation in the SQL Schema



26
27
28
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 26

def status
  @status
end

#updated_atObject

When this entry was last updated



29
30
31
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 29

def updated_at
  @updated_at
end

#valueObject

The address value example [email protected]



32
33
34
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 32

def value
  @value
end

#verifiedObject

Indicates if the address has already been verified



35
36
37
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 35

def verified
  @verified
end

#verified_atObject

Returns the value of attribute verified_at.



37
38
39
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 37

def verified_at
  @verified_at
end

#viaObject

The delivery method



40
41
42
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 40

def via
  @via
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 65

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'status' => :'status',
    :'updated_at' => :'updated_at',
    :'value' => :'value',
    :'verified' => :'verified',
    :'verified_at' => :'verified_at',
    :'via' => :'via'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 89

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'id' => :'String',
    :'status' => :'String',
    :'updated_at' => :'Time',
    :'value' => :'String',
    :'verified' => :'Boolean',
    :'verified_at' => :'Time',
    :'via' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      id == o.id &&
      status == o.status &&
      updated_at == o.updated_at &&
      value == o.value &&
      verified == o.verified &&
      verified_at == o.verified_at &&
      via == o.via
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 265

def hash
  [created_at, id, status, updated_at, value, verified, verified_at, via].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @verified.nil?
    invalid_properties.push('invalid value for "verified", verified cannot be nil.')
  end

  if @via.nil?
    invalid_properties.push('invalid value for "via", via cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
200
# File 'lib/ory-client/models/verifiable_identity_address.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @status.nil?
  return false if @value.nil?
  return false if @verified.nil?
  return false if @via.nil?
  via_validator = EnumAttributeValidator.new('String', ["email", "sms"])
  return false unless via_validator.valid?(@via)
  true
end