Class: OryClient::VerificationFlow
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::VerificationFlow
- Defined in:
- lib/ory-client/models/verification_flow.rb
Overview
Used to verify an out-of-band communication channel such as an email address or a phone number. For more information head over to: https://www.ory.com/docs/kratos/self-service/flows/verify-email-account-activation
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
Active, if set, contains the registration method that is being used.
-
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the request expires.
-
#id ⇒ Object
ID represents the request's unique ID.
-
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the request occurred.
-
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos.
-
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
-
#state ⇒ Object
Returns the value of attribute state.
-
#transient_payload ⇒ Object
TransientPayload is used to pass data from the verification flow to hooks and email templates.
-
#type ⇒ Object
The flow type can either be
apiorbrowser. -
#ui ⇒ Object
Returns the value of attribute ui.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VerificationFlow
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VerificationFlow
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/ory-client/models/verification_flow.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::VerificationFlow` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::VerificationFlow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'issued_at') self.issued_at = attributes[:'issued_at'] end if attributes.key?(:'request_url') self.request_url = attributes[:'request_url'] end if attributes.key?(:'return_to') self.return_to = attributes[:'return_to'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'ui') self.ui = attributes[:'ui'] else self.ui = nil end end |
Instance Attribute Details
#active ⇒ Object
Active, if set, contains the registration method that is being used. It is initially not set.
20 21 22 |
# File 'lib/ory-client/models/verification_flow.rb', line 20 def active @active end |
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the request expires. If the user still wishes to verify the address, a new request has to be initiated.
23 24 25 |
# File 'lib/ory-client/models/verification_flow.rb', line 23 def expires_at @expires_at end |
#id ⇒ Object
ID represents the request's unique ID. When performing the verification flow, this represents the id in the verify ui's query parameter: http://<selfservice.flows.verification.ui_url>?request=
26 27 28 |
# File 'lib/ory-client/models/verification_flow.rb', line 26 def id @id end |
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the request occurred.
29 30 31 |
# File 'lib/ory-client/models/verification_flow.rb', line 29 def issued_at @issued_at end |
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL's path or query for example.
32 33 34 |
# File 'lib/ory-client/models/verification_flow.rb', line 32 def request_url @request_url end |
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
35 36 37 |
# File 'lib/ory-client/models/verification_flow.rb', line 35 def return_to @return_to end |
#state ⇒ Object
Returns the value of attribute state.
37 38 39 |
# File 'lib/ory-client/models/verification_flow.rb', line 37 def state @state end |
#transient_payload ⇒ Object
TransientPayload is used to pass data from the verification flow to hooks and email templates
40 41 42 |
# File 'lib/ory-client/models/verification_flow.rb', line 40 def transient_payload @transient_payload end |
#type ⇒ Object
The flow type can either be api or browser.
43 44 45 |
# File 'lib/ory-client/models/verification_flow.rb', line 43 def type @type end |
#ui ⇒ Object
Returns the value of attribute ui.
45 46 47 |
# File 'lib/ory-client/models/verification_flow.rb', line 45 def ui @ui end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/ory-client/models/verification_flow.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/ory-client/models/verification_flow.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ory-client/models/verification_flow.rb', line 70 def self.attribute_map { :'active' => :'active', :'expires_at' => :'expires_at', :'id' => :'id', :'issued_at' => :'issued_at', :'request_url' => :'request_url', :'return_to' => :'return_to', :'state' => :'state', :'transient_payload' => :'transient_payload', :'type' => :'type', :'ui' => :'ui' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/ory-client/models/verification_flow.rb', line 289 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/ory-client/models/verification_flow.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/ory-client/models/verification_flow.rb', line 96 def self.openapi_types { :'active' => :'String', :'expires_at' => :'Time', :'id' => :'String', :'issued_at' => :'Time', :'request_url' => :'String', :'return_to' => :'String', :'state' => :'VerificationFlowState', :'transient_payload' => :'Object', :'type' => :'String', :'ui' => :'UiContainer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/ory-client/models/verification_flow.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && expires_at == o.expires_at && id == o.id && issued_at == o.issued_at && request_url == o.request_url && return_to == o.return_to && state == o.state && transient_payload == o.transient_payload && type == o.type && ui == o.ui end |
#eql?(o) ⇒ Boolean
276 277 278 |
# File 'lib/ory-client/models/verification_flow.rb', line 276 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/ory-client/models/verification_flow.rb', line 282 def hash [active, expires_at, id, issued_at, request_url, return_to, state, transient_payload, type, ui].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ory-client/models/verification_flow.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @ui.nil? invalid_properties.push('invalid value for "ui", ui cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/ory-client/models/verification_flow.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 |
# File 'lib/ory-client/models/verification_flow.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @state.nil? return false if @type.nil? return false if @ui.nil? true end |