Class: OryClient::Workspace

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/workspace.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Workspace

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/ory-client/models/workspace.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::Workspace` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::Workspace`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_policy')
    self.access_policy = attributes[:'access_policy']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'subscription_plan')
    self.subscription_plan = attributes[:'subscription_plan']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#access_policyObject

Controls who can access the workspace and its projects This does not control access level, only who can access it at all. CHECK_ORGANIZATION_AND_WORKSPACE_MEMBERSHIP WorkspaceAccessPolicyOrganizationMembershipRequired Only invited members that are part of the organization defined for the workspace can access it CHECK_ACCESS_PERMISSION WorkspaceAccessPolicyMembershipRequired All invited members can access the workspace, regardless of their organization membership This is useful for migration scenarios where workspaces previously did not have an organization assigned If a user is just a member of a project within the workspace, they’ll still have access to the project, but not to the workspace itself (the default for existing workspaces)



19
20
21
# File 'lib/ory-client/models/workspace.rb', line 19

def access_policy
  @access_policy
end

#created_atObject

Returns the value of attribute created_at.



21
22
23
# File 'lib/ory-client/models/workspace.rb', line 21

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



23
24
25
# File 'lib/ory-client/models/workspace.rb', line 23

def id
  @id
end

#nameObject

Returns the value of attribute name.



25
26
27
# File 'lib/ory-client/models/workspace.rb', line 25

def name
  @name
end

#organization_idObject

Returns the value of attribute organization_id.



27
28
29
# File 'lib/ory-client/models/workspace.rb', line 27

def organization_id
  @organization_id
end

#subscription_idObject

Returns the value of attribute subscription_id.



29
30
31
# File 'lib/ory-client/models/workspace.rb', line 29

def subscription_id
  @subscription_id
end

#subscription_planObject

Returns the value of attribute subscription_plan.



31
32
33
# File 'lib/ory-client/models/workspace.rb', line 31

def subscription_plan
  @subscription_plan
end

#updated_atObject

Returns the value of attribute updated_at.



33
34
35
# File 'lib/ory-client/models/workspace.rb', line 33

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/ory-client/models/workspace.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/ory-client/models/workspace.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/ory-client/models/workspace.rb', line 58

def self.attribute_map
  {
    :'access_policy' => :'access_policy',
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'name' => :'name',
    :'organization_id' => :'organization_id',
    :'subscription_id' => :'subscription_id',
    :'subscription_plan' => :'subscription_plan',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/ory-client/models/workspace.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
100
101
102
# File 'lib/ory-client/models/workspace.rb', line 96

def self.openapi_nullable
  Set.new([
    :'organization_id',
    :'subscription_id',
    :'subscription_plan',
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ory-client/models/workspace.rb', line 82

def self.openapi_types
  {
    :'access_policy' => :'String',
    :'created_at' => :'Time',
    :'id' => :'String',
    :'name' => :'String',
    :'organization_id' => :'String',
    :'subscription_id' => :'String',
    :'subscription_plan' => :'String',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/ory-client/models/workspace.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_policy == o.access_policy &&
      created_at == o.created_at &&
      id == o.id &&
      name == o.name &&
      organization_id == o.organization_id &&
      subscription_id == o.subscription_id &&
      subscription_plan == o.subscription_plan &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/ory-client/models/workspace.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/ory-client/models/workspace.rb', line 271

def hash
  [access_policy, created_at, id, name, organization_id, subscription_id, subscription_plan, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/ory-client/models/workspace.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/ory-client/models/workspace.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
194
195
196
# File 'lib/ory-client/models/workspace.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  access_policy_validator = EnumAttributeValidator.new('String', ["CHECK_ORGANIZATION_AND_WORKSPACE_MEMBERSHIP", "CHECK_ACCESS_PERMISSION"])
  return false unless access_policy_validator.valid?(@access_policy)
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if @updated_at.nil?
  true
end