Class: OryClient::WorkspaceApiKey

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/workspace_api_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WorkspaceApiKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/ory-client/models/workspace_api_key.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::WorkspaceApiKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::WorkspaceApiKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'last_characters')
    self.last_characters = attributes[:'last_characters']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  else
    self.owner_id = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end
end

Instance Attribute Details

#created_atObject

The API key’s creation date



19
20
21
# File 'lib/ory-client/models/workspace_api_key.rb', line 19

def created_at
  @created_at
end

#expires_atObject

Returns the value of attribute expires_at.



21
22
23
# File 'lib/ory-client/models/workspace_api_key.rb', line 21

def expires_at
  @expires_at
end

#idObject

The key’s ID.



24
25
26
# File 'lib/ory-client/models/workspace_api_key.rb', line 24

def id
  @id
end

#last_charactersObject

The last characters of the key’s value. Lets you tell API keys apart in the UI without revealing the full value. Empty for keys created before this was introduced.



27
28
29
# File 'lib/ory-client/models/workspace_api_key.rb', line 27

def last_characters
  @last_characters
end

#nameObject

The API key’s Name Set this to help you remember, for example, where you use the API key.



30
31
32
# File 'lib/ory-client/models/workspace_api_key.rb', line 30

def name
  @name
end

#owner_idObject

The key’s owner



33
34
35
# File 'lib/ory-client/models/workspace_api_key.rb', line 33

def owner_id
  @owner_id
end

#updated_atObject

The API key’s last update date



36
37
38
# File 'lib/ory-client/models/workspace_api_key.rb', line 36

def updated_at
  @updated_at
end

#valueObject

The key’s value



39
40
41
# File 'lib/ory-client/models/workspace_api_key.rb', line 39

def value
  @value
end

#workspace_idObject

The API key’s workspace ID



42
43
44
# File 'lib/ory-client/models/workspace_api_key.rb', line 42

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/ory-client/models/workspace_api_key.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/ory-client/models/workspace_api_key.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/ory-client/models/workspace_api_key.rb', line 45

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'last_characters' => :'last_characters',
    :'name' => :'name',
    :'owner_id' => :'owner_id',
    :'updated_at' => :'updated_at',
    :'value' => :'value',
    :'workspace_id' => :'workspace_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/ory-client/models/workspace_api_key.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/ory-client/models/workspace_api_key.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/ory-client/models/workspace_api_key.rb', line 70

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'expires_at' => :'Time',
    :'id' => :'String',
    :'last_characters' => :'String',
    :'name' => :'String',
    :'owner_id' => :'String',
    :'updated_at' => :'Time',
    :'value' => :'String',
    :'workspace_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/ory-client/models/workspace_api_key.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      expires_at == o.expires_at &&
      id == o.id &&
      last_characters == o.last_characters &&
      name == o.name &&
      owner_id == o.owner_id &&
      updated_at == o.updated_at &&
      value == o.value &&
      workspace_id == o.workspace_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/ory-client/models/workspace_api_key.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/ory-client/models/workspace_api_key.rb', line 233

def hash
  [created_at, expires_at, id, last_characters, name, owner_id, updated_at, value, workspace_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/ory-client/models/workspace_api_key.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @owner_id.nil?
    invalid_properties.push('invalid value for "owner_id", owner_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/ory-client/models/workspace_api_key.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
# File 'lib/ory-client/models/workspace_api_key.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @owner_id.nil?
  true
end