Class: OryClient::WorkspaceOrganization

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/workspace_organization.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WorkspaceOrganization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/ory-client/models/workspace_organization.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::WorkspaceOrganization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::WorkspaceOrganization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_link')
    self.active_link = attributes[:'active_link']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'default_region')
    self.default_region = attributes[:'default_region']
  end

  if attributes.key?(:'domain_verifications')
    if (value = attributes[:'domain_verifications']).is_a?(Array)
      self.domain_verifications = value
    end
  end

  if attributes.key?(:'domains')
    if (value = attributes[:'domains']).is_a?(Array)
      self.domains = value
    end
  else
    self.domains = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'providers')
    if (value = attributes[:'providers']).is_a?(Array)
      self.providers = value
    end
  else
    self.providers = nil
  end

  if attributes.key?(:'session_lifespan')
    self.session_lifespan = attributes[:'session_lifespan']
  end
end

Instance Attribute Details

Returns the value of attribute active_link.



18
19
20
# File 'lib/ory-client/models/workspace_organization.rb', line 18

def active_link
  @active_link
end

#created_at ⇒ Object

Returns the value of attribute created_at.



20
21
22
# File 'lib/ory-client/models/workspace_organization.rb', line 20

def created_at
  @created_at
end

#default_region ⇒ Object

DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global



23
24
25
# File 'lib/ory-client/models/workspace_organization.rb', line 23

def default_region
  @default_region
end

#domain_verifications ⇒ Object

The verification status of each organization domain, including the DNS TXT record the customer must publish to prove control. A domain that has no verification started yet still appears, with the TXT record name set and an empty status.



26
27
28
# File 'lib/ory-client/models/workspace_organization.rb', line 26

def domain_verifications
  @domain_verifications
end

#domains ⇒ Object

The list of organization's domains.



29
30
31
# File 'lib/ory-client/models/workspace_organization.rb', line 29

def domains
  @domains
end

#id ⇒ Object

The organization's ID.



32
33
34
# File 'lib/ory-client/models/workspace_organization.rb', line 32

def id
  @id
end

#label ⇒ Object

The organization's human-readable label.



35
36
37
# File 'lib/ory-client/models/workspace_organization.rb', line 35

def label
  @label
end

#providers ⇒ Object

Returns the value of attribute providers.



37
38
39
# File 'lib/ory-client/models/workspace_organization.rb', line 37

def providers
  @providers
end

#session_lifespan ⇒ Object

SessionLifespan overrides the project-level session lifespan for sessions issued for this organization. A Go duration string between 1m and 8760h. A null (or zero) value means the project default applies.



40
41
42
# File 'lib/ory-client/models/workspace_organization.rb', line 40

def session_lifespan
  @session_lifespan
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



80
81
82
# File 'lib/ory-client/models/workspace_organization.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/ory-client/models/workspace_organization.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/ory-client/models/workspace_organization.rb', line 65

def self.attribute_map
  {
    :'active_link' => :'active_link',
    :'created_at' => :'created_at',
    :'default_region' => :'default_region',
    :'domain_verifications' => :'domain_verifications',
    :'domains' => :'domains',
    :'id' => :'id',
    :'label' => :'label',
    :'providers' => :'providers',
    :'session_lifespan' => :'session_lifespan'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/ory-client/models/workspace_organization.rb', line 333

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



105
106
107
108
# File 'lib/ory-client/models/workspace_organization.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/ory-client/models/workspace_organization.rb', line 90

def self.openapi_types
  {
    :'active_link' => :'OnboardingPortalLink',
    :'created_at' => :'Time',
    :'default_region' => :'String',
    :'domain_verifications' => :'Array<DomainVerificationStatus>',
    :'domains' => :'Array<String>',
    :'id' => :'String',
    :'label' => :'String',
    :'providers' => :'Array<String>',
    :'session_lifespan' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/ory-client/models/workspace_organization.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_link == o.active_link &&
      created_at == o.created_at &&
      default_region == o.default_region &&
      domain_verifications == o.domain_verifications &&
      domains == o.domains &&
      id == o.id &&
      label == o.label &&
      providers == o.providers &&
      session_lifespan == o.session_lifespan
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/ory-client/models/workspace_organization.rb', line 320

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



326
327
328
# File 'lib/ory-client/models/workspace_organization.rb', line 326

def hash
  [active_link, created_at, default_region, domain_verifications, domains, id, label, providers, session_lifespan].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ory-client/models/workspace_organization.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @domains.nil?
    invalid_properties.push('invalid value for "domains", domains cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @providers.nil?
    invalid_properties.push('invalid value for "providers", providers cannot be nil.')
  end

  pattern = Regexp.new(/^[0-9]+(s|m|h)$/)
  if !@session_lifespan.nil? && @session_lifespan !~ pattern
    invalid_properties.push("invalid value for \"session_lifespan\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/ory-client/models/workspace_organization.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ory-client/models/workspace_organization.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  default_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"])
  return false unless default_region_validator.valid?(@default_region)
  return false if @domains.nil?
  return false if @id.nil?
  return false if @label.nil?
  return false if @providers.nil?
  return false if !@session_lifespan.nil? && @session_lifespan !~ Regexp.new(/^[0-9]+(s|m|h)$/)
  true
end