Class: OryClient::AcceptOAuth2ConsentRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::AcceptOAuth2ConsentRequest
- Defined in:
- lib/ory-client/models/accept_o_auth2_consent_request.rb
Instance Attribute Summary collapse
-
#context ⇒ Object
Returns the value of attribute context.
-
#grant_access_token_audience ⇒ Object
GrantedAudience sets the audience the user authorized the client to use.
-
#grant_scope ⇒ Object
GrantScope sets the scope the user authorized the client to use.
-
#remember ⇒ Object
Remember, if set to true, tells ORY Hydra to remember this consent authorization and reuse it if the same client asks the same user for the same, or a subset of, scope.
-
#remember_for ⇒ Object
RememberFor sets how long the consent authorization should be remembered for in seconds.
-
#session ⇒ Object
Returns the value of attribute session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AcceptOAuth2ConsentRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AcceptOAuth2ConsentRequest
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::AcceptOAuth2ConsentRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::AcceptOAuth2ConsentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'grant_access_token_audience') if (value = attributes[:'grant_access_token_audience']).is_a?(Array) self.grant_access_token_audience = value end end if attributes.key?(:'grant_scope') if (value = attributes[:'grant_scope']).is_a?(Array) self.grant_scope = value end end if attributes.key?(:'remember') self.remember = attributes[:'remember'] end if attributes.key?(:'remember_for') self.remember_for = attributes[:'remember_for'] end if attributes.key?(:'session') self.session = attributes[:'session'] end end |
Instance Attribute Details
#context ⇒ Object
Returns the value of attribute context.
18 19 20 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 18 def context @context end |
#grant_access_token_audience ⇒ Object
GrantedAudience sets the audience the user authorized the client to use. Should be a subset of ‘requested_access_token_audience`.
21 22 23 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 21 def grant_access_token_audience @grant_access_token_audience end |
#grant_scope ⇒ Object
GrantScope sets the scope the user authorized the client to use. Should be a subset of ‘requested_scope`.
24 25 26 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 24 def grant_scope @grant_scope end |
#remember ⇒ Object
Remember, if set to true, tells ORY Hydra to remember this consent authorization and reuse it if the same client asks the same user for the same, or a subset of, scope.
27 28 29 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 27 def remember @remember end |
#remember_for ⇒ Object
RememberFor sets how long the consent authorization should be remembered for in seconds. If set to ‘0`, the authorization will be remembered indefinitely.
30 31 32 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 30 def remember_for @remember_for end |
#session ⇒ Object
Returns the value of attribute session.
32 33 34 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 32 def session @session end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 35 def self.attribute_map { :'context' => :'context', :'grant_access_token_audience' => :'grant_access_token_audience', :'grant_scope' => :'grant_scope', :'remember' => :'remember', :'remember_for' => :'remember_for', :'session' => :'session' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 57 def self.openapi_types { :'context' => :'Object', :'grant_access_token_audience' => :'Array<String>', :'grant_scope' => :'Array<String>', :'remember' => :'Boolean', :'remember_for' => :'Integer', :'session' => :'AcceptOAuth2ConsentRequestSession' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && context == o.context && grant_access_token_audience == o.grant_access_token_audience && grant_scope == o.grant_scope && remember == o.remember && remember_for == o.remember_for && session == o.session end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 155 def hash [context, grant_access_token_audience, grant_scope, remember, remember_for, session].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 |
# File 'lib/ory-client/models/accept_o_auth2_consent_request.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |