Class: OryClient::AccountExperienceConfiguration

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/account_experience_configuration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountExperienceConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/ory-client/models/account_experience_configuration.rb', line 159

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::AccountExperienceConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::AccountExperienceConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'default_locale')
    self.default_locale = attributes[:'default_locale']
  else
    self.default_locale = nil
  end

  if attributes.key?(:'default_redirect_url')
    self.default_redirect_url = attributes[:'default_redirect_url']
  else
    self.default_redirect_url = nil
  end

  if attributes.key?(:'enabled_locales')
    if (value = attributes[:'enabled_locales']).is_a?(Array)
      self.enabled_locales = value
    end
  else
    self.enabled_locales = nil
  end

  if attributes.key?(:'error_ui_url')
    self.error_ui_url = attributes[:'error_ui_url']
  else
    self.error_ui_url = nil
  end

  if attributes.key?(:'favicon_dark_url')
    self.favicon_dark_url = attributes[:'favicon_dark_url']
  end

  if attributes.key?(:'favicon_light_url')
    self.favicon_light_url = attributes[:'favicon_light_url']
  end

  if attributes.key?(:'hide_ory_branding')
    self.hide_ory_branding = attributes[:'hide_ory_branding']
  else
    self.hide_ory_branding = nil
  end

  if attributes.key?(:'hide_registration_link')
    self.hide_registration_link = attributes[:'hide_registration_link']
  else
    self.hide_registration_link = nil
  end

  if attributes.key?(:'locale_behavior')
    self.locale_behavior = attributes[:'locale_behavior']
  else
    self.locale_behavior = nil
  end

  if attributes.key?(:'login_ui_url')
    self. = attributes[:'login_ui_url']
  else
    self. = nil
  end

  if attributes.key?(:'logo_dark_url')
    self.logo_dark_url = attributes[:'logo_dark_url']
  end

  if attributes.key?(:'logo_light_url')
    self.logo_light_url = attributes[:'logo_light_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'recovery_enabled')
    self.recovery_enabled = attributes[:'recovery_enabled']
  else
    self.recovery_enabled = nil
  end

  if attributes.key?(:'recovery_ui_url')
    self.recovery_ui_url = attributes[:'recovery_ui_url']
  else
    self.recovery_ui_url = nil
  end

  if attributes.key?(:'registration_enabled')
    self.registration_enabled = attributes[:'registration_enabled']
  else
    self.registration_enabled = nil
  end

  if attributes.key?(:'registration_ui_url')
    self.registration_ui_url = attributes[:'registration_ui_url']
  else
    self.registration_ui_url = nil
  end

  if attributes.key?(:'settings_ui_url')
    self.settings_ui_url = attributes[:'settings_ui_url']
  else
    self.settings_ui_url = nil
  end

  if attributes.key?(:'stylesheet')
    self.stylesheet = attributes[:'stylesheet']
  end

  if attributes.key?(:'translations')
    if (value = attributes[:'translations']).is_a?(Array)
      self.translations = value
    end
  else
    self.translations = nil
  end

  if attributes.key?(:'verification_enabled')
    self.verification_enabled = attributes[:'verification_enabled']
  else
    self.verification_enabled = nil
  end

  if attributes.key?(:'verification_ui_url')
    self.verification_ui_url = attributes[:'verification_ui_url']
  else
    self.verification_ui_url = nil
  end
end

Instance Attribute Details

#default_localeObject

Returns the value of attribute default_locale.



18
19
20
# File 'lib/ory-client/models/account_experience_configuration.rb', line 18

def default_locale
  @default_locale
end

#default_redirect_urlObject

Returns the value of attribute default_redirect_url.



20
21
22
# File 'lib/ory-client/models/account_experience_configuration.rb', line 20

def default_redirect_url
  @default_redirect_url
end

#enabled_localesObject

Returns the value of attribute enabled_locales.



22
23
24
# File 'lib/ory-client/models/account_experience_configuration.rb', line 22

def enabled_locales
  @enabled_locales
end

#error_ui_urlObject

Returns the value of attribute error_ui_url.



24
25
26
# File 'lib/ory-client/models/account_experience_configuration.rb', line 24

def error_ui_url
  @error_ui_url
end

#favicon_dark_urlObject

Returns the value of attribute favicon_dark_url.



26
27
28
# File 'lib/ory-client/models/account_experience_configuration.rb', line 26

def favicon_dark_url
  @favicon_dark_url
end

#favicon_light_urlObject

Returns the value of attribute favicon_light_url.



28
29
30
# File 'lib/ory-client/models/account_experience_configuration.rb', line 28

def favicon_light_url
  @favicon_light_url
end

#hide_ory_brandingObject

Returns the value of attribute hide_ory_branding.



30
31
32
# File 'lib/ory-client/models/account_experience_configuration.rb', line 30

def hide_ory_branding
  @hide_ory_branding
end

Returns the value of attribute hide_registration_link.



32
33
34
# File 'lib/ory-client/models/account_experience_configuration.rb', line 32

def hide_registration_link
  @hide_registration_link
end

#locale_behaviorObject

force_default AccountExperienceLocaleBehaviorForceDefault respect_accept_language AccountExperienceLocaleBehaviorRespectAcceptLanguage



35
36
37
# File 'lib/ory-client/models/account_experience_configuration.rb', line 35

def locale_behavior
  @locale_behavior
end

#login_ui_urlObject

Returns the value of attribute login_ui_url.



37
38
39
# File 'lib/ory-client/models/account_experience_configuration.rb', line 37

def 
  @login_ui_url
end

#logo_dark_urlObject

Returns the value of attribute logo_dark_url.



39
40
41
# File 'lib/ory-client/models/account_experience_configuration.rb', line 39

def logo_dark_url
  @logo_dark_url
end

#logo_light_urlObject

Returns the value of attribute logo_light_url.



41
42
43
# File 'lib/ory-client/models/account_experience_configuration.rb', line 41

def logo_light_url
  @logo_light_url
end

#nameObject

Returns the value of attribute name.



43
44
45
# File 'lib/ory-client/models/account_experience_configuration.rb', line 43

def name
  @name
end

#recovery_enabledObject

Returns the value of attribute recovery_enabled.



45
46
47
# File 'lib/ory-client/models/account_experience_configuration.rb', line 45

def recovery_enabled
  @recovery_enabled
end

#recovery_ui_urlObject

Returns the value of attribute recovery_ui_url.



47
48
49
# File 'lib/ory-client/models/account_experience_configuration.rb', line 47

def recovery_ui_url
  @recovery_ui_url
end

#registration_enabledObject

Returns the value of attribute registration_enabled.



49
50
51
# File 'lib/ory-client/models/account_experience_configuration.rb', line 49

def registration_enabled
  @registration_enabled
end

#registration_ui_urlObject

Returns the value of attribute registration_ui_url.



51
52
53
# File 'lib/ory-client/models/account_experience_configuration.rb', line 51

def registration_ui_url
  @registration_ui_url
end

#settings_ui_urlObject

Returns the value of attribute settings_ui_url.



53
54
55
# File 'lib/ory-client/models/account_experience_configuration.rb', line 53

def settings_ui_url
  @settings_ui_url
end

#stylesheetObject

Returns the value of attribute stylesheet.



55
56
57
# File 'lib/ory-client/models/account_experience_configuration.rb', line 55

def stylesheet
  @stylesheet
end

#translationsObject

Returns the value of attribute translations.



57
58
59
# File 'lib/ory-client/models/account_experience_configuration.rb', line 57

def translations
  @translations
end

#verification_enabledObject

Returns the value of attribute verification_enabled.



59
60
61
# File 'lib/ory-client/models/account_experience_configuration.rb', line 59

def verification_enabled
  @verification_enabled
end

#verification_ui_urlObject

Returns the value of attribute verification_ui_url.



61
62
63
# File 'lib/ory-client/models/account_experience_configuration.rb', line 61

def verification_ui_url
  @verification_ui_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



114
115
116
# File 'lib/ory-client/models/account_experience_configuration.rb', line 114

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/ory-client/models/account_experience_configuration.rb', line 119

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/ory-client/models/account_experience_configuration.rb', line 86

def self.attribute_map
  {
    :'default_locale' => :'default_locale',
    :'default_redirect_url' => :'default_redirect_url',
    :'enabled_locales' => :'enabled_locales',
    :'error_ui_url' => :'error_ui_url',
    :'favicon_dark_url' => :'favicon_dark_url',
    :'favicon_light_url' => :'favicon_light_url',
    :'hide_ory_branding' => :'hide_ory_branding',
    :'hide_registration_link' => :'hide_registration_link',
    :'locale_behavior' => :'locale_behavior',
    :'login_ui_url' => :'login_ui_url',
    :'logo_dark_url' => :'logo_dark_url',
    :'logo_light_url' => :'logo_light_url',
    :'name' => :'name',
    :'recovery_enabled' => :'recovery_enabled',
    :'recovery_ui_url' => :'recovery_ui_url',
    :'registration_enabled' => :'registration_enabled',
    :'registration_ui_url' => :'registration_ui_url',
    :'settings_ui_url' => :'settings_ui_url',
    :'stylesheet' => :'stylesheet',
    :'translations' => :'translations',
    :'verification_enabled' => :'verification_enabled',
    :'verification_ui_url' => :'verification_ui_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/ory-client/models/account_experience_configuration.rb', line 616

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



152
153
154
155
# File 'lib/ory-client/models/account_experience_configuration.rb', line 152

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ory-client/models/account_experience_configuration.rb', line 124

def self.openapi_types
  {
    :'default_locale' => :'String',
    :'default_redirect_url' => :'String',
    :'enabled_locales' => :'Array<String>',
    :'error_ui_url' => :'String',
    :'favicon_dark_url' => :'String',
    :'favicon_light_url' => :'String',
    :'hide_ory_branding' => :'Boolean',
    :'hide_registration_link' => :'Boolean',
    :'locale_behavior' => :'String',
    :'login_ui_url' => :'String',
    :'logo_dark_url' => :'String',
    :'logo_light_url' => :'String',
    :'name' => :'String',
    :'recovery_enabled' => :'Boolean',
    :'recovery_ui_url' => :'String',
    :'registration_enabled' => :'Boolean',
    :'registration_ui_url' => :'String',
    :'settings_ui_url' => :'String',
    :'stylesheet' => :'String',
    :'translations' => :'Array<RevisionAccountExperienceCustomTranslation>',
    :'verification_enabled' => :'Boolean',
    :'verification_ui_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/ory-client/models/account_experience_configuration.rb', line 574

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      default_locale == o.default_locale &&
      default_redirect_url == o.default_redirect_url &&
      enabled_locales == o.enabled_locales &&
      error_ui_url == o.error_ui_url &&
      favicon_dark_url == o.favicon_dark_url &&
      favicon_light_url == o.favicon_light_url &&
      hide_ory_branding == o.hide_ory_branding &&
      hide_registration_link == o.hide_registration_link &&
      locale_behavior == o.locale_behavior &&
       == o. &&
      logo_dark_url == o.logo_dark_url &&
      logo_light_url == o.logo_light_url &&
      name == o.name &&
      recovery_enabled == o.recovery_enabled &&
      recovery_ui_url == o.recovery_ui_url &&
      registration_enabled == o.registration_enabled &&
      registration_ui_url == o.registration_ui_url &&
      settings_ui_url == o.settings_ui_url &&
      stylesheet == o.stylesheet &&
      translations == o.translations &&
      verification_enabled == o.verification_enabled &&
      verification_ui_url == o.verification_ui_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


603
604
605
# File 'lib/ory-client/models/account_experience_configuration.rb', line 603

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



609
610
611
# File 'lib/ory-client/models/account_experience_configuration.rb', line 609

def hash
  [default_locale, default_redirect_url, enabled_locales, error_ui_url, favicon_dark_url, favicon_light_url, hide_ory_branding, hide_registration_link, locale_behavior, , logo_dark_url, logo_light_url, name, recovery_enabled, recovery_ui_url, registration_enabled, registration_ui_url, settings_ui_url, stylesheet, translations, verification_enabled, verification_ui_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/ory-client/models/account_experience_configuration.rb', line 302

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @default_locale.nil?
    invalid_properties.push('invalid value for "default_locale", default_locale cannot be nil.')
  end

  if @default_redirect_url.nil?
    invalid_properties.push('invalid value for "default_redirect_url", default_redirect_url cannot be nil.')
  end

  if @enabled_locales.nil?
    invalid_properties.push('invalid value for "enabled_locales", enabled_locales cannot be nil.')
  end

  if @error_ui_url.nil?
    invalid_properties.push('invalid value for "error_ui_url", error_ui_url cannot be nil.')
  end

  if @hide_ory_branding.nil?
    invalid_properties.push('invalid value for "hide_ory_branding", hide_ory_branding cannot be nil.')
  end

  if @hide_registration_link.nil?
    invalid_properties.push('invalid value for "hide_registration_link", hide_registration_link cannot be nil.')
  end

  if @locale_behavior.nil?
    invalid_properties.push('invalid value for "locale_behavior", locale_behavior cannot be nil.')
  end

  if @login_ui_url.nil?
    invalid_properties.push('invalid value for "login_ui_url", login_ui_url cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @recovery_enabled.nil?
    invalid_properties.push('invalid value for "recovery_enabled", recovery_enabled cannot be nil.')
  end

  if @recovery_ui_url.nil?
    invalid_properties.push('invalid value for "recovery_ui_url", recovery_ui_url cannot be nil.')
  end

  if @registration_enabled.nil?
    invalid_properties.push('invalid value for "registration_enabled", registration_enabled cannot be nil.')
  end

  if @registration_ui_url.nil?
    invalid_properties.push('invalid value for "registration_ui_url", registration_ui_url cannot be nil.')
  end

  if @settings_ui_url.nil?
    invalid_properties.push('invalid value for "settings_ui_url", settings_ui_url cannot be nil.')
  end

  if @translations.nil?
    invalid_properties.push('invalid value for "translations", translations cannot be nil.')
  end

  if @verification_enabled.nil?
    invalid_properties.push('invalid value for "verification_enabled", verification_enabled cannot be nil.')
  end

  if @verification_ui_url.nil?
    invalid_properties.push('invalid value for "verification_ui_url", verification_ui_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



638
639
640
641
642
643
644
645
646
647
648
649
650
# File 'lib/ory-client/models/account_experience_configuration.rb', line 638

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/ory-client/models/account_experience_configuration.rb', line 378

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @default_locale.nil?
  return false if @default_redirect_url.nil?
  return false if @enabled_locales.nil?
  return false if @error_ui_url.nil?
  return false if @hide_ory_branding.nil?
  return false if @hide_registration_link.nil?
  return false if @locale_behavior.nil?
  locale_behavior_validator = EnumAttributeValidator.new('String', ["force_default", "respect_accept_language"])
  return false unless locale_behavior_validator.valid?(@locale_behavior)
  return false if @login_ui_url.nil?
  return false if @name.nil?
  return false if @recovery_enabled.nil?
  return false if @recovery_ui_url.nil?
  return false if @registration_enabled.nil?
  return false if @registration_ui_url.nil?
  return false if @settings_ui_url.nil?
  return false if @translations.nil?
  return false if @verification_enabled.nil?
  return false if @verification_ui_url.nil?
  true
end