Class: OryClient::CreateEventStreamBody

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/create_event_stream_body.rb

Overview

Create Event Stream Request Body

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateEventStreamBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/ory-client/models/create_event_stream_body.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CreateEventStreamBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CreateEventStreamBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'https_endpoint')
    self.https_endpoint = attributes[:'https_endpoint']
  end

  if attributes.key?(:'role_arn')
    self.role_arn = attributes[:'role_arn']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'topic_arn')
    self.topic_arn = attributes[:'topic_arn']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end
end

Instance Attribute Details

#https_endpointObject

The HTTPS endpoint URL to send events to. Required if type is https.



20
21
22
# File 'lib/ory-client/models/create_event_stream_body.rb', line 20

def https_endpoint
  @https_endpoint
end

#role_arnObject

The AWS IAM role ARN to assume when publishing to the SNS topic. Required if type is sns.



23
24
25
# File 'lib/ory-client/models/create_event_stream_body.rb', line 23

def role_arn
  @role_arn
end

#statusObject

The status of the event stream. Defaults to active. A paused stream is created but does not forward any events until it is set to active.



26
27
28
# File 'lib/ory-client/models/create_event_stream_body.rb', line 26

def status
  @status
end

#topic_arnObject

The AWS SNS topic ARN. Required if type is sns.



29
30
31
# File 'lib/ory-client/models/create_event_stream_body.rb', line 29

def topic_arn
  @topic_arn
end

#typeObject

The type of the event stream (AWS SNS or HTTPS webhook).



32
33
34
# File 'lib/ory-client/models/create_event_stream_body.rb', line 32

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ory-client/models/create_event_stream_body.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ory-client/models/create_event_stream_body.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/ory-client/models/create_event_stream_body.rb', line 57

def self.attribute_map
  {
    :'https_endpoint' => :'https_endpoint',
    :'role_arn' => :'role_arn',
    :'status' => :'status',
    :'topic_arn' => :'topic_arn',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/ory-client/models/create_event_stream_body.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/ory-client/models/create_event_stream_body.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/ory-client/models/create_event_stream_body.rb', line 78

def self.openapi_types
  {
    :'https_endpoint' => :'String',
    :'role_arn' => :'String',
    :'status' => :'String',
    :'topic_arn' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
# File 'lib/ory-client/models/create_event_stream_body.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      https_endpoint == o.https_endpoint &&
      role_arn == o.role_arn &&
      status == o.status &&
      topic_arn == o.topic_arn &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/ory-client/models/create_event_stream_body.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/ory-client/models/create_event_stream_body.rb', line 197

def hash
  [https_endpoint, role_arn, status, topic_arn, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
# File 'lib/ory-client/models/create_event_stream_body.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/ory-client/models/create_event_stream_body.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
# File 'lib/ory-client/models/create_event_stream_body.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["active", "paused"])
  return false unless status_validator.valid?(@status)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["sns", "https"])
  return false unless type_validator.valid?(@type)
  true
end