Class: OryClient::CreateIdentityBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::CreateIdentityBody
- Defined in:
- lib/ory-client/models/create_identity_body.rb
Overview
Create Identity Body
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#credentials ⇒ Object
Returns the value of attribute credentials.
-
#external_id ⇒ Object
ExternalID is an optional external ID of the identity.
-
#metadata_admin ⇒ Object
Store metadata about the user which is only accessible through admin APIs such as ‘GET /admin/identities/<id>`.
-
#metadata_public ⇒ Object
Store metadata about the identity which the identity itself can see when calling for example the session endpoint.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#recovery_addresses ⇒ Object
RecoveryAddresses contains all the addresses that can be used to recover an identity.
-
#region ⇒ Object
Region is the Ory Network region this identity will be created in.
-
#schema_id ⇒ Object
SchemaID is the ID of the JSON Schema to be used for validating the identity’s traits.
-
#state ⇒ Object
State is the identity’s state.
-
#traits ⇒ Object
Traits represent an identity’s traits.
-
#verifiable_addresses ⇒ Object
VerifiableAddresses contains all the addresses that can be verified by the user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIdentityBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateIdentityBody
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ory-client/models/create_identity_body.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CreateIdentityBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CreateIdentityBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'credentials') self.credentials = attributes[:'credentials'] end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'metadata_admin') self. = attributes[:'metadata_admin'] end if attributes.key?(:'metadata_public') self. = attributes[:'metadata_public'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'recovery_addresses') if (value = attributes[:'recovery_addresses']).is_a?(Array) self.recovery_addresses = value end end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'schema_id') self.schema_id = attributes[:'schema_id'] else self.schema_id = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'traits') self.traits = attributes[:'traits'] else self.traits = nil end if attributes.key?(:'verifiable_addresses') if (value = attributes[:'verifiable_addresses']).is_a?(Array) self.verifiable_addresses = value end end end |
Instance Attribute Details
#credentials ⇒ Object
Returns the value of attribute credentials.
19 20 21 |
# File 'lib/ory-client/models/create_identity_body.rb', line 19 def credentials @credentials end |
#external_id ⇒ Object
ExternalID is an optional external ID of the identity. This is used to link the identity to an external system. If set, the external ID must be unique across all identities.
22 23 24 |
# File 'lib/ory-client/models/create_identity_body.rb', line 22 def external_id @external_id end |
#metadata_admin ⇒ Object
Store metadata about the user which is only accessible through admin APIs such as ‘GET /admin/identities/<id>`.
25 26 27 |
# File 'lib/ory-client/models/create_identity_body.rb', line 25 def @metadata_admin end |
#metadata_public ⇒ Object
Store metadata about the identity which the identity itself can see when calling for example the session endpoint. Do not store sensitive information (e.g. credit score) about the identity in this field.
28 29 30 |
# File 'lib/ory-client/models/create_identity_body.rb', line 28 def @metadata_public end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
30 31 32 |
# File 'lib/ory-client/models/create_identity_body.rb', line 30 def organization_id @organization_id end |
#recovery_addresses ⇒ Object
RecoveryAddresses contains all the addresses that can be used to recover an identity. Use this structure to import recovery addresses for an identity. Please keep in mind that the address needs to be represented in the Identity Schema or this field will be overwritten on the next identity update.
33 34 35 |
# File 'lib/ory-client/models/create_identity_body.rb', line 33 def recovery_addresses @recovery_addresses end |
#region ⇒ Object
Region is the Ory Network region this identity will be created in. Optional; defaults to the project home region if omitted. Only effective on the Ory Network. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global
36 37 38 |
# File 'lib/ory-client/models/create_identity_body.rb', line 36 def region @region end |
#schema_id ⇒ Object
SchemaID is the ID of the JSON Schema to be used for validating the identity’s traits.
39 40 41 |
# File 'lib/ory-client/models/create_identity_body.rb', line 39 def schema_id @schema_id end |
#state ⇒ Object
State is the identity’s state. active StateActive inactive StateInactive
42 43 44 |
# File 'lib/ory-client/models/create_identity_body.rb', line 42 def state @state end |
#traits ⇒ Object
Traits represent an identity’s traits. The identity is able to create, modify, and delete traits in a self-service manner. The input will always be validated against the JSON Schema defined in ‘schema_url`.
45 46 47 |
# File 'lib/ory-client/models/create_identity_body.rb', line 45 def traits @traits end |
#verifiable_addresses ⇒ Object
VerifiableAddresses contains all the addresses that can be verified by the user. Use this structure to import verified addresses for an identity. Please keep in mind that the address needs to be represented in the Identity Schema or this field will be overwritten on the next identity update.
48 49 50 |
# File 'lib/ory-client/models/create_identity_body.rb', line 48 def verifiable_addresses @verifiable_addresses end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/ory-client/models/create_identity_body.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/ory-client/models/create_identity_body.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/ory-client/models/create_identity_body.rb', line 73 def self.attribute_map { :'credentials' => :'credentials', :'external_id' => :'external_id', :'metadata_admin' => :'metadata_admin', :'metadata_public' => :'metadata_public', :'organization_id' => :'organization_id', :'recovery_addresses' => :'recovery_addresses', :'region' => :'region', :'schema_id' => :'schema_id', :'state' => :'state', :'traits' => :'traits', :'verifiable_addresses' => :'verifiable_addresses' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/ory-client/models/create_identity_body.rb', line 296 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
117 118 119 120 121 122 123 |
# File 'lib/ory-client/models/create_identity_body.rb', line 117 def self.openapi_nullable Set.new([ :'metadata_admin', :'metadata_public', :'organization_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/ory-client/models/create_identity_body.rb', line 100 def self.openapi_types { :'credentials' => :'IdentityWithCredentials', :'external_id' => :'String', :'metadata_admin' => :'Object', :'metadata_public' => :'Object', :'organization_id' => :'String', :'recovery_addresses' => :'Array<RecoveryIdentityAddress>', :'region' => :'String', :'schema_id' => :'String', :'state' => :'String', :'traits' => :'Object', :'verifiable_addresses' => :'Array<VerifiableIdentityAddress>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/ory-client/models/create_identity_body.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && credentials == o.credentials && external_id == o.external_id && == o. && == o. && organization_id == o.organization_id && recovery_addresses == o.recovery_addresses && region == o.region && schema_id == o.schema_id && state == o.state && traits == o.traits && verifiable_addresses == o.verifiable_addresses end |
#eql?(o) ⇒ Boolean
283 284 285 |
# File 'lib/ory-client/models/create_identity_body.rb', line 283 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/ory-client/models/create_identity_body.rb', line 289 def hash [credentials, external_id, , , organization_id, recovery_addresses, region, schema_id, state, traits, verifiable_addresses].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/ory-client/models/create_identity_body.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @schema_id.nil? invalid_properties.push('invalid value for "schema_id", schema_id cannot be nil.') end if @traits.nil? invalid_properties.push('invalid value for "traits", traits cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/ory-client/models/create_identity_body.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/ory-client/models/create_identity_body.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"]) return false unless region_validator.valid?(@region) return false if @schema_id.nil? state_validator = EnumAttributeValidator.new('String', ["active", "inactive"]) return false unless state_validator.valid?(@state) return false if @traits.nil? true end |