Class: OryClient::CustomDomain
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::CustomDomain
- Defined in:
- lib/ory-client/models/custom_domain.rb
Overview
Custom Hostname
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
-
#cors_allowed_origins ⇒ Object
Returns the value of attribute cors_allowed_origins.
-
#cors_enabled ⇒ Object
Returns the value of attribute cors_enabled.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_ui_base_url ⇒ Object
Returns the value of attribute custom_ui_base_url.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Returns the value of attribute id.
-
#ssl_status ⇒ Object
initializing _ pending_validation _ deleted _ pending_issuance _ pending_deployment _ pending_deletion _ pending_expiration _ expired _ active _ initializing_timed_out _ validation_timed_out _ issuance_timed_out _ deployment_timed_out _ deletion_timed_out _ pending_cleanup _ staging_deployment _ staging_active _ deactivating _ inactive _ backup_issued _ holding_deployment _ _ Cloudflare sometimes returns an empty string.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#verification_errors ⇒ Object
Returns the value of attribute verification_errors.
-
#verification_status ⇒ Object
Returns the value of attribute verification_status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomDomain
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomDomain
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ory-client/models/custom_domain.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::CustomDomain` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::CustomDomain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cookie_domain') self. = attributes[:'cookie_domain'] end if attributes.key?(:'cors_allowed_origins') if (value = attributes[:'cors_allowed_origins']).is_a?(Array) self.cors_allowed_origins = value end end if attributes.key?(:'cors_enabled') self.cors_enabled = attributes[:'cors_enabled'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'custom_ui_base_url') self.custom_ui_base_url = attributes[:'custom_ui_base_url'] end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ssl_status') self.ssl_status = attributes[:'ssl_status'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'verification_errors') if (value = attributes[:'verification_errors']).is_a?(Array) self.verification_errors = value end end if attributes.key?(:'verification_status') self.verification_status = attributes[:'verification_status'] end end |
Instance Attribute Details
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
19 20 21 |
# File 'lib/ory-client/models/custom_domain.rb', line 19 def @cookie_domain end |
#cors_allowed_origins ⇒ Object
Returns the value of attribute cors_allowed_origins.
21 22 23 |
# File 'lib/ory-client/models/custom_domain.rb', line 21 def cors_allowed_origins @cors_allowed_origins end |
#cors_enabled ⇒ Object
Returns the value of attribute cors_enabled.
23 24 25 |
# File 'lib/ory-client/models/custom_domain.rb', line 23 def cors_enabled @cors_enabled end |
#created_at ⇒ Object
Returns the value of attribute created_at.
25 26 27 |
# File 'lib/ory-client/models/custom_domain.rb', line 25 def created_at @created_at end |
#custom_ui_base_url ⇒ Object
Returns the value of attribute custom_ui_base_url.
27 28 29 |
# File 'lib/ory-client/models/custom_domain.rb', line 27 def custom_ui_base_url @custom_ui_base_url end |
#hostname ⇒ Object
Returns the value of attribute hostname.
29 30 31 |
# File 'lib/ory-client/models/custom_domain.rb', line 29 def hostname @hostname end |
#id ⇒ Object
Returns the value of attribute id.
31 32 33 |
# File 'lib/ory-client/models/custom_domain.rb', line 31 def id @id end |
#ssl_status ⇒ Object
initializing _ pending_validation _ deleted _ pending_issuance _ pending_deployment _ pending_deletion _ pending_expiration _ expired _ active _ initializing_timed_out _ validation_timed_out _ issuance_timed_out _ deployment_timed_out _ deletion_timed_out _ pending_cleanup _ staging_deployment _ staging_active _ deactivating _ inactive _ backup_issued _ holding_deployment _ _ Cloudflare sometimes returns an empty string.
34 35 36 |
# File 'lib/ory-client/models/custom_domain.rb', line 34 def ssl_status @ssl_status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/ory-client/models/custom_domain.rb', line 36 def updated_at @updated_at end |
#verification_errors ⇒ Object
Returns the value of attribute verification_errors.
38 39 40 |
# File 'lib/ory-client/models/custom_domain.rb', line 38 def verification_errors @verification_errors end |
#verification_status ⇒ Object
Returns the value of attribute verification_status.
40 41 42 |
# File 'lib/ory-client/models/custom_domain.rb', line 40 def verification_status @verification_status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/ory-client/models/custom_domain.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/ory-client/models/custom_domain.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ory-client/models/custom_domain.rb', line 65 def self.attribute_map { :'cookie_domain' => :'cookie_domain', :'cors_allowed_origins' => :'cors_allowed_origins', :'cors_enabled' => :'cors_enabled', :'created_at' => :'created_at', :'custom_ui_base_url' => :'custom_ui_base_url', :'hostname' => :'hostname', :'id' => :'id', :'ssl_status' => :'ssl_status', :'updated_at' => :'updated_at', :'verification_errors' => :'verification_errors', :'verification_status' => :'verification_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/ory-client/models/custom_domain.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/ory-client/models/custom_domain.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/ory-client/models/custom_domain.rb', line 92 def self.openapi_types { :'cookie_domain' => :'String', :'cors_allowed_origins' => :'Array<String>', :'cors_enabled' => :'Boolean', :'created_at' => :'Time', :'custom_ui_base_url' => :'String', :'hostname' => :'String', :'id' => :'String', :'ssl_status' => :'String', :'updated_at' => :'Time', :'verification_errors' => :'Array<String>', :'verification_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ory-client/models/custom_domain.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && cors_allowed_origins == o.cors_allowed_origins && cors_enabled == o.cors_enabled && created_at == o.created_at && custom_ui_base_url == o.custom_ui_base_url && hostname == o.hostname && id == o.id && ssl_status == o.ssl_status && updated_at == o.updated_at && verification_errors == o.verification_errors && verification_status == o.verification_status end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/ory-client/models/custom_domain.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/ory-client/models/custom_domain.rb', line 232 def hash [, cors_allowed_origins, cors_enabled, created_at, custom_ui_base_url, hostname, id, ssl_status, updated_at, verification_errors, verification_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 |
# File 'lib/ory-client/models/custom_domain.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/ory-client/models/custom_domain.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 |
# File 'lib/ory-client/models/custom_domain.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' ssl_status_validator = EnumAttributeValidator.new('String', ["initializing", "pending_validation", "deleted", "pending_issuance", "pending_deployment", "pending_deletion", "pending_expiration", "expired", "active", "initializing_timed_out", "validation_timed_out", "issuance_timed_out", "deployment_timed_out", "deletion_timed_out", "pending_cleanup", "staging_deployment", "staging_active", "deactivating", "inactive", "backup_issued", "holding_deployment", ""]) return false unless ssl_status_validator.valid?(@ssl_status) true end |