Class: OryClient::DeriveTokenRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::DeriveTokenRequest
- Defined in:
- lib/ory-client/models/derive_token_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#algorithm ⇒ Object
Returns the value of attribute algorithm.
-
#credential ⇒ Object
Returns the value of attribute credential.
-
#custom_claims ⇒ Object
custom_claims is a JSON object whose entries are merged into the JWT payload (or macaroon caveats) at signing time.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#ttl ⇒ Object
ttl sets the expiry as a duration from now.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeriveTokenRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeriveTokenRequest
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/ory-client/models/derive_token_request.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeriveTokenRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeriveTokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'algorithm') self.algorithm = attributes[:'algorithm'] else self.algorithm = 'TOKEN_ALGORITHM_UNSPECIFIED' end if attributes.key?(:'credential') self.credential = attributes[:'credential'] end if attributes.key?(:'custom_claims') self.custom_claims = attributes[:'custom_claims'] end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end end if attributes.key?(:'ttl') self.ttl = attributes[:'ttl'] end end |
Instance Attribute Details
#algorithm ⇒ Object
Returns the value of attribute algorithm.
18 19 20 |
# File 'lib/ory-client/models/derive_token_request.rb', line 18 def algorithm @algorithm end |
#credential ⇒ Object
Returns the value of attribute credential.
20 21 22 |
# File 'lib/ory-client/models/derive_token_request.rb', line 20 def credential @credential end |
#custom_claims ⇒ Object
custom_claims is a JSON object whose entries are merged into the JWT payload (or macaroon caveats) at signing time. Reserved JWT claims (iss, sub, aud, exp, nbf, iat, jti) are rejected. Total serialized size is capped at 4KB.
23 24 25 |
# File 'lib/ory-client/models/derive_token_request.rb', line 23 def custom_claims @custom_claims end |
#scopes ⇒ Object
Returns the value of attribute scopes.
25 26 27 |
# File 'lib/ory-client/models/derive_token_request.rb', line 25 def scopes @scopes end |
#ttl ⇒ Object
ttl sets the expiry as a duration from now. Encoded as a google.protobuf.Duration (string ending in "s", e.g. "3600s"). Accepted bounds: 1s to 315360000s (~10 years). If unset or zero, the project default TTL applies. For convenience, the server also accepts Go-style duration strings ("24h", "30m", "1h30m") and an extended unit set ("1d", "1w", "1mo", "1y"; approximations: 1mo = 30d, 1y = 365d). Clients should prefer the standard Duration encoding for portability.
28 29 30 |
# File 'lib/ory-client/models/derive_token_request.rb', line 28 def ttl @ttl end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/ory-client/models/derive_token_request.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/ory-client/models/derive_token_request.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 |
# File 'lib/ory-client/models/derive_token_request.rb', line 53 def self.attribute_map { :'algorithm' => :'algorithm', :'credential' => :'credential', :'custom_claims' => :'custom_claims', :'scopes' => :'scopes', :'ttl' => :'ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ory-client/models/derive_token_request.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/ory-client/models/derive_token_request.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 |
# File 'lib/ory-client/models/derive_token_request.rb', line 74 def self.openapi_types { :'algorithm' => :'TokenAlgorithm', :'credential' => :'String', :'custom_claims' => :'Object', :'scopes' => :'Array<String>', :'ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 |
# File 'lib/ory-client/models/derive_token_request.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && algorithm == o.algorithm && credential == o.credential && custom_claims == o.custom_claims && scopes == o.scopes && ttl == o.ttl end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/ory-client/models/derive_token_request.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/ory-client/models/derive_token_request.rb', line 166 def hash [algorithm, credential, custom_claims, scopes, ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 |
# File 'lib/ory-client/models/derive_token_request.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/ory-client/models/derive_token_request.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 |
# File 'lib/ory-client/models/derive_token_request.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |