Class: OryClient::DeviceAuthnKey

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/device_authn_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceAuthnKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/ory-client/models/device_authn_key.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeviceAuthnKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeviceAuthnKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attestation')
    self.attestation = attributes[:'attestation']
  end

  if attributes.key?(:'client_key_id')
    self.client_key_id = attributes[:'client_key_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'device_name')
    self.device_name = attributes[:'device_name']
  end

  if attributes.key?(:'device_type')
    self.device_type = attributes[:'device_type']
  end

  if attributes.key?(:'public_key')
    if (value = attributes[:'public_key']).is_a?(Array)
      self.public_key = value
    end
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#attestationObject

Returns the value of attribute attestation.



18
19
20
# File 'lib/ory-client/models/device_authn_key.rb', line 18

def attestation
  @attestation
end

#client_key_idObject

ClientKeyID is a client-chosen id for the key and is unique per identity.



21
22
23
# File 'lib/ory-client/models/device_authn_key.rb', line 21

def client_key_id
  @client_key_id
end

#created_atObject

CreatedAt is the timestamp of when the key was created. Only used for troubleshooting/UI.



24
25
26
# File 'lib/ory-client/models/device_authn_key.rb', line 24

def created_at
  @created_at
end

#device_nameObject

DeviceName is a human readable name for the device, helping the user to distinguish it from others.



27
28
29
# File 'lib/ory-client/models/device_authn_key.rb', line 27

def device_name
  @device_name
end

#device_typeObject

Returns the value of attribute device_type.



29
30
31
# File 'lib/ory-client/models/device_authn_key.rb', line 29

def device_type
  @device_type
end

#public_keyObject

PublicKey is an EC (in v1) public key, used to verify signatures, stored as uncompressed bytes. The private key resides inside the device and does not exist on the server.



32
33
34
# File 'lib/ory-client/models/device_authn_key.rb', line 32

def public_key
  @public_key
end

#stateObject

Returns the value of attribute state.



34
35
36
# File 'lib/ory-client/models/device_authn_key.rb', line 34

def state
  @state
end

#versionObject

v1 uses SHA256 + EC256. v2 (in the future) may use ML-DSA which is post-quantum resistant. This requires Android/iOS support so we have to wait. We intentionally avoid storing the cryptographic algorithm here a la JWT/TLS to avoid security issues and algorithm negotiation.



37
38
39
# File 'lib/ory-client/models/device_authn_key.rb', line 37

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/ory-client/models/device_authn_key.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/ory-client/models/device_authn_key.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/ory-client/models/device_authn_key.rb', line 40

def self.attribute_map
  {
    :'attestation' => :'attestation',
    :'client_key_id' => :'client_key_id',
    :'created_at' => :'created_at',
    :'device_name' => :'device_name',
    :'device_type' => :'device_type',
    :'public_key' => :'public_key',
    :'state' => :'state',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/ory-client/models/device_authn_key.rb', line 179

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/ory-client/models/device_authn_key.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/ory-client/models/device_authn_key.rb', line 64

def self.openapi_types
  {
    :'attestation' => :'DeviceAuthnAttestation',
    :'client_key_id' => :'String',
    :'created_at' => :'Time',
    :'device_name' => :'String',
    :'device_type' => :'String',
    :'public_key' => :'Array<Integer>',
    :'state' => :'String',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/ory-client/models/device_authn_key.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attestation == o.attestation &&
      client_key_id == o.client_key_id &&
      created_at == o.created_at &&
      device_name == o.device_name &&
      device_type == o.device_type &&
      public_key == o.public_key &&
      state == o.state &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/ory-client/models/device_authn_key.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/ory-client/models/device_authn_key.rb', line 172

def hash
  [attestation, client_key_id, created_at, device_name, device_type, public_key, state, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/ory-client/models/device_authn_key.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/ory-client/models/device_authn_key.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
# File 'lib/ory-client/models/device_authn_key.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end