Class: OryClient::DeviceAuthnKey

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/device_authn_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceAuthnKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ory-client/models/device_authn_key.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeviceAuthnKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeviceAuthnKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_key_id')
    self.client_key_id = attributes[:'client_key_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'device_name')
    self.device_name = attributes[:'device_name']
  end

  if attributes.key?(:'device_type')
    self.device_type = attributes[:'device_type']
  end

  if attributes.key?(:'public_key')
    if (value = attributes[:'public_key']).is_a?(Array)
      self.public_key = value
    end
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#client_key_idObject

ClientKeyID is a client-chosen id for the key and is unique per identity.



19
20
21
# File 'lib/ory-client/models/device_authn_key.rb', line 19

def client_key_id
  @client_key_id
end

#created_atObject

CreatedAt is the timestamp of when the key was created. Only used for troubleshooting/UI.



22
23
24
# File 'lib/ory-client/models/device_authn_key.rb', line 22

def created_at
  @created_at
end

#device_nameObject

DeviceName is a human readable name for the device, helping the user to distinguish it from others.



25
26
27
# File 'lib/ory-client/models/device_authn_key.rb', line 25

def device_name
  @device_name
end

#device_typeObject

Returns the value of attribute device_type.



27
28
29
# File 'lib/ory-client/models/device_authn_key.rb', line 27

def device_type
  @device_type
end

#public_keyObject

PublicKey is an EC (in v1) public key, used to verify signatures, stored as uncompressed bytes. The private key resides inside the device and does not exist on the server.



30
31
32
# File 'lib/ory-client/models/device_authn_key.rb', line 30

def public_key
  @public_key
end

#stateObject

Returns the value of attribute state.



32
33
34
# File 'lib/ory-client/models/device_authn_key.rb', line 32

def state
  @state
end

#versionObject

v1 uses SHA256 + EC256. v2 (in the future) may use ML-DSA which is post-quantum resistant. This requires Android/iOS support so we have to wait. We intentionally avoid storing the cryptographic algorithm here a la JWT/TLS to avoid security issues and algorithm negotiation.



35
36
37
# File 'lib/ory-client/models/device_authn_key.rb', line 35

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/ory-client/models/device_authn_key.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/ory-client/models/device_authn_key.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/ory-client/models/device_authn_key.rb', line 38

def self.attribute_map
  {
    :'client_key_id' => :'client_key_id',
    :'created_at' => :'created_at',
    :'device_name' => :'device_name',
    :'device_type' => :'device_type',
    :'public_key' => :'public_key',
    :'state' => :'state',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ory-client/models/device_authn_key.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/ory-client/models/device_authn_key.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ory-client/models/device_authn_key.rb', line 61

def self.openapi_types
  {
    :'client_key_id' => :'String',
    :'created_at' => :'Time',
    :'device_name' => :'String',
    :'device_type' => :'String',
    :'public_key' => :'Array<Integer>',
    :'state' => :'String',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ory-client/models/device_authn_key.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_key_id == o.client_key_id &&
      created_at == o.created_at &&
      device_name == o.device_name &&
      device_type == o.device_type &&
      public_key == o.public_key &&
      state == o.state &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/ory-client/models/device_authn_key.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/ory-client/models/device_authn_key.rb', line 163

def hash
  [client_key_id, created_at, device_name, device_type, public_key, state, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
# File 'lib/ory-client/models/device_authn_key.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/ory-client/models/device_authn_key.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
# File 'lib/ory-client/models/device_authn_key.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end