Class: OryClient::DeviceUserAuthRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::DeviceUserAuthRequest
- Defined in:
- lib/ory-client/models/device_user_auth_request.rb
Instance Attribute Summary collapse
-
#challenge ⇒ Object
ID is the identifier ("device challenge") of the device grant request.
-
#client ⇒ Object
Returns the value of attribute client.
-
#handled_at ⇒ Object
Returns the value of attribute handled_at.
-
#request_url ⇒ Object
RequestURL is the original Device Authorization URL requested.
-
#requested_access_token_audience ⇒ Object
RequestedAudience contains the access token audience as requested by the OAuth 2.0 Client.
-
#requested_scope ⇒ Object
RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceUserAuthRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeviceUserAuthRequest
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::DeviceUserAuthRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::DeviceUserAuthRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'challenge') self.challenge = attributes[:'challenge'] else self.challenge = nil end if attributes.key?(:'client') self.client = attributes[:'client'] end if attributes.key?(:'handled_at') self.handled_at = attributes[:'handled_at'] end if attributes.key?(:'request_url') self.request_url = attributes[:'request_url'] end if attributes.key?(:'requested_access_token_audience') if (value = attributes[:'requested_access_token_audience']).is_a?(Array) self.requested_access_token_audience = value end end if attributes.key?(:'requested_scope') if (value = attributes[:'requested_scope']).is_a?(Array) self.requested_scope = value end end end |
Instance Attribute Details
#challenge ⇒ Object
ID is the identifier ("device challenge") of the device grant request. It is used to identify the session.
19 20 21 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 19 def challenge @challenge end |
#client ⇒ Object
Returns the value of attribute client.
21 22 23 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 21 def client @client end |
#handled_at ⇒ Object
Returns the value of attribute handled_at.
23 24 25 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 23 def handled_at @handled_at end |
#request_url ⇒ Object
RequestURL is the original Device Authorization URL requested.
26 27 28 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 26 def request_url @request_url end |
#requested_access_token_audience ⇒ Object
RequestedAudience contains the access token audience as requested by the OAuth 2.0 Client.
29 30 31 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 29 def requested_access_token_audience @requested_access_token_audience end |
#requested_scope ⇒ Object
RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.
32 33 34 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 32 def requested_scope @requested_scope end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 35 def self.attribute_map { :'challenge' => :'challenge', :'client' => :'client', :'handled_at' => :'handled_at', :'request_url' => :'request_url', :'requested_access_token_audience' => :'requested_access_token_audience', :'requested_scope' => :'requested_scope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 57 def self.openapi_types { :'challenge' => :'String', :'client' => :'OAuth2Client', :'handled_at' => :'Time', :'request_url' => :'String', :'requested_access_token_audience' => :'Array<String>', :'requested_scope' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && challenge == o.challenge && client == o.client && handled_at == o.handled_at && request_url == o.request_url && requested_access_token_audience == o.requested_access_token_audience && requested_scope == o.requested_scope end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 172 def hash [challenge, client, handled_at, request_url, requested_access_token_audience, requested_scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @challenge.nil? invalid_properties.push('invalid value for "challenge", challenge cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 |
# File 'lib/ory-client/models/device_user_auth_request.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @challenge.nil? true end |