Class: OryClient::EventStream
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::EventStream
- Defined in:
- lib/ory-client/models/event_stream.rb
Overview
Event Stream
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#https_endpoint ⇒ Object
Returns the value of attribute https_endpoint.
-
#id ⇒ Object
Returns the value of attribute id.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#status ⇒ Object
The status of the event stream.
-
#topic_arn ⇒ Object
Returns the value of attribute topic_arn.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventStream
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventStream
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/ory-client/models/event_stream.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::EventStream` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::EventStream`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'https_endpoint') self.https_endpoint = attributes[:'https_endpoint'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'role_arn') self.role_arn = attributes[:'role_arn'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'topic_arn') self.topic_arn = attributes[:'topic_arn'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
19 20 21 |
# File 'lib/ory-client/models/event_stream.rb', line 19 def created_at @created_at end |
#https_endpoint ⇒ Object
Returns the value of attribute https_endpoint.
21 22 23 |
# File 'lib/ory-client/models/event_stream.rb', line 21 def https_endpoint @https_endpoint end |
#id ⇒ Object
Returns the value of attribute id.
23 24 25 |
# File 'lib/ory-client/models/event_stream.rb', line 23 def id @id end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
25 26 27 |
# File 'lib/ory-client/models/event_stream.rb', line 25 def role_arn @role_arn end |
#status ⇒ Object
The status of the event stream. A paused event stream does not forward any events until it is set back to active.
28 29 30 |
# File 'lib/ory-client/models/event_stream.rb', line 28 def status @status end |
#topic_arn ⇒ Object
Returns the value of attribute topic_arn.
30 31 32 |
# File 'lib/ory-client/models/event_stream.rb', line 30 def topic_arn @topic_arn end |
#type ⇒ Object
Returns the value of attribute type.
32 33 34 |
# File 'lib/ory-client/models/event_stream.rb', line 32 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
34 35 36 |
# File 'lib/ory-client/models/event_stream.rb', line 34 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/ory-client/models/event_stream.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/ory-client/models/event_stream.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/ory-client/models/event_stream.rb', line 59 def self.attribute_map { :'created_at' => :'created_at', :'https_endpoint' => :'https_endpoint', :'id' => :'id', :'role_arn' => :'role_arn', :'status' => :'status', :'topic_arn' => :'topic_arn', :'type' => :'type', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/ory-client/models/event_stream.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 |
# File 'lib/ory-client/models/event_stream.rb', line 97 def self.openapi_nullable Set.new([ :'https_endpoint', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ory-client/models/event_stream.rb', line 83 def self.openapi_types { :'created_at' => :'Time', :'https_endpoint' => :'String', :'id' => :'String', :'role_arn' => :'String', :'status' => :'String', :'topic_arn' => :'String', :'type' => :'String', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ory-client/models/event_stream.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && https_endpoint == o.https_endpoint && id == o.id && role_arn == o.role_arn && status == o.status && topic_arn == o.topic_arn && type == o.type && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/ory-client/models/event_stream.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/ory-client/models/event_stream.rb', line 202 def hash [created_at, https_endpoint, id, role_arn, status, topic_arn, type, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 |
# File 'lib/ory-client/models/event_stream.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/ory-client/models/event_stream.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 |
# File 'lib/ory-client/models/event_stream.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["active", "paused"]) return false unless status_validator.valid?(@status) true end |