Class: OryClient::GetJWKSResponseJwksKeysInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::GetJWKSResponseJwksKeysInner
- Defined in:
- lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb
Instance Attribute Summary collapse
-
#alg ⇒ Object
Returns the value of attribute alg.
-
#crv ⇒ Object
Returns the value of attribute crv.
-
#e ⇒ Object
Returns the value of attribute e.
-
#kid ⇒ Object
Returns the value of attribute kid.
-
#kty ⇒ Object
Returns the value of attribute kty.
-
#n ⇒ Object
Returns the value of attribute n.
-
#use ⇒ Object
Returns the value of attribute use.
-
#x ⇒ Object
Returns the value of attribute x.
-
#y ⇒ Object
Returns the value of attribute y.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetJWKSResponseJwksKeysInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetJWKSResponseJwksKeysInner
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::GetJWKSResponseJwksKeysInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::GetJWKSResponseJwksKeysInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'alg') self.alg = attributes[:'alg'] end if attributes.key?(:'crv') self.crv = attributes[:'crv'] end if attributes.key?(:'e') self.e = attributes[:'e'] end if attributes.key?(:'kid') self.kid = attributes[:'kid'] else self.kid = nil end if attributes.key?(:'kty') self.kty = attributes[:'kty'] else self.kty = nil end if attributes.key?(:'n') self.n = attributes[:'n'] end if attributes.key?(:'use') self.use = attributes[:'use'] end if attributes.key?(:'x') self.x = attributes[:'x'] end if attributes.key?(:'y') self.y = attributes[:'y'] end end |
Instance Attribute Details
#alg ⇒ Object
Returns the value of attribute alg.
18 19 20 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 18 def alg @alg end |
#crv ⇒ Object
Returns the value of attribute crv.
20 21 22 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 20 def crv @crv end |
#e ⇒ Object
Returns the value of attribute e.
22 23 24 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 22 def e @e end |
#kid ⇒ Object
Returns the value of attribute kid.
24 25 26 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 24 def kid @kid end |
#kty ⇒ Object
Returns the value of attribute kty.
26 27 28 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 26 def kty @kty end |
#n ⇒ Object
Returns the value of attribute n.
28 29 30 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 28 def n @n end |
#use ⇒ Object
Returns the value of attribute use.
30 31 32 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 30 def use @use end |
#x ⇒ Object
Returns the value of attribute x.
32 33 34 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 32 def x @x end |
#y ⇒ Object
Returns the value of attribute y.
34 35 36 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 34 def y @y end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 37 def self.attribute_map { :'alg' => :'alg', :'crv' => :'crv', :'e' => :'e', :'kid' => :'kid', :'kty' => :'kty', :'n' => :'n', :'use' => :'use', :'x' => :'x', :'y' => :'y' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 62 def self.openapi_types { :'alg' => :'String', :'crv' => :'String', :'e' => :'String', :'kid' => :'String', :'kty' => :'String', :'n' => :'String', :'use' => :'String', :'x' => :'String', :'y' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && alg == o.alg && crv == o.crv && e == o.e && kid == o.kid && kty == o.kty && n == o.n && use == o.use && x == o.x && y == o.y end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 208 def hash [alg, crv, e, kid, kty, n, use, x, y].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kid.nil? invalid_properties.push('invalid value for "kid", kid cannot be nil.') end if @kty.nil? invalid_properties.push('invalid value for "kty", kty cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 |
# File 'lib/ory-client/models/get_jwks_response_jwks_keys_inner.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kid.nil? return false if @kty.nil? true end |