Class: OryClient::Identity
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::Identity
- Defined in:
- lib/ory-client/models/identity.rb
Overview
An [identity](www.ory.com/docs/kratos/concepts/identity-user-model) represents a (human) user in Ory.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
CreatedAt is a helper struct field for gobuffalo.pop.
-
#credentials ⇒ Object
Credentials represents all credentials that can be used for authenticating this identity.
-
#external_id ⇒ Object
ExternalID is an optional external ID of the identity.
-
#id ⇒ Object
ID is the identity’s unique identifier.
-
#metadata_admin ⇒ Object
NullJSONRawMessage represents a json.RawMessage that works well with JSON, SQL, and Swagger and is NULLable-.
-
#metadata_public ⇒ Object
NullJSONRawMessage represents a json.RawMessage that works well with JSON, SQL, and Swagger and is NULLable-.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#recovery_addresses ⇒ Object
RecoveryAddresses contains all the addresses that can be used to recover an identity.
-
#region ⇒ Object
Region is the Ory Network region this identity is homed in.
-
#schema_id ⇒ Object
SchemaID is the ID of the JSON Schema to be used for validating the identity’s traits.
-
#schema_url ⇒ Object
SchemaURL is the URL of the endpoint where the identity’s traits schema can be fetched from.
-
#state ⇒ Object
State is the identity’s state.
-
#state_changed_at ⇒ Object
Returns the value of attribute state_changed_at.
-
#traits ⇒ Object
Traits represent an identity’s traits.
-
#updated_at ⇒ Object
UpdatedAt is a helper struct field for gobuffalo.pop.
-
#verifiable_addresses ⇒ Object
VerifiableAddresses contains all the addresses that can be verified by the user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Identity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Identity
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/ory-client/models/identity.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::Identity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::Identity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'credentials') if (value = attributes[:'credentials']).is_a?(Hash) self.credentials = value end end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'metadata_admin') self. = attributes[:'metadata_admin'] end if attributes.key?(:'metadata_public') self. = attributes[:'metadata_public'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'recovery_addresses') if (value = attributes[:'recovery_addresses']).is_a?(Array) self.recovery_addresses = value end end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'schema_id') self.schema_id = attributes[:'schema_id'] else self.schema_id = nil end if attributes.key?(:'schema_url') self.schema_url = attributes[:'schema_url'] else self.schema_url = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'state_changed_at') self.state_changed_at = attributes[:'state_changed_at'] end if attributes.key?(:'traits') self.traits = attributes[:'traits'] else self.traits = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'verifiable_addresses') if (value = attributes[:'verifiable_addresses']).is_a?(Array) self.verifiable_addresses = value end end end |
Instance Attribute Details
#created_at ⇒ Object
CreatedAt is a helper struct field for gobuffalo.pop.
20 21 22 |
# File 'lib/ory-client/models/identity.rb', line 20 def created_at @created_at end |
#credentials ⇒ Object
Credentials represents all credentials that can be used for authenticating this identity.
23 24 25 |
# File 'lib/ory-client/models/identity.rb', line 23 def credentials @credentials end |
#external_id ⇒ Object
ExternalID is an optional external ID of the identity. This is used to link the identity to an external system. If set, the external ID must be unique across all identities.
26 27 28 |
# File 'lib/ory-client/models/identity.rb', line 26 def external_id @external_id end |
#id ⇒ Object
ID is the identity’s unique identifier. The Identity ID can not be changed and can not be chosen. This ensures future compatibility and optimization for distributed stores such as CockroachDB.
29 30 31 |
# File 'lib/ory-client/models/identity.rb', line 29 def id @id end |
#metadata_admin ⇒ Object
NullJSONRawMessage represents a json.RawMessage that works well with JSON, SQL, and Swagger and is NULLable-
32 33 34 |
# File 'lib/ory-client/models/identity.rb', line 32 def @metadata_admin end |
#metadata_public ⇒ Object
NullJSONRawMessage represents a json.RawMessage that works well with JSON, SQL, and Swagger and is NULLable-
35 36 37 |
# File 'lib/ory-client/models/identity.rb', line 35 def @metadata_public end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
37 38 39 |
# File 'lib/ory-client/models/identity.rb', line 37 def organization_id @organization_id end |
#recovery_addresses ⇒ Object
RecoveryAddresses contains all the addresses that can be used to recover an identity.
40 41 42 |
# File 'lib/ory-client/models/identity.rb', line 40 def recovery_addresses @recovery_addresses end |
#region ⇒ Object
Region is the Ory Network region this identity is homed in. Set by the multi-region persister; empty on OSS and single-region deployments. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global
43 44 45 |
# File 'lib/ory-client/models/identity.rb', line 43 def region @region end |
#schema_id ⇒ Object
SchemaID is the ID of the JSON Schema to be used for validating the identity’s traits.
46 47 48 |
# File 'lib/ory-client/models/identity.rb', line 46 def schema_id @schema_id end |
#schema_url ⇒ Object
SchemaURL is the URL of the endpoint where the identity’s traits schema can be fetched from. format: url
49 50 51 |
# File 'lib/ory-client/models/identity.rb', line 49 def schema_url @schema_url end |
#state ⇒ Object
State is the identity’s state. This value has currently no effect. active StateActive inactive StateInactive
52 53 54 |
# File 'lib/ory-client/models/identity.rb', line 52 def state @state end |
#state_changed_at ⇒ Object
Returns the value of attribute state_changed_at.
54 55 56 |
# File 'lib/ory-client/models/identity.rb', line 54 def state_changed_at @state_changed_at end |
#traits ⇒ Object
Traits represent an identity’s traits. The identity is able to create, modify, and delete traits in a self-service manner. The input will always be validated against the JSON Schema defined in ‘schema_url`.
57 58 59 |
# File 'lib/ory-client/models/identity.rb', line 57 def traits @traits end |
#updated_at ⇒ Object
UpdatedAt is a helper struct field for gobuffalo.pop.
60 61 62 |
# File 'lib/ory-client/models/identity.rb', line 60 def updated_at @updated_at end |
#verifiable_addresses ⇒ Object
VerifiableAddresses contains all the addresses that can be verified by the user.
63 64 65 |
# File 'lib/ory-client/models/identity.rb', line 63 def verifiable_addresses @verifiable_addresses end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
110 111 112 |
# File 'lib/ory-client/models/identity.rb', line 110 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
115 116 117 |
# File 'lib/ory-client/models/identity.rb', line 115 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/ory-client/models/identity.rb', line 88 def self.attribute_map { :'created_at' => :'created_at', :'credentials' => :'credentials', :'external_id' => :'external_id', :'id' => :'id', :'metadata_admin' => :'metadata_admin', :'metadata_public' => :'metadata_public', :'organization_id' => :'organization_id', :'recovery_addresses' => :'recovery_addresses', :'region' => :'region', :'schema_id' => :'schema_id', :'schema_url' => :'schema_url', :'state' => :'state', :'state_changed_at' => :'state_changed_at', :'traits' => :'traits', :'updated_at' => :'updated_at', :'verifiable_addresses' => :'verifiable_addresses' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/ory-client/models/identity.rb', line 368 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 146 147 148 149 |
# File 'lib/ory-client/models/identity.rb', line 142 def self.openapi_nullable Set.new([ :'metadata_admin', :'metadata_public', :'organization_id', :'traits', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/ory-client/models/identity.rb', line 120 def self.openapi_types { :'created_at' => :'Time', :'credentials' => :'Hash<String, IdentityCredentials>', :'external_id' => :'String', :'id' => :'String', :'metadata_admin' => :'Object', :'metadata_public' => :'Object', :'organization_id' => :'String', :'recovery_addresses' => :'Array<RecoveryIdentityAddress>', :'region' => :'String', :'schema_id' => :'String', :'schema_url' => :'String', :'state' => :'String', :'state_changed_at' => :'Time', :'traits' => :'Object', :'updated_at' => :'Time', :'verifiable_addresses' => :'Array<VerifiableIdentityAddress>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/ory-client/models/identity.rb', line 332 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && credentials == o.credentials && external_id == o.external_id && id == o.id && == o. && == o. && organization_id == o.organization_id && recovery_addresses == o.recovery_addresses && region == o.region && schema_id == o.schema_id && schema_url == o.schema_url && state == o.state && state_changed_at == o.state_changed_at && traits == o.traits && updated_at == o.updated_at && verifiable_addresses == o.verifiable_addresses end |
#eql?(o) ⇒ Boolean
355 356 357 |
# File 'lib/ory-client/models/identity.rb', line 355 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
361 362 363 |
# File 'lib/ory-client/models/identity.rb', line 361 def hash [created_at, credentials, external_id, id, , , organization_id, recovery_addresses, region, schema_id, schema_url, state, state_changed_at, traits, updated_at, verifiable_addresses].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/ory-client/models/identity.rb', line 248 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @schema_id.nil? invalid_properties.push('invalid value for "schema_id", schema_id cannot be nil.') end if @schema_url.nil? invalid_properties.push('invalid value for "schema_url", schema_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/ory-client/models/identity.rb', line 390 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/ory-client/models/identity.rb', line 268 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"]) return false unless region_validator.valid?(@region) return false if @schema_id.nil? return false if @schema_url.nil? state_validator = EnumAttributeValidator.new('String', ["active", "inactive"]) return false unless state_validator.valid?(@state) true end |