Class: OryClient::NormalizedProjectRevisionThirdPartyProvider

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ory-client/models/normalized_project_revision_third_party_provider.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NormalizedProjectRevisionThirdPartyProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 218

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::NormalizedProjectRevisionThirdPartyProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::NormalizedProjectRevisionThirdPartyProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_linking_mode')
    self. = attributes[:'account_linking_mode']
  end

  if attributes.key?(:'additional_id_token_audiences')
    if (value = attributes[:'additional_id_token_audiences']).is_a?(Array)
      self.additional_id_token_audiences = value
    end
  end

  if attributes.key?(:'apple_private_key')
    self.apple_private_key = attributes[:'apple_private_key']
  end

  if attributes.key?(:'apple_private_key_id')
    self.apple_private_key_id = attributes[:'apple_private_key_id']
  end

  if attributes.key?(:'apple_team_id')
    self.apple_team_id = attributes[:'apple_team_id']
  end

  if attributes.key?(:'auth_url')
    self.auth_url = attributes[:'auth_url']
  end

  if attributes.key?(:'azure_tenant')
    self.azure_tenant = attributes[:'azure_tenant']
  end

  if attributes.key?(:'claims_source')
    self.claims_source = attributes[:'claims_source']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'fedcm_config_url')
    self.fedcm_config_url = attributes[:'fedcm_config_url']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'issuer_url')
    self.issuer_url = attributes[:'issuer_url']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'mapper_url')
    self.mapper_url = attributes[:'mapper_url']
  end

  if attributes.key?(:'net_id_token_origin_header')
    self.net_id_token_origin_header = attributes[:'net_id_token_origin_header']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'pkce')
    self.pkce = attributes[:'pkce']
  end

  if attributes.key?(:'project_revision_id')
    self.project_revision_id = attributes[:'project_revision_id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'provider_id')
    self.provider_id = attributes[:'provider_id']
  end

  if attributes.key?(:'proxy_oidc_redirect_url')
    self.proxy_oidc_redirect_url = attributes[:'proxy_oidc_redirect_url']
  end

  if attributes.key?(:'requested_claims')
    self.requested_claims = attributes[:'requested_claims']
  end

  if attributes.key?(:'scope')
    if (value = attributes[:'scope']).is_a?(Array)
      self.scope = value
    end
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'subject_source')
    self.subject_source = attributes[:'subject_source']
  end

  if attributes.key?(:'token_url')
    self.token_url = attributes[:'token_url']
  end

  if attributes.key?(:'update_identity_on_login')
    self. = attributes[:'update_identity_on_login']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#account_linking_modeObject

AccountLinkingMode controls how account conflicts are resolved for this provider. Possible values are ‘confirm_with_existing_credential` (default) and `automatic`. `automatic` silently links accounts when the provider verifies email ownership. Only supported for `apple` and `google` providers. automatic AccountLinkingModeAutomatic AccountLinkingModeAutomatic silently links accounts if the provider verifies email ownership. confirm_with_existing_credential AccountLinkingModeConfirmWithExistingCredential AccountLinkingModeConfirmWithExistingCredential requires the user to confirm the account linking by providing an existing credential.



19
20
21
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 19

def 
  @account_linking_mode
end

#additional_id_token_audiencesObject

AdditionalIDTokenAudiences is a list of additional audiences allowed in the ID Token. This is only relevant in OIDC flows that submit an IDToken instead of using the callback from the OIDC provider.



22
23
24
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 22

def additional_id_token_audiences
  @additional_id_token_audiences
end

#apple_private_keyObject

Returns the value of attribute apple_private_key.



24
25
26
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 24

def apple_private_key
  @apple_private_key
end

#apple_private_key_idObject

Apple Private Key Identifier Sign In with Apple Private Key Identifier needed for generating a JWT token for client secret



27
28
29
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 27

def apple_private_key_id
  @apple_private_key_id
end

#apple_team_idObject

Apple Developer Team ID Apple Developer Team ID needed for generating a JWT token for client secret



30
31
32
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 30

def apple_team_id
  @apple_team_id
end

#auth_urlObject

AuthURL is the authorize url, typically something like: example.org/oauth2/auth Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when ‘provider` is set to `generic`.



33
34
35
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 33

def auth_url
  @auth_url
end

#azure_tenantObject

Tenant is the Azure AD Tenant to use for authentication, and must be set when ‘provider` is set to `microsoft`. Can be either `common`, `organizations`, `consumers` for a multitenant application or a specific tenant like `8eaef023-2b34-4da1-9baa-8bc8c9d6a490` or `contoso.onmicrosoft.com`.



36
37
38
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 36

def azure_tenant
  @azure_tenant
end

#claims_sourceObject

Returns the value of attribute claims_source.



38
39
40
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 38

def claims_source
  @claims_source
end

#client_idObject

ClientID is the application’s Client ID.



41
42
43
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 41

def client_id
  @client_id
end

#client_secretObject

Returns the value of attribute client_secret.



43
44
45
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 43

def client_secret
  @client_secret
end

#created_atObject

The Project’s Revision Creation Date



46
47
48
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 46

def created_at
  @created_at
end

#fedcm_config_urlObject

Returns the value of attribute fedcm_config_url.



48
49
50
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 48

def fedcm_config_url
  @fedcm_config_url
end

#idObject

Returns the value of attribute id.



50
51
52
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 50

def id
  @id
end

#issuer_urlObject

IssuerURL is the OpenID Connect Server URL. You can leave this empty if ‘provider` is not set to `generic`. If set, neither `auth_url` nor `token_url` are required.



53
54
55
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 53

def issuer_url
  @issuer_url
end

#labelObject

Label represents an optional label which can be used in the UI generation.



56
57
58
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 56

def label
  @label
end

#mapper_urlObject

Mapper specifies the JSONNet code snippet which uses the OpenID Connect Provider’s data (e.g. GitHub or Google profile information) to hydrate the identity’s data.



59
60
61
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 59

def mapper_url
  @mapper_url
end

#net_id_token_origin_headerObject

Returns the value of attribute net_id_token_origin_header.



61
62
63
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 61

def net_id_token_origin_header
  @net_id_token_origin_header
end

#organization_idObject

Returns the value of attribute organization_id.



63
64
65
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 63

def organization_id
  @organization_id
end

#pkceObject

Returns the value of attribute pkce.



65
66
67
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 65

def pkce
  @pkce
end

#project_revision_idObject

The Revision’s ID this provider belongs to



68
69
70
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 68

def project_revision_id
  @project_revision_id
end

#providerObject

Provider is either "generic" for a generic OAuth 2.0 / OpenID Connect Provider or one of: generic google github gitlab microsoft discord slack facebook vk yandex apple



71
72
73
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 71

def provider
  @provider
end

#provider_idObject

ID is the provider’s ID



74
75
76
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 74

def provider_id
  @provider_id
end

#proxy_oidc_redirect_urlObject

Proxy OIDC Redirect URL if overriding with a customer-controlled URL



77
78
79
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 77

def proxy_oidc_redirect_url
  @proxy_oidc_redirect_url
end

#requested_claimsObject

Returns the value of attribute requested_claims.



79
80
81
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 79

def requested_claims
  @requested_claims
end

#scopeObject

Scope specifies optional requested permissions.



82
83
84
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 82

def scope
  @scope
end

#stateObject

State indicates the state of the provider Only providers with state ‘enabled` will be used for authentication enabled ThirdPartyProviderStateEnabled disabled ThirdPartyProviderStateDisabled



85
86
87
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 85

def state
  @state
end

#subject_sourceObject

Returns the value of attribute subject_source.



87
88
89
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 87

def subject_source
  @subject_source
end

#token_urlObject

TokenURL is the token url, typically something like: example.org/oauth2/token Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when ‘provider` is set to `generic`.



90
91
92
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 90

def token_url
  @token_url
end

#update_identity_on_loginObject

UpdateIdentityOnLogin controls whether the identity is updated from OIDC claims on each login. Possible values are "never" (default) and "automatic". never UpdateIdentityOnLoginNever UpdateIdentityOnLoginNever disables identity updates on login (default). automatic UpdateIdentityOnLoginAutomatic UpdateIdentityOnLoginAutomatic re-runs the Jsonnet claims mapper on every OIDC login and updates the identity’s traits and metadata automatically.



93
94
95
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 93

def 
  @update_identity_on_login
end

#updated_atObject

Last Time Project’s Revision was Updated



96
97
98
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 96

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



157
158
159
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 157

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



162
163
164
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 162

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 121

def self.attribute_map
  {
    :'account_linking_mode' => :'account_linking_mode',
    :'additional_id_token_audiences' => :'additional_id_token_audiences',
    :'apple_private_key' => :'apple_private_key',
    :'apple_private_key_id' => :'apple_private_key_id',
    :'apple_team_id' => :'apple_team_id',
    :'auth_url' => :'auth_url',
    :'azure_tenant' => :'azure_tenant',
    :'claims_source' => :'claims_source',
    :'client_id' => :'client_id',
    :'client_secret' => :'client_secret',
    :'created_at' => :'created_at',
    :'fedcm_config_url' => :'fedcm_config_url',
    :'id' => :'id',
    :'issuer_url' => :'issuer_url',
    :'label' => :'label',
    :'mapper_url' => :'mapper_url',
    :'net_id_token_origin_header' => :'net_id_token_origin_header',
    :'organization_id' => :'organization_id',
    :'pkce' => :'pkce',
    :'project_revision_id' => :'project_revision_id',
    :'provider' => :'provider',
    :'provider_id' => :'provider_id',
    :'proxy_oidc_redirect_url' => :'proxy_oidc_redirect_url',
    :'requested_claims' => :'requested_claims',
    :'scope' => :'scope',
    :'state' => :'state',
    :'subject_source' => :'subject_source',
    :'token_url' => :'token_url',
    :'update_identity_on_login' => :'update_identity_on_login',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 472

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 203

def self.openapi_nullable
  Set.new([
    :'apple_private_key',
    :'claims_source',
    :'client_secret',
    :'fedcm_config_url',
    :'net_id_token_origin_header',
    :'organization_id',
    :'pkce',
    :'subject_source',
  ])
end

.openapi_typesObject

Attribute type mapping.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 167

def self.openapi_types
  {
    :'account_linking_mode' => :'String',
    :'additional_id_token_audiences' => :'Array<String>',
    :'apple_private_key' => :'String',
    :'apple_private_key_id' => :'String',
    :'apple_team_id' => :'String',
    :'auth_url' => :'String',
    :'azure_tenant' => :'String',
    :'claims_source' => :'String',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'created_at' => :'Time',
    :'fedcm_config_url' => :'String',
    :'id' => :'String',
    :'issuer_url' => :'String',
    :'label' => :'String',
    :'mapper_url' => :'String',
    :'net_id_token_origin_header' => :'String',
    :'organization_id' => :'String',
    :'pkce' => :'String',
    :'project_revision_id' => :'String',
    :'provider' => :'String',
    :'provider_id' => :'String',
    :'proxy_oidc_redirect_url' => :'String',
    :'requested_claims' => :'Object',
    :'scope' => :'Array<String>',
    :'state' => :'String',
    :'subject_source' => :'String',
    :'token_url' => :'String',
    :'update_identity_on_login' => :'String',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 422

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      additional_id_token_audiences == o.additional_id_token_audiences &&
      apple_private_key == o.apple_private_key &&
      apple_private_key_id == o.apple_private_key_id &&
      apple_team_id == o.apple_team_id &&
      auth_url == o.auth_url &&
      azure_tenant == o.azure_tenant &&
      claims_source == o.claims_source &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      created_at == o.created_at &&
      fedcm_config_url == o.fedcm_config_url &&
      id == o.id &&
      issuer_url == o.issuer_url &&
      label == o.label &&
      mapper_url == o.mapper_url &&
      net_id_token_origin_header == o.net_id_token_origin_header &&
      organization_id == o.organization_id &&
      pkce == o.pkce &&
      project_revision_id == o.project_revision_id &&
      provider == o.provider &&
      provider_id == o.provider_id &&
      proxy_oidc_redirect_url == o.proxy_oidc_redirect_url &&
      requested_claims == o.requested_claims &&
      scope == o.scope &&
      state == o.state &&
      subject_source == o.subject_source &&
      token_url == o.token_url &&
       == o. &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


459
460
461
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 459

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



465
466
467
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 465

def hash
  [, additional_id_token_audiences, apple_private_key, apple_private_key_id, apple_team_id, auth_url, azure_tenant, claims_source, client_id, client_secret, created_at, fedcm_config_url, id, issuer_url, label, mapper_url, net_id_token_origin_header, organization_id, pkce, project_revision_id, provider, provider_id, proxy_oidc_redirect_url, requested_claims, scope, state, subject_source, token_url, , updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



359
360
361
362
363
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 359

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 494

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 367

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
   = EnumAttributeValidator.new('String', ["automatic", "confirm_with_existing_credential"])
  return false unless .valid?(@account_linking_mode)
  pkce_validator = EnumAttributeValidator.new('String', ["auto", "never", "force"])
  return false unless pkce_validator.valid?(@pkce)
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"])
  return false unless state_validator.valid?(@state)
   = EnumAttributeValidator.new('String', ["never", "automatic"])
  return false unless .valid?(@update_identity_on_login)
  true
end