Class: OryClient::NormalizedProjectRevisionThirdPartyProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::NormalizedProjectRevisionThirdPartyProvider
- Defined in:
- lib/ory-client/models/normalized_project_revision_third_party_provider.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_linking_mode ⇒ Object
AccountLinkingMode controls how account conflicts are resolved for this provider.
-
#additional_id_token_audiences ⇒ Object
Returns the value of attribute additional_id_token_audiences.
-
#apple_private_key ⇒ Object
Returns the value of attribute apple_private_key.
-
#apple_private_key_id ⇒ Object
Apple Private Key Identifier Sign In with Apple Private Key Identifier needed for generating a JWT token for client secret.
-
#apple_team_id ⇒ Object
Apple Developer Team ID Apple Developer Team ID needed for generating a JWT token for client secret.
-
#auth_url ⇒ Object
AuthURL is the authorize url, typically something like: example.org/oauth2/auth Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when
provideris set togeneric. -
#azure_tenant ⇒ Object
Tenant is the Azure AD Tenant to use for authentication, and must be set when
provideris set tomicrosoft. -
#claims_source ⇒ Object
Returns the value of attribute claims_source.
-
#client_id ⇒ Object
ClientID is the application’s Client ID.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#created_at ⇒ Object
The Project’s Revision Creation Date.
-
#fedcm_config_url ⇒ Object
Returns the value of attribute fedcm_config_url.
-
#id ⇒ Object
Returns the value of attribute id.
-
#issuer_url ⇒ Object
IssuerURL is the OpenID Connect Server URL.
-
#label ⇒ Object
Label represents an optional label which can be used in the UI generation.
-
#mapper_url ⇒ Object
Mapper specifies the JSONNet code snippet which uses the OpenID Connect Provider’s data (e.g. GitHub or Google profile information) to hydrate the identity’s data.
-
#net_id_token_origin_header ⇒ Object
Returns the value of attribute net_id_token_origin_header.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#pkce ⇒ Object
Returns the value of attribute pkce.
-
#project_revision_id ⇒ Object
The Revision’s ID this provider belongs to.
-
#provider ⇒ Object
Provider is either \“generic\” for a generic OAuth 2.0 / OpenID Connect Provider or one of: generic google github gitlab microsoft discord slack facebook vk yandex apple.
-
#provider_id ⇒ Object
ID is the provider’s ID.
-
#proxy_oidc_redirect_url ⇒ Object
Proxy OIDC Redirect URL if overriding with a customer-controlled URL.
-
#requested_claims ⇒ Object
Returns the value of attribute requested_claims.
-
#scope ⇒ Object
Returns the value of attribute scope.
-
#state ⇒ Object
State indicates the state of the provider Only providers with state
enabledwill be used for authentication enabled ThirdPartyProviderStateEnabled disabled ThirdPartyProviderStateDisabled. -
#subject_source ⇒ Object
Returns the value of attribute subject_source.
-
#token_url ⇒ Object
TokenURL is the token url, typically something like: example.org/oauth2/token Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when
provideris set togeneric. -
#update_identity_on_login ⇒ Object
UpdateIdentityOnLogin controls whether the identity is updated from OIDC claims on each login.
-
#updated_at ⇒ Object
Last Time Project’s Revision was Updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NormalizedProjectRevisionThirdPartyProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NormalizedProjectRevisionThirdPartyProvider
Initializes the object
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 216 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::NormalizedProjectRevisionThirdPartyProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::NormalizedProjectRevisionThirdPartyProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_linking_mode') self.account_linking_mode = attributes[:'account_linking_mode'] end if attributes.key?(:'additional_id_token_audiences') if (value = attributes[:'additional_id_token_audiences']).is_a?(Array) self.additional_id_token_audiences = value end end if attributes.key?(:'apple_private_key') self.apple_private_key = attributes[:'apple_private_key'] end if attributes.key?(:'apple_private_key_id') self.apple_private_key_id = attributes[:'apple_private_key_id'] end if attributes.key?(:'apple_team_id') self.apple_team_id = attributes[:'apple_team_id'] end if attributes.key?(:'auth_url') self.auth_url = attributes[:'auth_url'] end if attributes.key?(:'azure_tenant') self.azure_tenant = attributes[:'azure_tenant'] end if attributes.key?(:'claims_source') self.claims_source = attributes[:'claims_source'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'fedcm_config_url') self.fedcm_config_url = attributes[:'fedcm_config_url'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'issuer_url') self.issuer_url = attributes[:'issuer_url'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'mapper_url') self.mapper_url = attributes[:'mapper_url'] end if attributes.key?(:'net_id_token_origin_header') self.net_id_token_origin_header = attributes[:'net_id_token_origin_header'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'pkce') self.pkce = attributes[:'pkce'] end if attributes.key?(:'project_revision_id') self.project_revision_id = attributes[:'project_revision_id'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] end if attributes.key?(:'proxy_oidc_redirect_url') self.proxy_oidc_redirect_url = attributes[:'proxy_oidc_redirect_url'] end if attributes.key?(:'requested_claims') self.requested_claims = attributes[:'requested_claims'] end if attributes.key?(:'scope') if (value = attributes[:'scope']).is_a?(Array) self.scope = value end end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'subject_source') self.subject_source = attributes[:'subject_source'] end if attributes.key?(:'token_url') self.token_url = attributes[:'token_url'] end if attributes.key?(:'update_identity_on_login') self.update_identity_on_login = attributes[:'update_identity_on_login'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#account_linking_mode ⇒ Object
AccountLinkingMode controls how account conflicts are resolved for this provider. Possible values are confirm_with_existing_credential (default) and automatic. automatic silently links accounts when the provider verifies email ownership. Only supported for apple and google providers. automatic AccountLinkingModeAutomatic AccountLinkingModeAutomatic silently links accounts if the provider verifies email ownership. confirm_with_existing_credential AccountLinkingModeConfirmWithExistingCredential AccountLinkingModeConfirmWithExistingCredential requires the user to confirm the account linking by providing an existing credential.
19 20 21 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 19 def account_linking_mode @account_linking_mode end |
#additional_id_token_audiences ⇒ Object
Returns the value of attribute additional_id_token_audiences.
21 22 23 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 21 def additional_id_token_audiences @additional_id_token_audiences end |
#apple_private_key ⇒ Object
Returns the value of attribute apple_private_key.
23 24 25 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 23 def apple_private_key @apple_private_key end |
#apple_private_key_id ⇒ Object
Apple Private Key Identifier Sign In with Apple Private Key Identifier needed for generating a JWT token for client secret
26 27 28 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 26 def apple_private_key_id @apple_private_key_id end |
#apple_team_id ⇒ Object
Apple Developer Team ID Apple Developer Team ID needed for generating a JWT token for client secret
29 30 31 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 29 def apple_team_id @apple_team_id end |
#auth_url ⇒ Object
AuthURL is the authorize url, typically something like: example.org/oauth2/auth Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when provider is set to generic.
32 33 34 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 32 def auth_url @auth_url end |
#azure_tenant ⇒ Object
Tenant is the Azure AD Tenant to use for authentication, and must be set when provider is set to microsoft. Can be either common, organizations, consumers for a multitenant application or a specific tenant like 8eaef023-2b34-4da1-9baa-8bc8c9d6a490 or contoso.onmicrosoft.com.
35 36 37 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 35 def azure_tenant @azure_tenant end |
#claims_source ⇒ Object
Returns the value of attribute claims_source.
37 38 39 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 37 def claims_source @claims_source end |
#client_id ⇒ Object
ClientID is the application’s Client ID.
40 41 42 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 40 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
42 43 44 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 42 def client_secret @client_secret end |
#created_at ⇒ Object
The Project’s Revision Creation Date
45 46 47 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 45 def created_at @created_at end |
#fedcm_config_url ⇒ Object
Returns the value of attribute fedcm_config_url.
47 48 49 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 47 def fedcm_config_url @fedcm_config_url end |
#id ⇒ Object
Returns the value of attribute id.
49 50 51 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 49 def id @id end |
#issuer_url ⇒ Object
IssuerURL is the OpenID Connect Server URL. You can leave this empty if provider is not set to generic. If set, neither auth_url nor token_url are required.
52 53 54 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 52 def issuer_url @issuer_url end |
#label ⇒ Object
Label represents an optional label which can be used in the UI generation.
55 56 57 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 55 def label @label end |
#mapper_url ⇒ Object
Mapper specifies the JSONNet code snippet which uses the OpenID Connect Provider’s data (e.g. GitHub or Google profile information) to hydrate the identity’s data.
58 59 60 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 58 def mapper_url @mapper_url end |
#net_id_token_origin_header ⇒ Object
Returns the value of attribute net_id_token_origin_header.
60 61 62 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 60 def net_id_token_origin_header @net_id_token_origin_header end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
62 63 64 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 62 def organization_id @organization_id end |
#pkce ⇒ Object
Returns the value of attribute pkce.
64 65 66 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 64 def pkce @pkce end |
#project_revision_id ⇒ Object
The Revision’s ID this provider belongs to
67 68 69 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 67 def project_revision_id @project_revision_id end |
#provider ⇒ Object
Provider is either \“generic\” for a generic OAuth 2.0 / OpenID Connect Provider or one of: generic google github gitlab microsoft discord slack facebook vk yandex apple
70 71 72 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 70 def provider @provider end |
#provider_id ⇒ Object
ID is the provider’s ID
73 74 75 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 73 def provider_id @provider_id end |
#proxy_oidc_redirect_url ⇒ Object
Proxy OIDC Redirect URL if overriding with a customer-controlled URL
76 77 78 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 76 def proxy_oidc_redirect_url @proxy_oidc_redirect_url end |
#requested_claims ⇒ Object
Returns the value of attribute requested_claims.
78 79 80 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 78 def requested_claims @requested_claims end |
#scope ⇒ Object
Returns the value of attribute scope.
80 81 82 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 80 def scope @scope end |
#state ⇒ Object
State indicates the state of the provider Only providers with state enabled will be used for authentication enabled ThirdPartyProviderStateEnabled disabled ThirdPartyProviderStateDisabled
83 84 85 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 83 def state @state end |
#subject_source ⇒ Object
Returns the value of attribute subject_source.
85 86 87 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 85 def subject_source @subject_source end |
#token_url ⇒ Object
TokenURL is the token url, typically something like: example.org/oauth2/token Should only be used when the OAuth2 / OpenID Connect server is not supporting OpenID Connect Discovery and when provider is set to generic.
88 89 90 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 88 def token_url @token_url end |
#update_identity_on_login ⇒ Object
UpdateIdentityOnLogin controls whether the identity is updated from OIDC claims on each login. Possible values are \“never\” (default) and \“automatic\”. never UpdateIdentityOnLoginNever UpdateIdentityOnLoginNever disables identity updates on login (default). automatic UpdateIdentityOnLoginAutomatic UpdateIdentityOnLoginAutomatic re-runs the Jsonnet claims mapper on every OIDC login and updates the identity’s traits and metadata automatically.
91 92 93 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 91 def update_identity_on_login @update_identity_on_login end |
#updated_at ⇒ Object
Last Time Project’s Revision was Updated
94 95 96 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 94 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
155 156 157 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 155 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
160 161 162 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 160 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 119 def self.attribute_map { :'account_linking_mode' => :'account_linking_mode', :'additional_id_token_audiences' => :'additional_id_token_audiences', :'apple_private_key' => :'apple_private_key', :'apple_private_key_id' => :'apple_private_key_id', :'apple_team_id' => :'apple_team_id', :'auth_url' => :'auth_url', :'azure_tenant' => :'azure_tenant', :'claims_source' => :'claims_source', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'created_at' => :'created_at', :'fedcm_config_url' => :'fedcm_config_url', :'id' => :'id', :'issuer_url' => :'issuer_url', :'label' => :'label', :'mapper_url' => :'mapper_url', :'net_id_token_origin_header' => :'net_id_token_origin_header', :'organization_id' => :'organization_id', :'pkce' => :'pkce', :'project_revision_id' => :'project_revision_id', :'provider' => :'provider', :'provider_id' => :'provider_id', :'proxy_oidc_redirect_url' => :'proxy_oidc_redirect_url', :'requested_claims' => :'requested_claims', :'scope' => :'scope', :'state' => :'state', :'subject_source' => :'subject_source', :'token_url' => :'token_url', :'update_identity_on_login' => :'update_identity_on_login', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 470 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 201 def self.openapi_nullable Set.new([ :'apple_private_key', :'claims_source', :'client_secret', :'fedcm_config_url', :'net_id_token_origin_header', :'organization_id', :'pkce', :'subject_source', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 165 def self.openapi_types { :'account_linking_mode' => :'String', :'additional_id_token_audiences' => :'Array<String>', :'apple_private_key' => :'String', :'apple_private_key_id' => :'String', :'apple_team_id' => :'String', :'auth_url' => :'String', :'azure_tenant' => :'String', :'claims_source' => :'String', :'client_id' => :'String', :'client_secret' => :'String', :'created_at' => :'Time', :'fedcm_config_url' => :'String', :'id' => :'String', :'issuer_url' => :'String', :'label' => :'String', :'mapper_url' => :'String', :'net_id_token_origin_header' => :'String', :'organization_id' => :'String', :'pkce' => :'String', :'project_revision_id' => :'String', :'provider' => :'String', :'provider_id' => :'String', :'proxy_oidc_redirect_url' => :'String', :'requested_claims' => :'Object', :'scope' => :'Array<String>', :'state' => :'String', :'subject_source' => :'String', :'token_url' => :'String', :'update_identity_on_login' => :'String', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 420 def ==(o) return true if self.equal?(o) self.class == o.class && account_linking_mode == o.account_linking_mode && additional_id_token_audiences == o.additional_id_token_audiences && apple_private_key == o.apple_private_key && apple_private_key_id == o.apple_private_key_id && apple_team_id == o.apple_team_id && auth_url == o.auth_url && azure_tenant == o.azure_tenant && claims_source == o.claims_source && client_id == o.client_id && client_secret == o.client_secret && created_at == o.created_at && fedcm_config_url == o.fedcm_config_url && id == o.id && issuer_url == o.issuer_url && label == o.label && mapper_url == o.mapper_url && net_id_token_origin_header == o.net_id_token_origin_header && organization_id == o.organization_id && pkce == o.pkce && project_revision_id == o.project_revision_id && provider == o.provider && provider_id == o.provider_id && proxy_oidc_redirect_url == o.proxy_oidc_redirect_url && requested_claims == o.requested_claims && scope == o.scope && state == o.state && subject_source == o.subject_source && token_url == o.token_url && update_identity_on_login == o.update_identity_on_login && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
457 458 459 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 457 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
463 464 465 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 463 def hash [account_linking_mode, additional_id_token_audiences, apple_private_key, apple_private_key_id, apple_team_id, auth_url, azure_tenant, claims_source, client_id, client_secret, created_at, fedcm_config_url, id, issuer_url, label, mapper_url, net_id_token_origin_header, organization_id, pkce, project_revision_id, provider, provider_id, proxy_oidc_redirect_url, requested_claims, scope, state, subject_source, token_url, update_identity_on_login, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
357 358 359 360 361 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 357 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 492 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/ory-client/models/normalized_project_revision_third_party_provider.rb', line 365 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' account_linking_mode_validator = EnumAttributeValidator.new('String', ["automatic", "confirm_with_existing_credential"]) return false unless account_linking_mode_validator.valid?(@account_linking_mode) pkce_validator = EnumAttributeValidator.new('String', ["auto", "never", "force"]) return false unless pkce_validator.valid?(@pkce) state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"]) return false unless state_validator.valid?(@state) update_identity_on_login_validator = EnumAttributeValidator.new('String', ["never", "automatic"]) return false unless update_identity_on_login_validator.valid?(@update_identity_on_login) true end |