Class: OryClient::OAuth2ConsentRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::OAuth2ConsentRequest
- Defined in:
- lib/ory-client/models/o_auth2_consent_request.rb
Instance Attribute Summary collapse
-
#acr ⇒ Object
ACR represents the Authentication AuthorizationContext Class Reference value for this authentication session.
-
#amr ⇒ Object
AMR is the Authentication Methods References value for this authentication session.
-
#challenge ⇒ Object
Challenge is used to retrieve/accept/deny the consent request.
-
#client ⇒ Object
Returns the value of attribute client.
-
#consent_request_id ⇒ Object
ConsentRequestID is the ID of the consent request.
-
#context ⇒ Object
Returns the value of attribute context.
-
#login_challenge ⇒ Object
LoginChallenge is the login challenge this consent challenge belongs to.
-
#login_session_id ⇒ Object
LoginSessionID is the login session ID.
-
#oidc_context ⇒ Object
Returns the value of attribute oidc_context.
-
#request_url ⇒ Object
RequestURL is the original OAuth 2.0 Authorization URL requested by the OAuth 2.0 client.
-
#requested_access_token_audience ⇒ Object
RequestedAudience contains the access token audience as requested by the OAuth 2.0 Client.
-
#requested_scope ⇒ Object
RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.
-
#skip ⇒ Object
Skip, if true, implies that the client has requested the same scopes from the same user previously.
-
#subject ⇒ Object
Subject is the user ID of the end-user that authenticated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OAuth2ConsentRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OAuth2ConsentRequest
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OAuth2ConsentRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OAuth2ConsentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acr') self.acr = attributes[:'acr'] end if attributes.key?(:'amr') if (value = attributes[:'amr']).is_a?(Array) self.amr = value end end if attributes.key?(:'challenge') self.challenge = attributes[:'challenge'] else self.challenge = nil end if attributes.key?(:'client') self.client = attributes[:'client'] end if attributes.key?(:'consent_request_id') self. = attributes[:'consent_request_id'] end if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'login_challenge') self.login_challenge = attributes[:'login_challenge'] end if attributes.key?(:'login_session_id') self.login_session_id = attributes[:'login_session_id'] end if attributes.key?(:'oidc_context') self.oidc_context = attributes[:'oidc_context'] end if attributes.key?(:'request_url') self.request_url = attributes[:'request_url'] end if attributes.key?(:'requested_access_token_audience') if (value = attributes[:'requested_access_token_audience']).is_a?(Array) self.requested_access_token_audience = value end end if attributes.key?(:'requested_scope') if (value = attributes[:'requested_scope']).is_a?(Array) self.requested_scope = value end end if attributes.key?(:'skip') self.skip = attributes[:'skip'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end end |
Instance Attribute Details
#acr ⇒ Object
ACR represents the Authentication AuthorizationContext Class Reference value for this authentication session. You can use it to express that, for example, a user authenticated using two factor authentication.
19 20 21 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 19 def acr @acr end |
#amr ⇒ Object
AMR is the Authentication Methods References value for this authentication session. You can use it to specify the method a user used to authenticate. For example, if the acr indicates a user used two factor authentication, the amr can express they used a software-secured key.
22 23 24 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 22 def amr @amr end |
#challenge ⇒ Object
Challenge is used to retrieve/accept/deny the consent request.
25 26 27 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 25 def challenge @challenge end |
#client ⇒ Object
Returns the value of attribute client.
27 28 29 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 27 def client @client end |
#consent_request_id ⇒ Object
ConsentRequestID is the ID of the consent request.
30 31 32 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 30 def @consent_request_id end |
#context ⇒ Object
Returns the value of attribute context.
32 33 34 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 32 def context @context end |
#login_challenge ⇒ Object
LoginChallenge is the login challenge this consent challenge belongs to. It can be used to associate a login and consent request in the login & consent app.
35 36 37 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 35 def login_challenge @login_challenge end |
#login_session_id ⇒ Object
LoginSessionID is the login session ID. If the user-agent reuses a login session (via cookie / remember flag) this ID will remain the same. If the user-agent did not have an existing authentication session (e.g. remember is false) this will be a new random value. This value is used as the "sid" parameter in the ID Token and in OIDC Front-/Back- channel logout. It’s value can generally be used to associate consecutive login requests by a certain user.
38 39 40 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 38 def login_session_id @login_session_id end |
#oidc_context ⇒ Object
Returns the value of attribute oidc_context.
40 41 42 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 40 def oidc_context @oidc_context end |
#request_url ⇒ Object
RequestURL is the original OAuth 2.0 Authorization URL requested by the OAuth 2.0 client. It is the URL which initiates the OAuth 2.0 Authorization Code or OAuth 2.0 Implicit flow. This URL is typically not needed, but might come in handy if you want to deal with additional request parameters.
43 44 45 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 43 def request_url @request_url end |
#requested_access_token_audience ⇒ Object
RequestedAudience contains the access token audience as requested by the OAuth 2.0 Client.
46 47 48 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 46 def requested_access_token_audience @requested_access_token_audience end |
#requested_scope ⇒ Object
RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.
49 50 51 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 49 def requested_scope @requested_scope end |
#skip ⇒ Object
Skip, if true, implies that the client has requested the same scopes from the same user previously. If true, you must not ask the user to grant the requested scopes. You must however either allow or deny the consent request using the usual API call.
52 53 54 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 52 def skip @skip end |
#subject ⇒ Object
Subject is the user ID of the end-user that authenticated. Now, that end user needs to grant or deny the scope requested by the OAuth 2.0 client.
55 56 57 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 55 def subject @subject end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 58 def self.attribute_map { :'acr' => :'acr', :'amr' => :'amr', :'challenge' => :'challenge', :'client' => :'client', :'consent_request_id' => :'consent_request_id', :'context' => :'context', :'login_challenge' => :'login_challenge', :'login_session_id' => :'login_session_id', :'oidc_context' => :'oidc_context', :'request_url' => :'request_url', :'requested_access_token_audience' => :'requested_access_token_audience', :'requested_scope' => :'requested_scope', :'skip' => :'skip', :'subject' => :'subject' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 260 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 88 def self.openapi_types { :'acr' => :'String', :'amr' => :'Array<String>', :'challenge' => :'String', :'client' => :'OAuth2Client', :'consent_request_id' => :'String', :'context' => :'Object', :'login_challenge' => :'String', :'login_session_id' => :'String', :'oidc_context' => :'OAuth2ConsentRequestOpenIDConnectContext', :'request_url' => :'String', :'requested_access_token_audience' => :'Array<String>', :'requested_scope' => :'Array<String>', :'skip' => :'Boolean', :'subject' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && acr == o.acr && amr == o.amr && challenge == o.challenge && client == o.client && == o. && context == o.context && login_challenge == o.login_challenge && login_session_id == o.login_session_id && oidc_context == o.oidc_context && request_url == o.request_url && requested_access_token_audience == o.requested_access_token_audience && requested_scope == o.requested_scope && skip == o.skip && subject == o.subject end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 253 def hash [acr, amr, challenge, client, , context, login_challenge, login_session_id, oidc_context, request_url, requested_access_token_audience, requested_scope, skip, subject].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @challenge.nil? invalid_properties.push('invalid value for "challenge", challenge cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 |
# File 'lib/ory-client/models/o_auth2_consent_request.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @challenge.nil? true end |