Class: OryClient::OAuth2ConsentSession

Inherits:
Object
  • Object
show all
Defined in:
lib/ory-client/models/o_auth2_consent_session.rb

Overview

A completed OAuth 2.0 Consent Session.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OAuth2ConsentSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OAuth2ConsentSession` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OAuth2ConsentSession`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'consent_request')
    self.consent_request = attributes[:'consent_request']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'grant_access_token_audience')
    if (value = attributes[:'grant_access_token_audience']).is_a?(Array)
      self.grant_access_token_audience = value
    end
  end

  if attributes.key?(:'grant_scope')
    if (value = attributes[:'grant_scope']).is_a?(Array)
      self.grant_scope = value
    end
  end

  if attributes.key?(:'handled_at')
    self.handled_at = attributes[:'handled_at']
  end

  if attributes.key?(:'remember')
    self.remember = attributes[:'remember']
  end

  if attributes.key?(:'remember_for')
    self.remember_for = attributes[:'remember_for']
  end

  if attributes.key?(:'session')
    self.session = attributes[:'session']
  end
end

Instance Attribute Details

Returns the value of attribute consent_request.



19
20
21
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 19

def consent_request
  @consent_request
end

#contextObject

Returns the value of attribute context.



21
22
23
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 21

def context
  @context
end

#expires_atObject

Returns the value of attribute expires_at.



23
24
25
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 23

def expires_at
  @expires_at
end

#grant_access_token_audienceObject

Returns the value of attribute grant_access_token_audience.



25
26
27
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 25

def grant_access_token_audience
  @grant_access_token_audience
end

#grant_scopeObject

Returns the value of attribute grant_scope.



27
28
29
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 27

def grant_scope
  @grant_scope
end

#handled_atObject

Returns the value of attribute handled_at.



29
30
31
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 29

def handled_at
  @handled_at
end

#rememberObject

Remember Consent Remember, if set to true, tells ORY Hydra to remember this consent authorization and reuse it if the same client asks the same user for the same, or a subset of, scope.



32
33
34
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 32

def remember
  @remember
end

#remember_forObject

Remember Consent For RememberFor sets how long the consent authorization should be remembered for in seconds. If set to ‘0`, the authorization will be remembered indefinitely.



35
36
37
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 35

def remember_for
  @remember_for
end

#sessionObject

Returns the value of attribute session.



37
38
39
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 37

def session
  @session
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 55

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 40

def self.attribute_map
  {
    :'consent_request' => :'consent_request',
    :'context' => :'context',
    :'expires_at' => :'expires_at',
    :'grant_access_token_audience' => :'grant_access_token_audience',
    :'grant_scope' => :'grant_scope',
    :'handled_at' => :'handled_at',
    :'remember' => :'remember',
    :'remember_for' => :'remember_for',
    :'session' => :'session'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 180

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 60

def self.openapi_types
  {
    :'consent_request' => :'OAuth2ConsentRequest',
    :'context' => :'Object',
    :'expires_at' => :'OAuth2ConsentSessionExpiresAt',
    :'grant_access_token_audience' => :'Array<String>',
    :'grant_scope' => :'Array<String>',
    :'handled_at' => :'Time',
    :'remember' => :'Boolean',
    :'remember_for' => :'Integer',
    :'session' => :'AcceptOAuth2ConsentRequestSession'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      consent_request == o.consent_request &&
      context == o.context &&
      expires_at == o.expires_at &&
      grant_access_token_audience == o.grant_access_token_audience &&
      grant_scope == o.grant_scope &&
      handled_at == o.handled_at &&
      remember == o.remember &&
      remember_for == o.remember_for &&
      session == o.session
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 211

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OryClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 282

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 173

def hash
  [consent_request, context, expires_at, grant_access_token_audience, grant_scope, handled_at, remember, remember_for, session].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 138

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 258

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



252
253
254
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 252

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
# File 'lib/ory-client/models/o_auth2_consent_session.rb', line 145

def valid?
  true
end