Class: OryClient::OnboardingPortalLink

Inherits:
Object
  • Object
show all
Defined in:
lib/ory-client/models/onboarding_portal_link.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OnboardingPortalLink

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 168

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OnboardingPortalLink` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OnboardingPortalLink`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'apple_mapper_url')
    self.apple_mapper_url = attributes[:'apple_mapper_url']
  end

  if attributes.key?(:'auth0_mapper_url')
    self.auth0_mapper_url = attributes[:'auth0_mapper_url']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'custom_hostname_id')
    self.custom_hostname_id = attributes[:'custom_hostname_id']
  end

  if attributes.key?(:'enable_scim')
    self.enable_scim = attributes[:'enable_scim']
  end

  if attributes.key?(:'enable_sso')
    self.enable_sso = attributes[:'enable_sso']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'facebook_mapper_url')
    self.facebook_mapper_url = attributes[:'facebook_mapper_url']
  end

  if attributes.key?(:'generic_oidc_mapper_url')
    self.generic_oidc_mapper_url = attributes[:'generic_oidc_mapper_url']
  end

  if attributes.key?(:'github_mapper_url')
    self.github_mapper_url = attributes[:'github_mapper_url']
  end

  if attributes.key?(:'gitlab_mapper_url')
    self.gitlab_mapper_url = attributes[:'gitlab_mapper_url']
  end

  if attributes.key?(:'google_mapper_url')
    self.google_mapper_url = attributes[:'google_mapper_url']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'microsoft_mapper_url')
    self.microsoft_mapper_url = attributes[:'microsoft_mapper_url']
  end

  if attributes.key?(:'netid_mapper_url')
    self.netid_mapper_url = attributes[:'netid_mapper_url']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  else
    self.project_id = nil
  end

  if attributes.key?(:'proxy_acs_url')
    self.proxy_acs_url = attributes[:'proxy_acs_url']
  end

  if attributes.key?(:'proxy_oidc_redirect_url')
    self.proxy_oidc_redirect_url = attributes[:'proxy_oidc_redirect_url']
  end

  if attributes.key?(:'proxy_saml_audience_override')
    self.proxy_saml_audience_override = attributes[:'proxy_saml_audience_override']
  end

  if attributes.key?(:'proxy_scim_server_url')
    self.proxy_scim_server_url = attributes[:'proxy_scim_server_url']
  end

  if attributes.key?(:'saml_mapper_url')
    self.saml_mapper_url = attributes[:'saml_mapper_url']
  end

  if attributes.key?(:'scim_mapper_url')
    self.scim_mapper_url = attributes[:'scim_mapper_url']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end
end

Instance Attribute Details

#apple_mapper_urlObject

AppleMapper specifies the JSONNet code snippet which uses Apple’s profile information to hydrate the identity’s data.



19
20
21
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 19

def apple_mapper_url
  @apple_mapper_url
end

#auth0_mapper_urlObject

Auth0Mapper specifies the JSONNet code snippet which uses Auth0’s profile information to hydrate the identity’s data.



22
23
24
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 22

def auth0_mapper_url
  @auth0_mapper_url
end

#created_atObject

The onboarding portal link’s creation date



25
26
27
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 25

def created_at
  @created_at
end

#custom_hostname_idObject

Returns the value of attribute custom_hostname_id.



27
28
29
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 27

def custom_hostname_id
  @custom_hostname_id
end

#enable_scimObject

Feature flag to enable SCIM configuration



30
31
32
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 30

def enable_scim
  @enable_scim
end

#enable_ssoObject

Feature flag to enable SSO configuration



33
34
35
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 33

def enable_sso
  @enable_sso
end

#expires_atObject

The onboarding portal link’s expiry date



36
37
38
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 36

def expires_at
  @expires_at
end

#facebook_mapper_urlObject

FacebookMapper specifies the JSONNet code snippet which uses Facebook’s profile information to hydrate the identity’s data.



39
40
41
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 39

def facebook_mapper_url
  @facebook_mapper_url
end

#generic_oidc_mapper_urlObject

GenericOIDCMapper specifies the JSONNet code snippet which uses the OIDC Provider’s profile information to hydrate the identity’s data.



42
43
44
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 42

def generic_oidc_mapper_url
  @generic_oidc_mapper_url
end

#github_mapper_urlObject

GithubMapper specifies the JSONNet code snippet which uses GitHub’s profile information to hydrate the identity’s data.



45
46
47
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 45

def github_mapper_url
  @github_mapper_url
end

#gitlab_mapper_urlObject

GitLabMapper specifies the JSONNet code snippet which uses GitLab’s profile information to hydrate the identity’s data.



48
49
50
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 48

def gitlab_mapper_url
  @gitlab_mapper_url
end

#google_mapper_urlObject

GoogleMapper specifies the JSONNet code snippet which uses Google’s profile information to hydrate the identity’s data.



51
52
53
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 51

def google_mapper_url
  @google_mapper_url
end

#idObject

The onboarding portal link’s ID.



54
55
56
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 54

def id
  @id
end

#microsoft_mapper_urlObject

MicrosoftMapper specifies the JSONNet code snippet which uses Microsoft’s profile information to hydrate the identity’s data.



57
58
59
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 57

def microsoft_mapper_url
  @microsoft_mapper_url
end

#netid_mapper_urlObject

NetIDMapper specifies the JSONNet code snippet which uses NetID’s profile information to hydrate the identity’s data.



60
61
62
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 60

def netid_mapper_url
  @netid_mapper_url
end

#organization_idObject

The onboarding portal link’s organization ID



63
64
65
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 63

def organization_id
  @organization_id
end

#project_idObject

The onboarding portal link’s project ID



66
67
68
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 66

def project_id
  @project_id
end

#proxy_acs_urlObject

Proxy ACS URL if overriding with a customer-controlled URL



69
70
71
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 69

def proxy_acs_url
  @proxy_acs_url
end

#proxy_oidc_redirect_urlObject

Proxy OIDC Redirect URL if overriding with a customer-controlled URL



72
73
74
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 72

def proxy_oidc_redirect_url
  @proxy_oidc_redirect_url
end

#proxy_saml_audience_overrideObject

SAML Audience Override if overriding with a customer-controlled one



75
76
77
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 75

def proxy_saml_audience_override
  @proxy_saml_audience_override
end

#proxy_scim_server_urlObject

Proxy SCIM Server URL if overriding with a customer-controlled URL



78
79
80
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 78

def proxy_scim_server_url
  @proxy_scim_server_url
end

#saml_mapper_urlObject

SAMLMapper specifies the JSONNet code snippet which uses the SAML Provider’s profile information to hydrate the identity’s data.



81
82
83
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 81

def saml_mapper_url
  @saml_mapper_url
end

#scim_mapper_urlObject

SCIMMapper specifies the JSONNet code snippet which uses the SCIM Provider’s profile information to hydrate the identity’s data.



84
85
86
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 84

def scim_mapper_url
  @scim_mapper_url
end

#valueObject

The onboarding portal link’s value



87
88
89
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 87

def value
  @value
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 449

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OryClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



120
121
122
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 120

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 125

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 90

def self.attribute_map
  {
    :'apple_mapper_url' => :'apple_mapper_url',
    :'auth0_mapper_url' => :'auth0_mapper_url',
    :'created_at' => :'created_at',
    :'custom_hostname_id' => :'custom_hostname_id',
    :'enable_scim' => :'enable_scim',
    :'enable_sso' => :'enable_sso',
    :'expires_at' => :'expires_at',
    :'facebook_mapper_url' => :'facebook_mapper_url',
    :'generic_oidc_mapper_url' => :'generic_oidc_mapper_url',
    :'github_mapper_url' => :'github_mapper_url',
    :'gitlab_mapper_url' => :'gitlab_mapper_url',
    :'google_mapper_url' => :'google_mapper_url',
    :'id' => :'id',
    :'microsoft_mapper_url' => :'microsoft_mapper_url',
    :'netid_mapper_url' => :'netid_mapper_url',
    :'organization_id' => :'organization_id',
    :'project_id' => :'project_id',
    :'proxy_acs_url' => :'proxy_acs_url',
    :'proxy_oidc_redirect_url' => :'proxy_oidc_redirect_url',
    :'proxy_saml_audience_override' => :'proxy_saml_audience_override',
    :'proxy_scim_server_url' => :'proxy_scim_server_url',
    :'saml_mapper_url' => :'saml_mapper_url',
    :'scim_mapper_url' => :'scim_mapper_url',
    :'value' => :'value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 425

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



160
161
162
163
164
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 160

def self.openapi_nullable
  Set.new([
    :'custom_hostname_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 130

def self.openapi_types
  {
    :'apple_mapper_url' => :'String',
    :'auth0_mapper_url' => :'String',
    :'created_at' => :'Time',
    :'custom_hostname_id' => :'String',
    :'enable_scim' => :'Boolean',
    :'enable_sso' => :'Boolean',
    :'expires_at' => :'Time',
    :'facebook_mapper_url' => :'String',
    :'generic_oidc_mapper_url' => :'String',
    :'github_mapper_url' => :'String',
    :'gitlab_mapper_url' => :'String',
    :'google_mapper_url' => :'String',
    :'id' => :'String',
    :'microsoft_mapper_url' => :'String',
    :'netid_mapper_url' => :'String',
    :'organization_id' => :'String',
    :'project_id' => :'String',
    :'proxy_acs_url' => :'String',
    :'proxy_oidc_redirect_url' => :'String',
    :'proxy_saml_audience_override' => :'String',
    :'proxy_scim_server_url' => :'String',
    :'saml_mapper_url' => :'String',
    :'scim_mapper_url' => :'String',
    :'value' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 381

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      apple_mapper_url == o.apple_mapper_url &&
      auth0_mapper_url == o.auth0_mapper_url &&
      created_at == o.created_at &&
      custom_hostname_id == o.custom_hostname_id &&
      enable_scim == o.enable_scim &&
      enable_sso == o.enable_sso &&
      expires_at == o.expires_at &&
      facebook_mapper_url == o.facebook_mapper_url &&
      generic_oidc_mapper_url == o.generic_oidc_mapper_url &&
      github_mapper_url == o.github_mapper_url &&
      gitlab_mapper_url == o.gitlab_mapper_url &&
      google_mapper_url == o.google_mapper_url &&
      id == o.id &&
      microsoft_mapper_url == o.microsoft_mapper_url &&
      netid_mapper_url == o.netid_mapper_url &&
      organization_id == o.organization_id &&
      project_id == o.project_id &&
      proxy_acs_url == o.proxy_acs_url &&
      proxy_oidc_redirect_url == o.proxy_oidc_redirect_url &&
      proxy_saml_audience_override == o.proxy_saml_audience_override &&
      proxy_scim_server_url == o.proxy_scim_server_url &&
      saml_mapper_url == o.saml_mapper_url &&
      scim_mapper_url == o.scim_mapper_url &&
      value == o.value
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 520

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


412
413
414
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 412

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



418
419
420
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 418

def hash
  [apple_mapper_url, auth0_mapper_url, created_at, custom_hostname_id, enable_scim, enable_sso, expires_at, facebook_mapper_url, generic_oidc_mapper_url, github_mapper_url, gitlab_mapper_url, google_mapper_url, id, microsoft_mapper_url, netid_mapper_url, organization_id, project_id, proxy_acs_url, proxy_oidc_redirect_url, proxy_saml_audience_override, proxy_scim_server_url, saml_mapper_url, scim_mapper_url, value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 291

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 496

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 502

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



490
491
492
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 490

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



319
320
321
322
323
324
325
326
327
# File 'lib/ory-client/models/onboarding_portal_link.rb', line 319

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expires_at.nil?
  return false if @id.nil?
  return false if @organization_id.nil?
  return false if @project_id.nil?
  return false if @value.nil?
  true
end