Class: OryClient::OnboardingPortalOrganization
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::OnboardingPortalOrganization
- Defined in:
- lib/ory-client/models/onboarding_portal_organization.rb
Instance Attribute Summary collapse
-
#apple_mapper_url ⇒ Object
AppleMapper specifies the JSONNet code snippet which uses Apple’s profile information to hydrate the identity’s data.
-
#auth0_mapper_url ⇒ Object
Auth0Mapper specifies the JSONNet code snippet which uses Auth0’s profile information to hydrate the identity’s data.
-
#base_url ⇒ Object
Returns the value of attribute base_url.
-
#facebook_mapper_url ⇒ Object
FacebookMapper specifies the JSONNet code snippet which uses Facebook’s profile information to hydrate the identity’s data.
-
#generic_oidc_mapper_url ⇒ Object
GenericOIDCMapper specifies the JSONNet code snippet which uses the OIDC Provider’s profile information to hydrate the identity’s data.
-
#github_mapper_url ⇒ Object
GithubMapper specifies the JSONNet code snippet which uses GitHub’s profile information to hydrate the identity’s data.
-
#gitlab_mapper_url ⇒ Object
GitLabMapper specifies the JSONNet code snippet which uses GitLab’s profile information to hydrate the identity’s data.
-
#google_mapper_url ⇒ Object
GoogleMapper specifies the JSONNet code snippet which uses Google’s profile information to hydrate the identity’s data.
-
#kratos_selfservice_methods_oidc_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_oidc_config_providers.
-
#kratos_selfservice_methods_saml_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_saml_config_providers.
-
#microsoft_mapper_url ⇒ Object
MicrosoftMapper specifies the JSONNet code snippet which uses Microsoft’s profile information to hydrate the identity’s data.
-
#netid_mapper_url ⇒ Object
NetIDMapper specifies the JSONNet code snippet which uses NetID’s profile information to hydrate the identity’s data.
-
#oidc_sso_enabled ⇒ Object
Returns the value of attribute oidc_sso_enabled.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#organization_label ⇒ Object
Organization Label.
-
#proxy_acs_url ⇒ Object
Proxy ACS URL if overriding with a customer-controlled URL.
-
#proxy_oidc_redirect_url ⇒ Object
Proxy OIDC Redirect URL if overriding with a customer-controlled URL.
-
#proxy_saml_audience_override ⇒ Object
SAML Audience Override if overriding with a customer-controlled one.
-
#proxy_scim_server_url ⇒ Object
Proxy SCIM Server URL if overriding with a customer-controlled URL.
-
#revision_id ⇒ Object
Returns the value of attribute revision_id.
-
#saml_mapper_url ⇒ Object
SAMLMapper specifies the JSONNet code snippet which uses the SAML Provider’s profile information to hydrate the identity’s data.
-
#saml_sso_enabled ⇒ Object
Returns the value of attribute saml_sso_enabled.
-
#scim_clients ⇒ Object
Returns the value of attribute scim_clients.
-
#scim_enabled ⇒ Object
Returns the value of attribute scim_enabled.
-
#scim_mapper_url ⇒ Object
SCIMMapper specifies the JSONNet code snippet which uses the SCIM Provider’s profile information to hydrate the identity’s data.
-
#sso_enabled ⇒ Object
Returns the value of attribute sso_enabled.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OnboardingPortalOrganization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OnboardingPortalOrganization
Initializes the object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 168 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OnboardingPortalOrganization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OnboardingPortalOrganization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'apple_mapper_url') self.apple_mapper_url = attributes[:'apple_mapper_url'] end if attributes.key?(:'auth0_mapper_url') self.auth0_mapper_url = attributes[:'auth0_mapper_url'] end if attributes.key?(:'base_url') self.base_url = attributes[:'base_url'] else self.base_url = nil end if attributes.key?(:'facebook_mapper_url') self.facebook_mapper_url = attributes[:'facebook_mapper_url'] end if attributes.key?(:'generic_oidc_mapper_url') self.generic_oidc_mapper_url = attributes[:'generic_oidc_mapper_url'] end if attributes.key?(:'github_mapper_url') self.github_mapper_url = attributes[:'github_mapper_url'] end if attributes.key?(:'gitlab_mapper_url') self.gitlab_mapper_url = attributes[:'gitlab_mapper_url'] end if attributes.key?(:'google_mapper_url') self.google_mapper_url = attributes[:'google_mapper_url'] end if attributes.key?(:'kratos_selfservice_methods_oidc_config_providers') if (value = attributes[:'kratos_selfservice_methods_oidc_config_providers']).is_a?(Array) self.kratos_selfservice_methods_oidc_config_providers = value end else self.kratos_selfservice_methods_oidc_config_providers = nil end if attributes.key?(:'kratos_selfservice_methods_saml_config_providers') if (value = attributes[:'kratos_selfservice_methods_saml_config_providers']).is_a?(Array) self.kratos_selfservice_methods_saml_config_providers = value end else self.kratos_selfservice_methods_saml_config_providers = nil end if attributes.key?(:'microsoft_mapper_url') self.microsoft_mapper_url = attributes[:'microsoft_mapper_url'] end if attributes.key?(:'netid_mapper_url') self.netid_mapper_url = attributes[:'netid_mapper_url'] end if attributes.key?(:'oidc_sso_enabled') self.oidc_sso_enabled = attributes[:'oidc_sso_enabled'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] else self.organization_id = nil end if attributes.key?(:'organization_label') self.organization_label = attributes[:'organization_label'] end if attributes.key?(:'proxy_acs_url') self.proxy_acs_url = attributes[:'proxy_acs_url'] end if attributes.key?(:'proxy_oidc_redirect_url') self.proxy_oidc_redirect_url = attributes[:'proxy_oidc_redirect_url'] end if attributes.key?(:'proxy_saml_audience_override') self.proxy_saml_audience_override = attributes[:'proxy_saml_audience_override'] end if attributes.key?(:'proxy_scim_server_url') self.proxy_scim_server_url = attributes[:'proxy_scim_server_url'] end if attributes.key?(:'revision_id') self.revision_id = attributes[:'revision_id'] else self.revision_id = nil end if attributes.key?(:'saml_mapper_url') self.saml_mapper_url = attributes[:'saml_mapper_url'] end if attributes.key?(:'saml_sso_enabled') self.saml_sso_enabled = attributes[:'saml_sso_enabled'] end if attributes.key?(:'scim_clients') if (value = attributes[:'scim_clients']).is_a?(Array) self.scim_clients = value end else self.scim_clients = nil end if attributes.key?(:'scim_enabled') self.scim_enabled = attributes[:'scim_enabled'] else self.scim_enabled = nil end if attributes.key?(:'scim_mapper_url') self.scim_mapper_url = attributes[:'scim_mapper_url'] end if attributes.key?(:'sso_enabled') self.sso_enabled = attributes[:'sso_enabled'] else self.sso_enabled = nil end end |
Instance Attribute Details
#apple_mapper_url ⇒ Object
AppleMapper specifies the JSONNet code snippet which uses Apple’s profile information to hydrate the identity’s data.
19 20 21 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 19 def apple_mapper_url @apple_mapper_url end |
#auth0_mapper_url ⇒ Object
Auth0Mapper specifies the JSONNet code snippet which uses Auth0’s profile information to hydrate the identity’s data.
22 23 24 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 22 def auth0_mapper_url @auth0_mapper_url end |
#base_url ⇒ Object
Returns the value of attribute base_url.
24 25 26 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 24 def base_url @base_url end |
#facebook_mapper_url ⇒ Object
FacebookMapper specifies the JSONNet code snippet which uses Facebook’s profile information to hydrate the identity’s data.
27 28 29 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 27 def facebook_mapper_url @facebook_mapper_url end |
#generic_oidc_mapper_url ⇒ Object
GenericOIDCMapper specifies the JSONNet code snippet which uses the OIDC Provider’s profile information to hydrate the identity’s data.
30 31 32 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 30 def generic_oidc_mapper_url @generic_oidc_mapper_url end |
#github_mapper_url ⇒ Object
GithubMapper specifies the JSONNet code snippet which uses GitHub’s profile information to hydrate the identity’s data.
33 34 35 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 33 def github_mapper_url @github_mapper_url end |
#gitlab_mapper_url ⇒ Object
GitLabMapper specifies the JSONNet code snippet which uses GitLab’s profile information to hydrate the identity’s data.
36 37 38 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 36 def gitlab_mapper_url @gitlab_mapper_url end |
#google_mapper_url ⇒ Object
GoogleMapper specifies the JSONNet code snippet which uses Google’s profile information to hydrate the identity’s data.
39 40 41 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 39 def google_mapper_url @google_mapper_url end |
#kratos_selfservice_methods_oidc_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_oidc_config_providers.
41 42 43 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 41 def kratos_selfservice_methods_oidc_config_providers @kratos_selfservice_methods_oidc_config_providers end |
#kratos_selfservice_methods_saml_config_providers ⇒ Object
Returns the value of attribute kratos_selfservice_methods_saml_config_providers.
43 44 45 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 43 def kratos_selfservice_methods_saml_config_providers @kratos_selfservice_methods_saml_config_providers end |
#microsoft_mapper_url ⇒ Object
MicrosoftMapper specifies the JSONNet code snippet which uses Microsoft’s profile information to hydrate the identity’s data.
46 47 48 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 46 def microsoft_mapper_url @microsoft_mapper_url end |
#netid_mapper_url ⇒ Object
NetIDMapper specifies the JSONNet code snippet which uses NetID’s profile information to hydrate the identity’s data.
49 50 51 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 49 def netid_mapper_url @netid_mapper_url end |
#oidc_sso_enabled ⇒ Object
Returns the value of attribute oidc_sso_enabled.
51 52 53 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 51 def oidc_sso_enabled @oidc_sso_enabled end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
53 54 55 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 53 def organization_id @organization_id end |
#organization_label ⇒ Object
Organization Label
56 57 58 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 56 def organization_label @organization_label end |
#proxy_acs_url ⇒ Object
Proxy ACS URL if overriding with a customer-controlled URL
59 60 61 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 59 def proxy_acs_url @proxy_acs_url end |
#proxy_oidc_redirect_url ⇒ Object
Proxy OIDC Redirect URL if overriding with a customer-controlled URL
62 63 64 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 62 def proxy_oidc_redirect_url @proxy_oidc_redirect_url end |
#proxy_saml_audience_override ⇒ Object
SAML Audience Override if overriding with a customer-controlled one
65 66 67 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 65 def proxy_saml_audience_override @proxy_saml_audience_override end |
#proxy_scim_server_url ⇒ Object
Proxy SCIM Server URL if overriding with a customer-controlled URL
68 69 70 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 68 def proxy_scim_server_url @proxy_scim_server_url end |
#revision_id ⇒ Object
Returns the value of attribute revision_id.
70 71 72 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 70 def revision_id @revision_id end |
#saml_mapper_url ⇒ Object
SAMLMapper specifies the JSONNet code snippet which uses the SAML Provider’s profile information to hydrate the identity’s data.
73 74 75 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 73 def saml_mapper_url @saml_mapper_url end |
#saml_sso_enabled ⇒ Object
Returns the value of attribute saml_sso_enabled.
75 76 77 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 75 def saml_sso_enabled @saml_sso_enabled end |
#scim_clients ⇒ Object
Returns the value of attribute scim_clients.
77 78 79 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 77 def scim_clients @scim_clients end |
#scim_enabled ⇒ Object
Returns the value of attribute scim_enabled.
79 80 81 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 79 def scim_enabled @scim_enabled end |
#scim_mapper_url ⇒ Object
SCIMMapper specifies the JSONNet code snippet which uses the SCIM Provider’s profile information to hydrate the identity’s data.
82 83 84 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 82 def scim_mapper_url @scim_mapper_url end |
#sso_enabled ⇒ Object
Returns the value of attribute sso_enabled.
84 85 86 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 84 def sso_enabled @sso_enabled end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
119 120 121 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 119 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
124 125 126 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 124 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 87 def self.attribute_map { :'apple_mapper_url' => :'apple_mapper_url', :'auth0_mapper_url' => :'auth0_mapper_url', :'base_url' => :'base_url', :'facebook_mapper_url' => :'facebook_mapper_url', :'generic_oidc_mapper_url' => :'generic_oidc_mapper_url', :'github_mapper_url' => :'github_mapper_url', :'gitlab_mapper_url' => :'gitlab_mapper_url', :'google_mapper_url' => :'google_mapper_url', :'kratos_selfservice_methods_oidc_config_providers' => :'kratos_selfservice_methods_oidc_config_providers', :'kratos_selfservice_methods_saml_config_providers' => :'kratos_selfservice_methods_saml_config_providers', :'microsoft_mapper_url' => :'microsoft_mapper_url', :'netid_mapper_url' => :'netid_mapper_url', :'oidc_sso_enabled' => :'oidc_sso_enabled', :'organization_id' => :'organization_id', :'organization_label' => :'organization_label', :'proxy_acs_url' => :'proxy_acs_url', :'proxy_oidc_redirect_url' => :'proxy_oidc_redirect_url', :'proxy_saml_audience_override' => :'proxy_saml_audience_override', :'proxy_scim_server_url' => :'proxy_scim_server_url', :'revision_id' => :'revision_id', :'saml_mapper_url' => :'saml_mapper_url', :'saml_sso_enabled' => :'saml_sso_enabled', :'scim_clients' => :'scim_clients', :'scim_enabled' => :'scim_enabled', :'scim_mapper_url' => :'scim_mapper_url', :'sso_enabled' => :'sso_enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 492 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
161 162 163 164 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 161 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 129 def self.openapi_types { :'apple_mapper_url' => :'String', :'auth0_mapper_url' => :'String', :'base_url' => :'String', :'facebook_mapper_url' => :'String', :'generic_oidc_mapper_url' => :'String', :'github_mapper_url' => :'String', :'gitlab_mapper_url' => :'String', :'google_mapper_url' => :'String', :'kratos_selfservice_methods_oidc_config_providers' => :'Array<NormalizedProjectRevisionThirdPartyProvider>', :'kratos_selfservice_methods_saml_config_providers' => :'Array<NormalizedProjectRevisionSAMLProvider>', :'microsoft_mapper_url' => :'String', :'netid_mapper_url' => :'String', :'oidc_sso_enabled' => :'Boolean', :'organization_id' => :'String', :'organization_label' => :'String', :'proxy_acs_url' => :'String', :'proxy_oidc_redirect_url' => :'String', :'proxy_saml_audience_override' => :'String', :'proxy_scim_server_url' => :'String', :'revision_id' => :'String', :'saml_mapper_url' => :'String', :'saml_sso_enabled' => :'Boolean', :'scim_clients' => :'Array<NormalizedProjectRevisionScimClient>', :'scim_enabled' => :'Boolean', :'scim_mapper_url' => :'String', :'sso_enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 446 def ==(o) return true if self.equal?(o) self.class == o.class && apple_mapper_url == o.apple_mapper_url && auth0_mapper_url == o.auth0_mapper_url && base_url == o.base_url && facebook_mapper_url == o.facebook_mapper_url && generic_oidc_mapper_url == o.generic_oidc_mapper_url && github_mapper_url == o.github_mapper_url && gitlab_mapper_url == o.gitlab_mapper_url && google_mapper_url == o.google_mapper_url && kratos_selfservice_methods_oidc_config_providers == o.kratos_selfservice_methods_oidc_config_providers && kratos_selfservice_methods_saml_config_providers == o.kratos_selfservice_methods_saml_config_providers && microsoft_mapper_url == o.microsoft_mapper_url && netid_mapper_url == o.netid_mapper_url && oidc_sso_enabled == o.oidc_sso_enabled && organization_id == o.organization_id && organization_label == o.organization_label && proxy_acs_url == o.proxy_acs_url && proxy_oidc_redirect_url == o.proxy_oidc_redirect_url && proxy_saml_audience_override == o.proxy_saml_audience_override && proxy_scim_server_url == o.proxy_scim_server_url && revision_id == o.revision_id && saml_mapper_url == o.saml_mapper_url && saml_sso_enabled == o.saml_sso_enabled && scim_clients == o.scim_clients && scim_enabled == o.scim_enabled && scim_mapper_url == o.scim_mapper_url && sso_enabled == o.sso_enabled end |
#eql?(o) ⇒ Boolean
479 480 481 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 479 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
485 486 487 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 485 def hash [apple_mapper_url, auth0_mapper_url, base_url, facebook_mapper_url, generic_oidc_mapper_url, github_mapper_url, gitlab_mapper_url, google_mapper_url, kratos_selfservice_methods_oidc_config_providers, kratos_selfservice_methods_saml_config_providers, microsoft_mapper_url, netid_mapper_url, oidc_sso_enabled, organization_id, organization_label, proxy_acs_url, proxy_oidc_redirect_url, proxy_saml_audience_override, proxy_scim_server_url, revision_id, saml_mapper_url, saml_sso_enabled, scim_clients, scim_enabled, scim_mapper_url, sso_enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 311 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @base_url.nil? invalid_properties.push('invalid value for "base_url", base_url cannot be nil.') end if @kratos_selfservice_methods_oidc_config_providers.nil? invalid_properties.push('invalid value for "kratos_selfservice_methods_oidc_config_providers", kratos_selfservice_methods_oidc_config_providers cannot be nil.') end if @kratos_selfservice_methods_saml_config_providers.nil? invalid_properties.push('invalid value for "kratos_selfservice_methods_saml_config_providers", kratos_selfservice_methods_saml_config_providers cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @revision_id.nil? invalid_properties.push('invalid value for "revision_id", revision_id cannot be nil.') end if @scim_clients.nil? invalid_properties.push('invalid value for "scim_clients", scim_clients cannot be nil.') end if @scim_enabled.nil? invalid_properties.push('invalid value for "scim_enabled", scim_enabled cannot be nil.') end if @sso_enabled.nil? invalid_properties.push('invalid value for "sso_enabled", sso_enabled cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 514 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/ory-client/models/onboarding_portal_organization.rb', line 351 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @base_url.nil? return false if @kratos_selfservice_methods_oidc_config_providers.nil? return false if @kratos_selfservice_methods_saml_config_providers.nil? return false if @organization_id.nil? return false if @revision_id.nil? return false if @scim_clients.nil? return false if @scim_enabled.nil? return false if @sso_enabled.nil? true end |