Class: OryClient::Organization
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::Organization
- Defined in:
- lib/ory-client/models/organization.rb
Overview
B2B SSO Organization
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default_region ⇒ Object
DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly.
-
#domains ⇒ Object
The list of organization’s domains.
-
#id ⇒ Object
The organization’s ID.
-
#label ⇒ Object
The organization’s human-readable label.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Organization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Organization
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/ory-client/models/organization.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::Organization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::Organization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'default_region') self.default_region = attributes[:'default_region'] end if attributes.key?(:'domains') if (value = attributes[:'domains']).is_a?(Array) self.domains = value end else self.domains = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
19 20 21 |
# File 'lib/ory-client/models/organization.rb', line 19 def created_at @created_at end |
#default_region ⇒ Object
DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global
22 23 24 |
# File 'lib/ory-client/models/organization.rb', line 22 def default_region @default_region end |
#domains ⇒ Object
The list of organization’s domains.
25 26 27 |
# File 'lib/ory-client/models/organization.rb', line 25 def domains @domains end |
#id ⇒ Object
The organization’s ID.
28 29 30 |
# File 'lib/ory-client/models/organization.rb', line 28 def id @id end |
#label ⇒ Object
The organization’s human-readable label.
31 32 33 |
# File 'lib/ory-client/models/organization.rb', line 31 def label @label end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/ory-client/models/organization.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/ory-client/models/organization.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/ory-client/models/organization.rb', line 56 def self.attribute_map { :'created_at' => :'created_at', :'default_region' => :'default_region', :'domains' => :'domains', :'id' => :'id', :'label' => :'label' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/ory-client/models/organization.rb', line 254 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/ory-client/models/organization.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/ory-client/models/organization.rb', line 77 def self.openapi_types { :'created_at' => :'Time', :'default_region' => :'String', :'domains' => :'Array<String>', :'id' => :'String', :'label' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 |
# File 'lib/ory-client/models/organization.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && default_region == o.default_region && domains == o.domains && id == o.id && label == o.label end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/ory-client/models/organization.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/ory-client/models/organization.rb', line 247 def hash [created_at, default_region, domains, id, label].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/ory-client/models/organization.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @domains.nil? invalid_properties.push('invalid value for "domains", domains cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/ory-client/models/organization.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/ory-client/models/organization.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? default_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"]) return false unless default_region_validator.valid?(@default_region) return false if @domains.nil? return false if @id.nil? return false if @label.nil? true end |