Class: OryClient::OrganizationBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::OrganizationBody
- Defined in:
- lib/ory-client/models/organization_body.rb
Overview
Create B2B SSO Organization Request Body
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#default_region ⇒ Object
DefaultRegion is the default Ory region for identities provisioned into this organization via JIT.
-
#domains ⇒ Object
Domains contains the list of organization’s domains.
-
#label ⇒ Object
Label contains the organization’s label.
-
#session_lifespan ⇒ Object
SessionLifespan overrides the project-level session.lifespan for sessions issued for this organization.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationBody
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ory-client/models/organization_body.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::OrganizationBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::OrganizationBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'default_region') self.default_region = attributes[:'default_region'] end if attributes.key?(:'domains') if (value = attributes[:'domains']).is_a?(Array) self.domains = value end end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'session_lifespan') self.session_lifespan = attributes[:'session_lifespan'] end end |
Instance Attribute Details
#default_region ⇒ Object
DefaultRegion is the default Ory region for identities provisioned into this organization via JIT. Must be inside the project’s home region. Empty (or omitted) means the organization has no default region: each identity provisioned via JIT is then homed in the gateway region of the request that created it, constrained by the project’s home region. On update, an empty string clears the value. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global
20 21 22 |
# File 'lib/ory-client/models/organization_body.rb', line 20 def default_region @default_region end |
#domains ⇒ Object
Domains contains the list of organization’s domains.
23 24 25 |
# File 'lib/ory-client/models/organization_body.rb', line 23 def domains @domains end |
#label ⇒ Object
Label contains the organization’s label.
26 27 28 |
# File 'lib/ory-client/models/organization_body.rb', line 26 def label @label end |
#session_lifespan ⇒ Object
SessionLifespan overrides the project-level session.lifespan for sessions issued for this organization. A Go duration string between 1m and 8760h (e.g. "1h", "24h"). Send "" to clear and inherit the project default. Omit to leave the existing value unchanged on update.
29 30 31 |
# File 'lib/ory-client/models/organization_body.rb', line 29 def session_lifespan @session_lifespan end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/ory-client/models/organization_body.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/ory-client/models/organization_body.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 |
# File 'lib/ory-client/models/organization_body.rb', line 54 def self.attribute_map { :'default_region' => :'default_region', :'domains' => :'domains', :'label' => :'label', :'session_lifespan' => :'session_lifespan' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ory-client/models/organization_body.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/ory-client/models/organization_body.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 |
# File 'lib/ory-client/models/organization_body.rb', line 74 def self.openapi_types { :'default_region' => :'String', :'domains' => :'Array<String>', :'label' => :'String', :'session_lifespan' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 |
# File 'lib/ory-client/models/organization_body.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && default_region == o.default_region && domains == o.domains && label == o.label && session_lifespan == o.session_lifespan end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/ory-client/models/organization_body.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/ory-client/models/organization_body.rb', line 170 def hash [default_region, domains, label, session_lifespan].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 |
# File 'lib/ory-client/models/organization_body.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ory-client/models/organization_body.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 |
# File 'lib/ory-client/models/organization_body.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' default_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"]) return false unless default_region_validator.valid?(@default_region) true end |