Class: OryClient::PlanDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::PlanDetails
- Defined in:
- lib/ory-client/models/plan_details.rb
Instance Attribute Summary collapse
-
#base_fee_monthly ⇒ Object
BaseFeeMonthly is the monthly base fee for the plan.
-
#base_fee_yearly ⇒ Object
BaseFeeYearly is the yearly base fee for the plan.
-
#custom ⇒ Object
Custom is true if the plan is custom.
-
#description ⇒ Object
Description is the description of the plan.
-
#development_features ⇒ Object
Returns the value of attribute development_features.
-
#features ⇒ Object
Returns the value of attribute features.
-
#latest ⇒ Object
Latest is true if the plan is the latest version of a plan and should be available for self-service usage.
-
#name ⇒ Object
Name is the name of the plan.
-
#production_features ⇒ Object
Returns the value of attribute production_features.
-
#staging_features ⇒ Object
Returns the value of attribute staging_features.
-
#version ⇒ Object
Version is the version of the plan.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlanDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlanDetails
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/ory-client/models/plan_details.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::PlanDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::PlanDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'base_fee_monthly') self.base_fee_monthly = attributes[:'base_fee_monthly'] else self.base_fee_monthly = nil end if attributes.key?(:'base_fee_yearly') self.base_fee_yearly = attributes[:'base_fee_yearly'] else self.base_fee_yearly = nil end if attributes.key?(:'custom') self.custom = attributes[:'custom'] else self.custom = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'development_features') if (value = attributes[:'development_features']).is_a?(Hash) self.development_features = value end else self.development_features = nil end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Hash) self.features = value end else self.features = nil end if attributes.key?(:'latest') self.latest = attributes[:'latest'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'production_features') if (value = attributes[:'production_features']).is_a?(Hash) self.production_features = value end else self.production_features = nil end if attributes.key?(:'staging_features') if (value = attributes[:'staging_features']).is_a?(Hash) self.staging_features = value end else self.staging_features = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end end |
Instance Attribute Details
#base_fee_monthly ⇒ Object
BaseFeeMonthly is the monthly base fee for the plan.
19 20 21 |
# File 'lib/ory-client/models/plan_details.rb', line 19 def base_fee_monthly @base_fee_monthly end |
#base_fee_yearly ⇒ Object
BaseFeeYearly is the yearly base fee for the plan.
22 23 24 |
# File 'lib/ory-client/models/plan_details.rb', line 22 def base_fee_yearly @base_fee_yearly end |
#custom ⇒ Object
Custom is true if the plan is custom. This means it will be hidden from the pricing page.
25 26 27 |
# File 'lib/ory-client/models/plan_details.rb', line 25 def custom @custom end |
#description ⇒ Object
Description is the description of the plan.
28 29 30 |
# File 'lib/ory-client/models/plan_details.rb', line 28 def description @description end |
#development_features ⇒ Object
Returns the value of attribute development_features.
30 31 32 |
# File 'lib/ory-client/models/plan_details.rb', line 30 def development_features @development_features end |
#features ⇒ Object
Returns the value of attribute features.
32 33 34 |
# File 'lib/ory-client/models/plan_details.rb', line 32 def features @features end |
#latest ⇒ Object
Latest is true if the plan is the latest version of a plan and should be available for self-service usage.
35 36 37 |
# File 'lib/ory-client/models/plan_details.rb', line 35 def latest @latest end |
#name ⇒ Object
Name is the name of the plan.
38 39 40 |
# File 'lib/ory-client/models/plan_details.rb', line 38 def name @name end |
#production_features ⇒ Object
Returns the value of attribute production_features.
40 41 42 |
# File 'lib/ory-client/models/plan_details.rb', line 40 def production_features @production_features end |
#staging_features ⇒ Object
Returns the value of attribute staging_features.
42 43 44 |
# File 'lib/ory-client/models/plan_details.rb', line 42 def staging_features @staging_features end |
#version ⇒ Object
Version is the version of the plan. The combination of ‘name@version` must be unique.
45 46 47 |
# File 'lib/ory-client/models/plan_details.rb', line 45 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/ory-client/models/plan_details.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/ory-client/models/plan_details.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/ory-client/models/plan_details.rb', line 48 def self.attribute_map { :'base_fee_monthly' => :'base_fee_monthly', :'base_fee_yearly' => :'base_fee_yearly', :'custom' => :'custom', :'description' => :'description', :'development_features' => :'development_features', :'features' => :'features', :'latest' => :'latest', :'name' => :'name', :'production_features' => :'production_features', :'staging_features' => :'staging_features', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/ory-client/models/plan_details.rb', line 384 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/ory-client/models/plan_details.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/ory-client/models/plan_details.rb', line 75 def self.openapi_types { :'base_fee_monthly' => :'Integer', :'base_fee_yearly' => :'Integer', :'custom' => :'Boolean', :'description' => :'String', :'development_features' => :'Hash<String, GenericUsage>', :'features' => :'Hash<String, GenericUsage>', :'latest' => :'Boolean', :'name' => :'String', :'production_features' => :'Hash<String, GenericUsage>', :'staging_features' => :'Hash<String, GenericUsage>', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/ory-client/models/plan_details.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && base_fee_monthly == o.base_fee_monthly && base_fee_yearly == o.base_fee_yearly && custom == o.custom && description == o.description && development_features == o.development_features && features == o.features && latest == o.latest && name == o.name && production_features == o.production_features && staging_features == o.staging_features && version == o.version end |
#eql?(o) ⇒ Boolean
371 372 373 |
# File 'lib/ory-client/models/plan_details.rb', line 371 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/ory-client/models/plan_details.rb', line 377 def hash [base_fee_monthly, base_fee_yearly, custom, description, development_features, features, latest, name, production_features, staging_features, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ory-client/models/plan_details.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @base_fee_monthly.nil? invalid_properties.push('invalid value for "base_fee_monthly", base_fee_monthly cannot be nil.') end if @base_fee_yearly.nil? invalid_properties.push('invalid value for "base_fee_yearly", base_fee_yearly cannot be nil.') end if @custom.nil? invalid_properties.push('invalid value for "custom", custom cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @development_features.nil? invalid_properties.push('invalid value for "development_features", development_features cannot be nil.') end if @features.nil? invalid_properties.push('invalid value for "features", features cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @production_features.nil? invalid_properties.push('invalid value for "production_features", production_features cannot be nil.') end if @staging_features.nil? invalid_properties.push('invalid value for "staging_features", staging_features cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/ory-client/models/plan_details.rb', line 406 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ory-client/models/plan_details.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @base_fee_monthly.nil? return false if @base_fee_yearly.nil? return false if @custom.nil? return false if @description.nil? return false if @development_features.nil? return false if @features.nil? return false if @name.nil? return false if @production_features.nil? return false if @staging_features.nil? return false if @version.nil? true end |