Class: OryClient::ProjectMember

Inherits:
ApiModelBase show all
Defined in:
lib/ory-client/models/project_member.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectMember

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ory-client/models/project_member.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::ProjectMember` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::ProjectMember`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'break_glass')
    self.break_glass = attributes[:'break_glass']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'email_verified')
    self.email_verified = attributes[:'email_verified']
  else
    self.email_verified = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end
end

Instance Attribute Details

#break_glassObject

BreakGlass is true when the identity’s recovery address has break-glass recovery enabled for the identity’s current organization.



19
20
21
# File 'lib/ory-client/models/project_member.rb', line 19

def break_glass
  @break_glass
end

#emailObject

Returns the value of attribute email.



21
22
23
# File 'lib/ory-client/models/project_member.rb', line 21

def email
  @email
end

#email_verifiedObject

Returns the value of attribute email_verified.



23
24
25
# File 'lib/ory-client/models/project_member.rb', line 23

def email_verified
  @email_verified
end

#idObject

Returns the value of attribute id.



25
26
27
# File 'lib/ory-client/models/project_member.rb', line 25

def id
  @id
end

#nameObject

Returns the value of attribute name.



27
28
29
# File 'lib/ory-client/models/project_member.rb', line 27

def name
  @name
end

#organization_idObject

Returns the value of attribute organization_id.



29
30
31
# File 'lib/ory-client/models/project_member.rb', line 29

def organization_id
  @organization_id
end

#roleObject

Returns the value of attribute role.



31
32
33
# File 'lib/ory-client/models/project_member.rb', line 31

def role
  @role
end

#sourceObject

Whether the member has access through the project directly or through workspace membership.



34
35
36
# File 'lib/ory-client/models/project_member.rb', line 34

def source
  @source
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/ory-client/models/project_member.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/ory-client/models/project_member.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/ory-client/models/project_member.rb', line 59

def self.attribute_map
  {
    :'break_glass' => :'break_glass',
    :'email' => :'email',
    :'email_verified' => :'email_verified',
    :'id' => :'id',
    :'name' => :'name',
    :'organization_id' => :'organization_id',
    :'role' => :'role',
    :'source' => :'source'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/ory-client/models/project_member.rb', line 294

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
# File 'lib/ory-client/models/project_member.rb', line 97

def self.openapi_nullable
  Set.new([
    :'organization_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/ory-client/models/project_member.rb', line 83

def self.openapi_types
  {
    :'break_glass' => :'Boolean',
    :'email' => :'String',
    :'email_verified' => :'Boolean',
    :'id' => :'String',
    :'name' => :'String',
    :'organization_id' => :'String',
    :'role' => :'String',
    :'source' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/ory-client/models/project_member.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      break_glass == o.break_glass &&
      email == o.email &&
      email_verified == o.email_verified &&
      id == o.id &&
      name == o.name &&
      organization_id == o.organization_id &&
      role == o.role &&
      source == o.source
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/ory-client/models/project_member.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/ory-client/models/project_member.rb', line 287

def hash
  [break_glass, email, email_verified, id, name, organization_id, role, source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ory-client/models/project_member.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @email_verified.nil?
    invalid_properties.push('invalid value for "email_verified", email_verified cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/ory-client/models/project_member.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
# File 'lib/ory-client/models/project_member.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @email_verified.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if @role.nil?
  source_validator = EnumAttributeValidator.new('String', ["project", "workspace"])
  return false unless source_validator.valid?(@source)
  true
end