Class: OryClient::RegistrationFlow
- Inherits:
-
Object
- Object
- OryClient::RegistrationFlow
- Defined in:
- lib/ory-client/models/registration_flow.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Returns the value of attribute active.
-
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the flow expires.
-
#id ⇒ Object
ID represents the flow’s unique ID.
-
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the flow occurred.
-
#oauth2_login_challenge ⇒ Object
Ory OAuth 2.0 Login Challenge.
-
#oauth2_login_request ⇒ Object
Returns the value of attribute oauth2_login_request.
-
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos.
-
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
-
#session_token_exchange_code ⇒ Object
SessionTokenExchangeCode holds the secret code that the client can use to retrieve a session token after the flow has been completed.
-
#state ⇒ Object
State represents the state of this request: choose_method: ask the user to choose a method (e.g. registration with email) sent_email: the email has been sent to the user passed_challenge: the request was successful and the registration challenge was passed.
-
#transient_payload ⇒ Object
TransientPayload is used to pass data from the registration to a webhook.
-
#type ⇒ Object
The flow type can either be ‘api` or `browser`.
-
#ui ⇒ Object
Returns the value of attribute ui.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegistrationFlow
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RegistrationFlow
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ory-client/models/registration_flow.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::RegistrationFlow` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::RegistrationFlow`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'issued_at') self.issued_at = attributes[:'issued_at'] end if attributes.key?(:'oauth2_login_challenge') self.oauth2_login_challenge = attributes[:'oauth2_login_challenge'] end if attributes.key?(:'oauth2_login_request') self.oauth2_login_request = attributes[:'oauth2_login_request'] end if attributes.key?(:'request_url') self.request_url = attributes[:'request_url'] end if attributes.key?(:'return_to') self.return_to = attributes[:'return_to'] end if attributes.key?(:'session_token_exchange_code') self.session_token_exchange_code = attributes[:'session_token_exchange_code'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'ui') self.ui = attributes[:'ui'] end end |
Instance Attribute Details
#active ⇒ Object
Returns the value of attribute active.
18 19 20 |
# File 'lib/ory-client/models/registration_flow.rb', line 18 def active @active end |
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the flow expires. If the user still wishes to log in, a new flow has to be initiated.
21 22 23 |
# File 'lib/ory-client/models/registration_flow.rb', line 21 def expires_at @expires_at end |
#id ⇒ Object
ID represents the flow’s unique ID. When performing the registration flow, this represents the id in the registration ui’s query parameter: http://<selfservice.flows.registration.ui_url>/?flow=<id>
24 25 26 |
# File 'lib/ory-client/models/registration_flow.rb', line 24 def id @id end |
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the flow occurred.
27 28 29 |
# File 'lib/ory-client/models/registration_flow.rb', line 27 def issued_at @issued_at end |
#oauth2_login_challenge ⇒ Object
Ory OAuth 2.0 Login Challenge. This value is set using the ‘login_challenge` query parameter of the registration and login endpoints. If set will cooperate with Ory OAuth2 and OpenID to act as an OAuth2 server / OpenID Provider.
30 31 32 |
# File 'lib/ory-client/models/registration_flow.rb', line 30 def oauth2_login_challenge @oauth2_login_challenge end |
#oauth2_login_request ⇒ Object
Returns the value of attribute oauth2_login_request.
32 33 34 |
# File 'lib/ory-client/models/registration_flow.rb', line 32 def oauth2_login_request @oauth2_login_request end |
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL’s path or query for example.
35 36 37 |
# File 'lib/ory-client/models/registration_flow.rb', line 35 def request_url @request_url end |
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
38 39 40 |
# File 'lib/ory-client/models/registration_flow.rb', line 38 def return_to @return_to end |
#session_token_exchange_code ⇒ Object
SessionTokenExchangeCode holds the secret code that the client can use to retrieve a session token after the flow has been completed. This is only set if the client has requested a session token exchange code, and if the flow is of type "api", and only on creating the flow.
41 42 43 |
# File 'lib/ory-client/models/registration_flow.rb', line 41 def session_token_exchange_code @session_token_exchange_code end |
#state ⇒ Object
State represents the state of this request: choose_method: ask the user to choose a method (e.g. registration with email) sent_email: the email has been sent to the user passed_challenge: the request was successful and the registration challenge was passed.
44 45 46 |
# File 'lib/ory-client/models/registration_flow.rb', line 44 def state @state end |
#transient_payload ⇒ Object
TransientPayload is used to pass data from the registration to a webhook
47 48 49 |
# File 'lib/ory-client/models/registration_flow.rb', line 47 def transient_payload @transient_payload end |
#type ⇒ Object
The flow type can either be ‘api` or `browser`.
50 51 52 |
# File 'lib/ory-client/models/registration_flow.rb', line 50 def type @type end |
#ui ⇒ Object
Returns the value of attribute ui.
52 53 54 |
# File 'lib/ory-client/models/registration_flow.rb', line 52 def ui @ui end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/ory-client/models/registration_flow.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/ory-client/models/registration_flow.rb', line 55 def self.attribute_map { :'active' => :'active', :'expires_at' => :'expires_at', :'id' => :'id', :'issued_at' => :'issued_at', :'oauth2_login_challenge' => :'oauth2_login_challenge', :'oauth2_login_request' => :'oauth2_login_request', :'request_url' => :'request_url', :'return_to' => :'return_to', :'session_token_exchange_code' => :'session_token_exchange_code', :'state' => :'state', :'transient_payload' => :'transient_payload', :'type' => :'type', :'ui' => :'ui' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 |
# File 'lib/ory-client/models/registration_flow.rb', line 250 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 |
# File 'lib/ory-client/models/registration_flow.rb', line 98 def self.openapi_nullable Set.new([ :'state', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ory-client/models/registration_flow.rb', line 79 def self.openapi_types { :'active' => :'IdentityCredentialsType', :'expires_at' => :'Time', :'id' => :'String', :'issued_at' => :'Time', :'oauth2_login_challenge' => :'String', :'oauth2_login_request' => :'OAuth2LoginRequest', :'request_url' => :'String', :'return_to' => :'String', :'session_token_exchange_code' => :'String', :'state' => :'Object', :'transient_payload' => :'Object', :'type' => :'String', :'ui' => :'UiContainer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ory-client/models/registration_flow.rb', line 217 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && expires_at == o.expires_at && id == o.id && issued_at == o.issued_at && oauth2_login_challenge == o.oauth2_login_challenge && oauth2_login_request == o.oauth2_login_request && request_url == o.request_url && return_to == o.return_to && session_token_exchange_code == o.session_token_exchange_code && state == o.state && transient_payload == o.transient_payload && type == o.type && ui == o.ui end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/ory-client/models/registration_flow.rb', line 281 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OryClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/ory-client/models/registration_flow.rb', line 352 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/ory-client/models/registration_flow.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/ory-client/models/registration_flow.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/ory-client/models/registration_flow.rb', line 243 def hash [active, expires_at, id, issued_at, oauth2_login_challenge, oauth2_login_request, request_url, return_to, session_token_exchange_code, state, transient_payload, type, ui].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ory-client/models/registration_flow.rb', line 174 def list_invalid_properties invalid_properties = Array.new if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @issued_at.nil? invalid_properties.push('invalid value for "issued_at", issued_at cannot be nil.') end if @request_url.nil? invalid_properties.push('invalid value for "request_url", request_url cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @ui.nil? invalid_properties.push('invalid value for "ui", ui cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
328 329 330 |
# File 'lib/ory-client/models/registration_flow.rb', line 328 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/ory-client/models/registration_flow.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/ory-client/models/registration_flow.rb', line 322 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 212 213 |
# File 'lib/ory-client/models/registration_flow.rb', line 205 def valid? return false if @expires_at.nil? return false if @id.nil? return false if @issued_at.nil? return false if @request_url.nil? return false if @type.nil? return false if @ui.nil? true end |