Class: OryClient::SessionAuthenticationMethod
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::SessionAuthenticationMethod
- Defined in:
- lib/ory-client/models/session_authentication_method.rb
Overview
A singular authenticator used during authentication / login.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aal ⇒ Object
Returns the value of attribute aal.
-
#completed_at ⇒ Object
When the authentication challenge was completed.
-
#method ⇒ Object
The method used in this authenticator.
-
#organization ⇒ Object
The Organization id used for authentication.
-
#provider ⇒ Object
OIDC or SAML provider id used for authentication.
-
#upstream_acr ⇒ Object
UpstreamACR is the ‘acr` claim reported by the upstream OIDC provider, if any.
-
#upstream_amr ⇒ Object
UpstreamAMR is the ‘amr` claim reported by the upstream OIDC provider, if any.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SessionAuthenticationMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SessionAuthenticationMethod
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::SessionAuthenticationMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::SessionAuthenticationMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aal') self.aal = attributes[:'aal'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'method') self.method = attributes[:'method'] end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'upstream_acr') self.upstream_acr = attributes[:'upstream_acr'] end if attributes.key?(:'upstream_amr') if (value = attributes[:'upstream_amr']).is_a?(Array) self.upstream_amr = value end end end |
Instance Attribute Details
#aal ⇒ Object
Returns the value of attribute aal.
19 20 21 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 19 def aal @aal end |
#completed_at ⇒ Object
When the authentication challenge was completed.
22 23 24 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 22 def completed_at @completed_at end |
#method ⇒ Object
The method used in this authenticator. password CredentialsTypePassword oidc CredentialsTypeOIDC totp CredentialsTypeTOTP lookup_secret CredentialsTypeLookup webauthn CredentialsTypeWebAuthn code CredentialsTypeCodeAuth passkey CredentialsTypePasskey profile CredentialsTypeProfile saml CredentialsTypeSAML deviceauthn CredentialsTypeDeviceAuthn link_recovery CredentialsTypeRecoveryLink CredentialsTypeRecoveryLink is a special credential type linked to the link strategy (recovery flow). It is not used within the credentials object itself. code_recovery CredentialsTypeRecoveryCode
25 26 27 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 25 def method @method end |
#organization ⇒ Object
The Organization id used for authentication
28 29 30 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 28 def organization @organization end |
#provider ⇒ Object
OIDC or SAML provider id used for authentication
31 32 33 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 31 def provider @provider end |
#upstream_acr ⇒ Object
UpstreamACR is the ‘acr` claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an `acr` claim.
34 35 36 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 34 def upstream_acr @upstream_acr end |
#upstream_amr ⇒ Object
UpstreamAMR is the ‘amr` claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an `amr` claim.
37 38 39 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 37 def upstream_amr @upstream_amr end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 62 def self.attribute_map { :'aal' => :'aal', :'completed_at' => :'completed_at', :'method' => :'method', :'organization' => :'organization', :'provider' => :'provider', :'upstream_acr' => :'upstream_acr', :'upstream_amr' => :'upstream_amr' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 85 def self.openapi_types { :'aal' => :'AuthenticatorAssuranceLevel', :'completed_at' => :'Time', :'method' => :'String', :'organization' => :'String', :'provider' => :'String', :'upstream_acr' => :'String', :'upstream_amr' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && aal == o.aal && completed_at == o.completed_at && method == o.method && organization == o.organization && provider == o.provider && upstream_acr == o.upstream_acr && upstream_amr == o.upstream_amr end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 199 def hash [aal, completed_at, method, organization, provider, upstream_acr, upstream_amr].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 164 165 |
# File 'lib/ory-client/models/session_authentication_method.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' method_validator = EnumAttributeValidator.new('String', ["password", "oidc", "totp", "lookup_secret", "webauthn", "code", "passkey", "profile", "saml", "deviceauthn", "link_recovery", "code_recovery"]) return false unless method_validator.valid?(@method) true end |