Class: OryClient::SettingsFlow
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::SettingsFlow
- Defined in:
- lib/ory-client/models/settings_flow.rb
Overview
This flow is used when an identity wants to update settings (e.g. profile data, passwords, …) in a selfservice manner. We recommend reading the [User Settings Documentation](../self-service/flows/user-settings)
Instance Attribute Summary collapse
-
#active ⇒ Object
Active, if set, contains the registration method that is being used.
-
#continue_with ⇒ Object
Contains a list of actions, that could follow this flow It can, for example, contain a reference to the verification flow, created as part of the user’s registration.
-
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the flow expires.
-
#id ⇒ Object
ID represents the flow’s unique ID.
-
#identity ⇒ Object
Returns the value of attribute identity.
-
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the flow occurred.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos.
-
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
-
#state ⇒ Object
State represents the state of this flow.
-
#transient_payload ⇒ Object
TransientPayload is used to pass data from the settings flow to hooks and email templates.
-
#type ⇒ Object
The flow type can either be ‘api` or `browser`.
-
#ui ⇒ Object
Returns the value of attribute ui.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SettingsFlow
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SettingsFlow
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/ory-client/models/settings_flow.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::SettingsFlow` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::SettingsFlow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'continue_with') if (value = attributes[:'continue_with']).is_a?(Array) self.continue_with = value end end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'identity') self.identity = attributes[:'identity'] else self.identity = nil end if attributes.key?(:'issued_at') self.issued_at = attributes[:'issued_at'] else self.issued_at = nil end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'request_url') self.request_url = attributes[:'request_url'] else self.request_url = nil end if attributes.key?(:'return_to') self.return_to = attributes[:'return_to'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'ui') self.ui = attributes[:'ui'] else self.ui = nil end end |
Instance Attribute Details
#active ⇒ Object
Active, if set, contains the registration method that is being used. It is initially not set.
20 21 22 |
# File 'lib/ory-client/models/settings_flow.rb', line 20 def active @active end |
#continue_with ⇒ Object
Contains a list of actions, that could follow this flow It can, for example, contain a reference to the verification flow, created as part of the user’s registration.
23 24 25 |
# File 'lib/ory-client/models/settings_flow.rb', line 23 def continue_with @continue_with end |
#expires_at ⇒ Object
ExpiresAt is the time (UTC) when the flow expires. If the user still wishes to update the setting, a new flow has to be initiated.
26 27 28 |
# File 'lib/ory-client/models/settings_flow.rb', line 26 def expires_at @expires_at end |
#id ⇒ Object
ID represents the flow’s unique ID. When performing the settings flow, this represents the id in the settings ui’s query parameter: http://<selfservice.flows.settings.ui_url>?flow=<id>
29 30 31 |
# File 'lib/ory-client/models/settings_flow.rb', line 29 def id @id end |
#identity ⇒ Object
Returns the value of attribute identity.
31 32 33 |
# File 'lib/ory-client/models/settings_flow.rb', line 31 def identity @identity end |
#issued_at ⇒ Object
IssuedAt is the time (UTC) when the flow occurred.
34 35 36 |
# File 'lib/ory-client/models/settings_flow.rb', line 34 def issued_at @issued_at end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
36 37 38 |
# File 'lib/ory-client/models/settings_flow.rb', line 36 def organization_id @organization_id end |
#request_url ⇒ Object
RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL’s path or query for example.
39 40 41 |
# File 'lib/ory-client/models/settings_flow.rb', line 39 def request_url @request_url end |
#return_to ⇒ Object
ReturnTo contains the requested return_to URL.
42 43 44 |
# File 'lib/ory-client/models/settings_flow.rb', line 42 def return_to @return_to end |
#state ⇒ Object
State represents the state of this flow. It knows two states: show_form: No user data has been collected, or it is invalid, and thus the form should be shown. success: Indicates that the settings flow has been updated successfully with the provided data. Done will stay true when repeatedly checking. If set to true, done will revert back to false only when a flow with invalid (e.g. "please use a valid phone number") data was sent.
45 46 47 |
# File 'lib/ory-client/models/settings_flow.rb', line 45 def state @state end |
#transient_payload ⇒ Object
TransientPayload is used to pass data from the settings flow to hooks and email templates
48 49 50 |
# File 'lib/ory-client/models/settings_flow.rb', line 48 def transient_payload @transient_payload end |
#type ⇒ Object
The flow type can either be ‘api` or `browser`.
51 52 53 |
# File 'lib/ory-client/models/settings_flow.rb', line 51 def type @type end |
#ui ⇒ Object
Returns the value of attribute ui.
53 54 55 |
# File 'lib/ory-client/models/settings_flow.rb', line 53 def ui @ui end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/ory-client/models/settings_flow.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/ory-client/models/settings_flow.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ory-client/models/settings_flow.rb', line 56 def self.attribute_map { :'active' => :'active', :'continue_with' => :'continue_with', :'expires_at' => :'expires_at', :'id' => :'id', :'identity' => :'identity', :'issued_at' => :'issued_at', :'organization_id' => :'organization_id', :'request_url' => :'request_url', :'return_to' => :'return_to', :'state' => :'state', :'transient_payload' => :'transient_payload', :'type' => :'type', :'ui' => :'ui' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/ory-client/models/settings_flow.rb', line 353 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 108 109 |
# File 'lib/ory-client/models/settings_flow.rb', line 104 def self.openapi_nullable Set.new([ :'organization_id', :'state', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ory-client/models/settings_flow.rb', line 85 def self.openapi_types { :'active' => :'String', :'continue_with' => :'Array<ContinueWith>', :'expires_at' => :'Time', :'id' => :'String', :'identity' => :'Identity', :'issued_at' => :'Time', :'organization_id' => :'String', :'request_url' => :'String', :'return_to' => :'String', :'state' => :'Object', :'transient_payload' => :'Object', :'type' => :'String', :'ui' => :'UiContainer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/ory-client/models/settings_flow.rb', line 320 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && continue_with == o.continue_with && expires_at == o.expires_at && id == o.id && identity == o.identity && issued_at == o.issued_at && organization_id == o.organization_id && request_url == o.request_url && return_to == o.return_to && state == o.state && transient_payload == o.transient_payload && type == o.type && ui == o.ui end |
#eql?(o) ⇒ Boolean
340 341 342 |
# File 'lib/ory-client/models/settings_flow.rb', line 340 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
346 347 348 |
# File 'lib/ory-client/models/settings_flow.rb', line 346 def hash [active, continue_with, expires_at, id, identity, issued_at, organization_id, request_url, return_to, state, transient_payload, type, ui].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ory-client/models/settings_flow.rb', line 200 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @identity.nil? invalid_properties.push('invalid value for "identity", identity cannot be nil.') end if @issued_at.nil? invalid_properties.push('invalid value for "issued_at", issued_at cannot be nil.') end if @request_url.nil? invalid_properties.push('invalid value for "request_url", request_url cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @ui.nil? invalid_properties.push('invalid value for "ui", ui cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/ory-client/models/settings_flow.rb', line 375 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/ory-client/models/settings_flow.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @expires_at.nil? return false if @id.nil? return false if @identity.nil? return false if @issued_at.nil? return false if @request_url.nil? return false if @type.nil? return false if @ui.nil? true end |