Class: OryClient::UiNodeInputAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::UiNodeInputAttributes
- Defined in:
- lib/ory-client/models/ui_node_input_attributes.rb
Overview
InputAttributes represents the attributes of an input node
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#autocomplete ⇒ Object
The autocomplete attribute for the input.
-
#disabled ⇒ Object
Sets the input’s disabled field to true or false.
-
#label ⇒ Object
Returns the value of attribute label.
-
#maxlength ⇒ Object
MaxLength may contain the input’s maximum length.
-
#name ⇒ Object
The input’s element name.
-
#node_type ⇒ Object
NodeType represents this node’s types.
-
#onclick ⇒ Object
OnClick may contain javascript which should be executed on click.
-
#onclick_trigger ⇒ Object
OnClickTrigger may contain a WebAuthn trigger which should be executed on click.
-
#onload ⇒ Object
OnLoad may contain javascript which should be executed on load.
-
#onload_trigger ⇒ Object
OnLoadTrigger may contain a WebAuthn trigger which should be executed on load.
-
#options ⇒ Object
The allowed values for the input when the underlying JSON schema defines an ‘enum`.
-
#pattern ⇒ Object
The input’s pattern.
-
#required ⇒ Object
Mark this input field as required.
-
#type ⇒ Object
The input’s element type.
-
#value ⇒ Object
The input’s value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UiNodeInputAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UiNodeInputAttributes
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 146 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UiNodeInputAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UiNodeInputAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'autocomplete') self.autocomplete = attributes[:'autocomplete'] end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] else self.disabled = nil end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'maxlength') self.maxlength = attributes[:'maxlength'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] else self.node_type = nil end if attributes.key?(:'onclick') self.onclick = attributes[:'onclick'] end if attributes.key?(:'onclick_trigger') self.onclick_trigger = attributes[:'onclick_trigger'] end if attributes.key?(:'onload') self.onload = attributes[:'onload'] end if attributes.key?(:'onload_trigger') self.onload_trigger = attributes[:'onload_trigger'] end if attributes.key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end end if attributes.key?(:'pattern') self.pattern = attributes[:'pattern'] end if attributes.key?(:'required') self.required = attributes[:'required'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#autocomplete ⇒ Object
The autocomplete attribute for the input. email InputAttributeAutocompleteEmail tel InputAttributeAutocompleteTel url InputAttributeAutocompleteUrl current-password InputAttributeAutocompleteCurrentPassword new-password InputAttributeAutocompleteNewPassword one-time-code InputAttributeAutocompleteOneTimeCode username webauthn InputAttributeAutocompleteUsernameWebauthn
20 21 22 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 20 def autocomplete @autocomplete end |
#disabled ⇒ Object
Sets the input’s disabled field to true or false.
23 24 25 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 23 def disabled @disabled end |
#label ⇒ Object
Returns the value of attribute label.
25 26 27 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 25 def label @label end |
#maxlength ⇒ Object
MaxLength may contain the input’s maximum length.
28 29 30 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 28 def maxlength @maxlength end |
#name ⇒ Object
The input’s element name.
31 32 33 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 31 def name @name end |
#node_type ⇒ Object
NodeType represents this node’s types. It is a mirror of ‘node.type` and is primarily used to allow compatibility with OpenAPI 3.0. In this struct it technically always is "input". text Text input Input img Image a Anchor script Script div Division
34 35 36 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 34 def node_type @node_type end |
#onclick ⇒ Object
OnClick may contain javascript which should be executed on click. This is primarily used for WebAuthn. Deprecated: Using OnClick requires the use of eval() which is a security risk. Use OnClickTrigger instead.
37 38 39 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 37 def onclick @onclick end |
#onclick_trigger ⇒ Object
OnClickTrigger may contain a WebAuthn trigger which should be executed on click. The trigger maps to a JavaScript function provided by Ory, which triggers actions such as PassKey registration or login. oryWebAuthnRegistration WebAuthnTriggersWebAuthnRegistration oryWebAuthnLogin WebAuthnTriggersWebAuthnLogin oryPasskeyLogin WebAuthnTriggersPasskeyLogin oryPasskeyLoginAutocompleteInit WebAuthnTriggersPasskeyLoginAutocompleteInit oryPasskeyRegistration WebAuthnTriggersPasskeyRegistration oryPasskeySettingsRegistration WebAuthnTriggersPasskeySettingsRegistration
40 41 42 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 40 def onclick_trigger @onclick_trigger end |
#onload ⇒ Object
OnLoad may contain javascript which should be executed on load. This is primarily used for WebAuthn. Deprecated: Using OnLoad requires the use of eval() which is a security risk. Use OnLoadTrigger instead.
43 44 45 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 43 def onload @onload end |
#onload_trigger ⇒ Object
OnLoadTrigger may contain a WebAuthn trigger which should be executed on load. The trigger maps to a JavaScript function provided by Ory, which triggers actions such as PassKey registration or login. oryWebAuthnRegistration WebAuthnTriggersWebAuthnRegistration oryWebAuthnLogin WebAuthnTriggersWebAuthnLogin oryPasskeyLogin WebAuthnTriggersPasskeyLogin oryPasskeyLoginAutocompleteInit WebAuthnTriggersPasskeyLoginAutocompleteInit oryPasskeyRegistration WebAuthnTriggersPasskeyRegistration oryPasskeySettingsRegistration WebAuthnTriggersPasskeySettingsRegistration
46 47 48 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 46 def onload_trigger @onload_trigger end |
#options ⇒ Object
The allowed values for the input when the underlying JSON schema defines an ‘enum`. When present, clients should render the field as a select/dropdown rather than a free-form text input. When absent, clients continue to render a plain text input, so this field is backward compatible with UIs that do not look at it.
49 50 51 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 49 def @options end |
#pattern ⇒ Object
The input’s pattern.
52 53 54 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 52 def pattern @pattern end |
#required ⇒ Object
Mark this input field as required.
55 56 57 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 55 def required @required end |
#type ⇒ Object
The input’s element type. text InputAttributeTypeText password InputAttributeTypePassword number InputAttributeTypeNumber checkbox InputAttributeTypeCheckbox hidden InputAttributeTypeHidden email InputAttributeTypeEmail tel InputAttributeTypeTel submit InputAttributeTypeSubmit button InputAttributeTypeButton datetime-local InputAttributeTypeDateTimeLocal date InputAttributeTypeDate url InputAttributeTypeURI
58 59 60 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 58 def type @type end |
#value ⇒ Object
The input’s value.
61 62 63 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 61 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
107 108 109 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 107 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
112 113 114 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 112 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 86 def self.attribute_map { :'autocomplete' => :'autocomplete', :'disabled' => :'disabled', :'label' => :'label', :'maxlength' => :'maxlength', :'name' => :'name', :'node_type' => :'node_type', :'onclick' => :'onclick', :'onclick_trigger' => :'onclickTrigger', :'onload' => :'onload', :'onload_trigger' => :'onloadTrigger', :'options' => :'options', :'pattern' => :'pattern', :'required' => :'required', :'type' => :'type', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 383 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
138 139 140 141 142 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 138 def self.openapi_nullable Set.new([ :'value' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 117 def self.openapi_types { :'autocomplete' => :'String', :'disabled' => :'Boolean', :'label' => :'UiText', :'maxlength' => :'Integer', :'name' => :'String', :'node_type' => :'String', :'onclick' => :'String', :'onclick_trigger' => :'String', :'onload' => :'String', :'onload_trigger' => :'String', :'options' => :'Array<UiNodeInputAttributesOption>', :'pattern' => :'String', :'required' => :'Boolean', :'type' => :'String', :'value' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 348 def ==(o) return true if self.equal?(o) self.class == o.class && autocomplete == o.autocomplete && disabled == o.disabled && label == o.label && maxlength == o.maxlength && name == o.name && node_type == o.node_type && onclick == o.onclick && onclick_trigger == o.onclick_trigger && onload == o.onload && onload_trigger == o.onload_trigger && == o. && pattern == o.pattern && required == o.required && type == o.type && value == o.value end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 376 def hash [autocomplete, disabled, label, maxlength, name, node_type, onclick, onclick_trigger, onload, onload_trigger, , pattern, required, type, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 233 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @disabled.nil? invalid_properties.push('invalid value for "disabled", disabled cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @node_type.nil? invalid_properties.push('invalid value for "node_type", node_type cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 405 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/ory-client/models/ui_node_input_attributes.rb', line 257 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' autocomplete_validator = EnumAttributeValidator.new('String', ["email", "tel", "url", "current-password", "new-password", "one-time-code", "username webauthn"]) return false unless autocomplete_validator.valid?(@autocomplete) return false if @disabled.nil? return false if @name.nil? return false if @node_type.nil? node_type_validator = EnumAttributeValidator.new('String', ["input"]) return false unless node_type_validator.valid?(@node_type) onclick_trigger_validator = EnumAttributeValidator.new('String', ["oryWebAuthnRegistration", "oryWebAuthnLogin", "oryPasskeyLogin", "oryPasskeyLoginAutocompleteInit", "oryPasskeyRegistration", "oryPasskeySettingsRegistration"]) return false unless onclick_trigger_validator.valid?(@onclick_trigger) onload_trigger_validator = EnumAttributeValidator.new('String', ["oryWebAuthnRegistration", "oryWebAuthnLogin", "oryPasskeyLogin", "oryPasskeyLoginAutocompleteInit", "oryPasskeyRegistration", "oryPasskeySettingsRegistration"]) return false unless onload_trigger_validator.valid?(@onload_trigger) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["text", "password", "number", "checkbox", "hidden", "email", "tel", "submit", "button", "datetime-local", "date", "url"]) return false unless type_validator.valid?(@type) true end |