Class: OryClient::UpdateSettingsFlowWithOidcMethod
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::UpdateSettingsFlowWithOidcMethod
- Defined in:
- lib/ory-client/models/update_settings_flow_with_oidc_method.rb
Overview
Update Settings Flow with OpenID Connect Method
Instance Attribute Summary collapse
-
#csrf_token ⇒ Object
The CSRF Token.
-
#flow ⇒ Object
Flow ID is the flow's ID.
-
#link ⇒ Object
Link this provider Either this or
unlinkmust be set. -
#method ⇒ Object
Method Should be set to profile when trying to update a profile.
-
#traits ⇒ Object
The identity's traits.
-
#transient_payload ⇒ Object
Transient data to pass along to any webhooks.
-
#unlink ⇒ Object
Unlink this provider Either this or
linkmust be set. -
#upstream_parameters ⇒ Object
UpstreamParameters are the parameters that are passed to the upstream identity provider.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSettingsFlowWithOidcMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSettingsFlowWithOidcMethod
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::UpdateSettingsFlowWithOidcMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::UpdateSettingsFlowWithOidcMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'csrf_token') self.csrf_token = attributes[:'csrf_token'] end if attributes.key?(:'flow') self.flow = attributes[:'flow'] end if attributes.key?(:'link') self.link = attributes[:'link'] end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end if attributes.key?(:'traits') self.traits = attributes[:'traits'] end if attributes.key?(:'transient_payload') self.transient_payload = attributes[:'transient_payload'] end if attributes.key?(:'unlink') self.unlink = attributes[:'unlink'] end if attributes.key?(:'upstream_parameters') self.upstream_parameters = attributes[:'upstream_parameters'] end end |
Instance Attribute Details
#csrf_token ⇒ Object
The CSRF Token
20 21 22 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 20 def csrf_token @csrf_token end |
#flow ⇒ Object
Flow ID is the flow's ID.
23 24 25 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 23 def flow @flow end |
#link ⇒ Object
Link this provider Either this or unlink must be set. type: string
26 27 28 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 26 def link @link end |
#method ⇒ Object
Method Should be set to profile when trying to update a profile.
29 30 31 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 29 def method @method end |
#traits ⇒ Object
The identity's traits
32 33 34 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 32 def traits @traits end |
#transient_payload ⇒ Object
Transient data to pass along to any webhooks
35 36 37 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 35 def transient_payload @transient_payload end |
#unlink ⇒ Object
Unlink this provider Either this or link must be set. type: string
38 39 40 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 38 def unlink @unlink end |
#upstream_parameters ⇒ Object
UpstreamParameters are the parameters that are passed to the upstream identity provider. These parameters are optional and depend on what the upstream identity provider supports. Supported parameters are: - hd (string): The hd parameter limits the login/registration process to a Google Organization, e.g. mycollege.edu. - prompt (string): The prompt specifies whether the Authorization Server prompts the End-User for reauthentication and consent, e.g. select_account. - acr_values (string): The acr_values specifies the Authentication Context Class Reference values for the authorization request.
41 42 43 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 41 def upstream_parameters @upstream_parameters end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 44 def self.attribute_map { :'csrf_token' => :'csrf_token', :'flow' => :'flow', :'link' => :'link', :'method' => :'method', :'traits' => :'traits', :'transient_payload' => :'transient_payload', :'unlink' => :'unlink', :'upstream_parameters' => :'upstream_parameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 198 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 68 def self.openapi_types { :'csrf_token' => :'String', :'flow' => :'String', :'link' => :'String', :'method' => :'String', :'traits' => :'Object', :'transient_payload' => :'Object', :'unlink' => :'String', :'upstream_parameters' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && csrf_token == o.csrf_token && flow == o.flow && link == o.link && method == o.method && traits == o.traits && transient_payload == o.transient_payload && unlink == o.unlink && upstream_parameters == o.upstream_parameters end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 191 def hash [csrf_token, flow, link, method, traits, transient_payload, unlink, upstream_parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 |
# File 'lib/ory-client/models/update_settings_flow_with_oidc_method.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @method.nil? true end |