Method: OryClient::UpdateVerificationFlowWithCodeMethod#code
- Defined in:
- lib/ory-client/models/update_verification_flow_with_code_method.rb
#code ⇒ Object
Code from the recovery email If you want to submit a code, use this field, but make sure to not include the email field, as well.
19 20 21 |
# File 'lib/ory-client/models/update_verification_flow_with_code_method.rb', line 19 def code @code end |