Class: OryClient::V0alpha0Api
- Inherits:
-
Object
- Object
- OryClient::V0alpha0Api
- Defined in:
- lib/ory-client/api/v0alpha0_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_project(opts = {}) ⇒ Project
Create a Project Creates a new project.
-
#create_project_with_http_info(opts = {}) ⇒ Array<(Project, Integer, Hash)>
Create a Project Creates a new project.
-
#get_project(project_id, opts = {}) ⇒ Project
Get a Project Get a projects you have access to by its ID.
-
#get_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Get a Project Get a projects you have access to by its ID.
-
#initialize(api_client = ApiClient.default) ⇒ V0alpha0Api
constructor
A new instance of V0alpha0Api.
-
#list_projects(opts = {}) ⇒ Array<Project>
List All Projects Lists all projects you have access to.
-
#list_projects_with_http_info(opts = {}) ⇒ Array<(Array<Project>, Integer, Hash)>
List All Projects Lists all projects you have access to.
-
#update_project(project_id, opts = {}) ⇒ Project
Update a Project Creates a new configuration revision for a project.
-
#update_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Update a Project Creates a new configuration revision for a project.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ V0alpha0Api
Returns a new instance of V0alpha0Api.
19 20 21 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_project(opts = {}) ⇒ Project
Create a Project Creates a new project.
27 28 29 30 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 27 def create_project(opts = {}) data, _status_code, _headers = create_project_with_http_info(opts) data end |
#create_project_with_http_info(opts = {}) ⇒ Array<(Project, Integer, Hash)>
Create a Project Creates a new project.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 37 def create_project_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.create_project ...' end # resource path local_var_path = '/backoffice/public/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'project_patch']) # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.create_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#create_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_project(project_id, opts = {}) ⇒ Project
Get a Project Get a projects you have access to by its ID.
88 89 90 91 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 88 def get_project(project_id, opts = {}) data, _status_code, _headers = get_project_with_http_info(project_id, opts) data end |
#get_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Get a Project Get a projects you have access to by its ID.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 98 def get_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.get_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.get_project" end # resource path local_var_path = '/backoffice/public/projects/{project_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.get_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#get_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_projects(opts = {}) ⇒ Array<Project>
List All Projects Lists all projects you have access to.
150 151 152 153 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 150 def list_projects(opts = {}) data, _status_code, _headers = list_projects_with_http_info(opts) data end |
#list_projects_with_http_info(opts = {}) ⇒ Array<(Array<Project>, Integer, Hash)>
List All Projects Lists all projects you have access to.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 159 def list_projects_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.list_projects ...' end # resource path local_var_path = '/backoffice/public/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Project>' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.list_projects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#list_projects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_project(project_id, opts = {}) ⇒ Project
Update a Project Creates a new configuration revision for a project.
209 210 211 212 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 209 def update_project(project_id, opts = {}) data, _status_code, _headers = update_project_with_http_info(project_id, opts) data end |
#update_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Update a Project Creates a new configuration revision for a project.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 220 def update_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.update_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.update_project" end # resource path local_var_path = '/backoffice/public/projects/{project_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'project_patch']) # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.update_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#update_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |