Class: OryClient::V0alpha0Api
- Inherits:
-
Object
- Object
- OryClient::V0alpha0Api
- Defined in:
- lib/ory-client/api/v0alpha0_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_project(opts = {}) ⇒ Project
Create a Project Creates a new project.
-
#create_project_with_http_info(opts = {}) ⇒ Array<(Project, Integer, Hash)>
Create a Project Creates a new project.
-
#get_active_project(opts = {}) ⇒ ActiveProject
Returns Your Active Ory Cloud Project Use this API to get your active project in the Ory Cloud Console UI.
-
#get_active_project_with_http_info(opts = {}) ⇒ Array<(ActiveProject, Integer, Hash)>
Returns Your Active Ory Cloud Project Use this API to get your active project in the Ory Cloud Console UI.
-
#get_project(project_id, opts = {}) ⇒ Project
Get a Project Get a projects you have access to by its ID.
-
#get_project_members(project_id, opts = {}) ⇒ Array<CloudAccount>
Get all members associated with this project.
-
#get_project_members_with_http_info(project_id, opts = {}) ⇒ Array<(Array<CloudAccount>, Integer, Hash)>
Get all members associated with this project.
-
#get_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Get a Project Get a projects you have access to by its ID.
-
#initialize(api_client = ApiClient.default) ⇒ V0alpha0Api
constructor
A new instance of V0alpha0Api.
-
#list_projects(opts = {}) ⇒ Array<Project>
List All Projects Lists all projects you have access to.
-
#list_projects_with_http_info(opts = {}) ⇒ Array<(Array<Project>, Integer, Hash)>
List All Projects Lists all projects you have access to.
-
#purge_project(project_id, opts = {}) ⇒ nil
Irrecoverably Purge a Project !! Use with extreme caution !! Using this API endpoint you can purge (completely delete) a project and its data.
-
#purge_project_with_http_info(project_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Irrecoverably Purge a Project !! Use with extreme caution !! Using this API endpoint you can purge (completely delete) a project and its data.
-
#remove_project_member(project_id, member_id, opts = {}) ⇒ nil
Remove a member associated with this project.
-
#remove_project_member_with_http_info(project_id, member_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove a member associated with this project.
-
#set_active_project(opts = {}) ⇒ nil
Sets Your Active Project Use this API to set your active project in the Ory Cloud Console UI.
-
#set_active_project_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Sets Your Active Project Use this API to set your active project in the Ory Cloud Console UI.
-
#update_project(project_id, opts = {}) ⇒ Project
Update a Project Creates a new configuration revision for a project.
-
#update_project_config(project_id, opts = {}) ⇒ SuccessfulProjectConfigUpdate
Update an Ory Cloud Project Configuration This endpoints allows you to update the Ory Cloud Project configuration for individual services (identity, permission, …).
-
#update_project_config_with_http_info(project_id, opts = {}) ⇒ Array<(SuccessfulProjectConfigUpdate, Integer, Hash)>
Update an Ory Cloud Project Configuration This endpoints allows you to update the Ory Cloud Project configuration for individual services (identity, permission, …).
-
#update_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Update a Project Creates a new configuration revision for a project.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ V0alpha0Api
Returns a new instance of V0alpha0Api.
19 20 21 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_project(opts = {}) ⇒ Project
Create a Project Creates a new project.
27 28 29 30 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 27 def create_project(opts = {}) data, _status_code, _headers = create_project_with_http_info(opts) data end |
#create_project_with_http_info(opts = {}) ⇒ Array<(Project, Integer, Hash)>
Create a Project Creates a new project.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 37 def create_project_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.create_project ...' end # resource path local_var_path = '/backoffice/public/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'project_revision']) # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.create_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#create_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_active_project(opts = {}) ⇒ ActiveProject
Returns Your Active Ory Cloud Project Use this API to get your active project in the Ory Cloud Console UI.
90 91 92 93 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 90 def get_active_project(opts = {}) data, _status_code, _headers = get_active_project_with_http_info(opts) data end |
#get_active_project_with_http_info(opts = {}) ⇒ Array<(ActiveProject, Integer, Hash)>
Returns Your Active Ory Cloud Project Use this API to get your active project in the Ory Cloud Console UI.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 99 def get_active_project_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.get_active_project ...' end # resource path local_var_path = '/backoffice/public/console/projects/active' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ActiveProject' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.get_active_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#get_active_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_project(project_id, opts = {}) ⇒ Project
Get a Project Get a projects you have access to by its ID.
148 149 150 151 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 148 def get_project(project_id, opts = {}) data, _status_code, _headers = get_project_with_http_info(project_id, opts) data end |
#get_project_members(project_id, opts = {}) ⇒ Array<CloudAccount>
Get all members associated with this project. This endpoint requires the user to be a member of the project with the role `OWNER` or `DEVELOPER`.
211 212 213 214 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 211 def get_project_members(project_id, opts = {}) data, _status_code, _headers = get_project_members_with_http_info(project_id, opts) data end |
#get_project_members_with_http_info(project_id, opts = {}) ⇒ Array<(Array<CloudAccount>, Integer, Hash)>
Get all members associated with this project. This endpoint requires the user to be a member of the project with the role `OWNER` or `DEVELOPER`.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 221 def get_project_members_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.get_project_members ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.get_project_members" end # resource path local_var_path = '/backoffice/public/projects/{project_id}/members'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CloudAccount>' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.get_project_members", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#get_project_members\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Get a Project Get a projects you have access to by its ID.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 158 def get_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.get_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.get_project" end # resource path local_var_path = '/backoffice/public/projects/{project_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.get_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#get_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_projects(opts = {}) ⇒ Array<Project>
List All Projects Lists all projects you have access to.
273 274 275 276 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 273 def list_projects(opts = {}) data, _status_code, _headers = list_projects_with_http_info(opts) data end |
#list_projects_with_http_info(opts = {}) ⇒ Array<(Array<Project>, Integer, Hash)>
List All Projects Lists all projects you have access to.
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 282 def list_projects_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.list_projects ...' end # resource path local_var_path = '/backoffice/public/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Project>' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.list_projects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#list_projects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#purge_project(project_id, opts = {}) ⇒ nil
Irrecoverably Purge a Project !! Use with extreme caution !! Using this API endpoint you can purge (completely delete) a project and its data. This action can not be undone and will delete ALL your data. !! Use with extreme caution !!
331 332 333 334 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 331 def purge_project(project_id, opts = {}) purge_project_with_http_info(project_id, opts) nil end |
#purge_project_with_http_info(project_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Irrecoverably Purge a Project !! Use with extreme caution !! Using this API endpoint you can purge (completely delete) a project and its data. This action can not be undone and will delete ALL your data. !! Use with extreme caution !!
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 341 def purge_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.purge_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.purge_project" end # resource path local_var_path = '/backoffice/public/projects/{project_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.purge_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#purge_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_project_member(project_id, member_id, opts = {}) ⇒ nil
Remove a member associated with this project. This also sets their invite status to `REMOVED`. This endpoint requires the user to be a member of the project with the role `OWNER`.
395 396 397 398 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 395 def remove_project_member(project_id, member_id, opts = {}) remove_project_member_with_http_info(project_id, member_id, opts) nil end |
#remove_project_member_with_http_info(project_id, member_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove a member associated with this project. This also sets their invite status to `REMOVED`. This endpoint requires the user to be a member of the project with the role `OWNER`.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 406 def remove_project_member_with_http_info(project_id, member_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.remove_project_member ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.remove_project_member" end # verify the required parameter 'member_id' is set if @api_client.config.client_side_validation && member_id.nil? fail ArgumentError, "Missing the required parameter 'member_id' when calling V0alpha0Api.remove_project_member" end # resource path local_var_path = '/backoffice/public/projects/{project_id}/members/{member_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'member_id' + '}', CGI.escape(member_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.remove_project_member", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#remove_project_member\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_active_project(opts = {}) ⇒ nil
Sets Your Active Project Use this API to set your active project in the Ory Cloud Console UI.
463 464 465 466 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 463 def set_active_project(opts = {}) set_active_project_with_http_info(opts) nil end |
#set_active_project_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Sets Your Active Project Use this API to set your active project in the Ory Cloud Console UI.
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 473 def set_active_project_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.set_active_project ...' end # resource path local_var_path = '/backoffice/public/console/projects/active' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'inline_object']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.set_active_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#set_active_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_project(project_id, opts = {}) ⇒ Project
Update a Project Creates a new configuration revision for a project.
528 529 530 531 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 528 def update_project(project_id, opts = {}) data, _status_code, _headers = update_project_with_http_info(project_id, opts) data end |
#update_project_config(project_id, opts = {}) ⇒ SuccessfulProjectConfigUpdate
Update an Ory Cloud Project Configuration This endpoints allows you to update the Ory Cloud Project configuration for individual services (identity, permission, …). The configuration is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions). This endpoint expects the `version` key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version. If you have an older version of a configuration, you should set the version key in the payload! While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source. For configuration items that can not be translated to Ory Cloud, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed. Be aware that updating any service's configuration will completely override your current configuration for that service!
598 599 600 601 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 598 def update_project_config(project_id, opts = {}) data, _status_code, _headers = update_project_config_with_http_info(project_id, opts) data end |
#update_project_config_with_http_info(project_id, opts = {}) ⇒ Array<(SuccessfulProjectConfigUpdate, Integer, Hash)>
Update an Ory Cloud Project Configuration This endpoints allows you to update the Ory Cloud Project configuration for individual services (identity, permission, …). The configuration is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions). This endpoint expects the `version` key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version. If you have an older version of a configuration, you should set the version key in the payload! While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source. For configuration items that can not be translated to Ory Cloud, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed. Be aware that updating any service's configuration will completely override your current configuration for that service!
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 609 def update_project_config_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.update_project_config ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.update_project_config" end # resource path local_var_path = '/backoffice/public/projects/{project_id}/configs'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'update_project_config_config']) # return_type return_type = opts[:debug_return_type] || 'SuccessfulProjectConfigUpdate' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.update_project_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#update_project_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_project_with_http_info(project_id, opts = {}) ⇒ Array<(Project, Integer, Hash)>
Update a Project Creates a new configuration revision for a project.
539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/ory-client/api/v0alpha0_api.rb', line 539 def update_project_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: V0alpha0Api.update_project ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling V0alpha0Api.update_project" end # resource path local_var_path = '/backoffice/public/projects/{project_id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'project_revision']) # return_type return_type = opts[:debug_return_type] || 'Project' # auth_names auth_names = opts[:debug_auth_names] || ['oryAccessToken'] = opts.merge( :operation => :"V0alpha0Api.update_project", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: V0alpha0Api#update_project\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |