Class: OryClient::WorkspaceOrganization
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OryClient::WorkspaceOrganization
- Defined in:
- lib/ory-client/models/workspace_organization.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_link ⇒ Object
Returns the value of attribute active_link.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default_region ⇒ Object
DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly.
-
#domains ⇒ Object
The list of organization’s domains.
-
#id ⇒ Object
The organization’s ID.
-
#label ⇒ Object
The organization’s human-readable label.
-
#providers ⇒ Object
Returns the value of attribute providers.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkspaceOrganization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkspaceOrganization
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/ory-client/models/workspace_organization.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OryClient::WorkspaceOrganization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OryClient::WorkspaceOrganization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active_link') self.active_link = attributes[:'active_link'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'default_region') self.default_region = attributes[:'default_region'] end if attributes.key?(:'domains') if (value = attributes[:'domains']).is_a?(Array) self.domains = value end else self.domains = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'providers') if (value = attributes[:'providers']).is_a?(Array) self.providers = value end else self.providers = nil end end |
Instance Attribute Details
#active_link ⇒ Object
Returns the value of attribute active_link.
18 19 20 |
# File 'lib/ory-client/models/workspace_organization.rb', line 18 def active_link @active_link end |
#created_at ⇒ Object
Returns the value of attribute created_at.
20 21 22 |
# File 'lib/ory-client/models/workspace_organization.rb', line 20 def created_at @created_at end |
#default_region ⇒ Object
DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global
23 24 25 |
# File 'lib/ory-client/models/workspace_organization.rb', line 23 def default_region @default_region end |
#domains ⇒ Object
The list of organization’s domains.
26 27 28 |
# File 'lib/ory-client/models/workspace_organization.rb', line 26 def domains @domains end |
#id ⇒ Object
The organization’s ID.
29 30 31 |
# File 'lib/ory-client/models/workspace_organization.rb', line 29 def id @id end |
#label ⇒ Object
The organization’s human-readable label.
32 33 34 |
# File 'lib/ory-client/models/workspace_organization.rb', line 32 def label @label end |
#providers ⇒ Object
Returns the value of attribute providers.
34 35 36 |
# File 'lib/ory-client/models/workspace_organization.rb', line 34 def providers @providers end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/ory-client/models/workspace_organization.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/ory-client/models/workspace_organization.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ory-client/models/workspace_organization.rb', line 59 def self.attribute_map { :'active_link' => :'active_link', :'created_at' => :'created_at', :'default_region' => :'default_region', :'domains' => :'domains', :'id' => :'id', :'label' => :'label', :'providers' => :'providers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/ory-client/models/workspace_organization.rb', line 290 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/ory-client/models/workspace_organization.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ory-client/models/workspace_organization.rb', line 82 def self.openapi_types { :'active_link' => :'OnboardingPortalLink', :'created_at' => :'Time', :'default_region' => :'String', :'domains' => :'Array<String>', :'id' => :'String', :'label' => :'String', :'providers' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/ory-client/models/workspace_organization.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && active_link == o.active_link && created_at == o.created_at && default_region == o.default_region && domains == o.domains && id == o.id && label == o.label && providers == o.providers end |
#eql?(o) ⇒ Boolean
277 278 279 |
# File 'lib/ory-client/models/workspace_organization.rb', line 277 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/ory-client/models/workspace_organization.rb', line 283 def hash [active_link, created_at, default_region, domains, id, label, providers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ory-client/models/workspace_organization.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @domains.nil? invalid_properties.push('invalid value for "domains", domains cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end if @providers.nil? invalid_properties.push('invalid value for "providers", providers cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/ory-client/models/workspace_organization.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/ory-client/models/workspace_organization.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? default_region_validator = EnumAttributeValidator.new('String', ["eu-central", "asia-northeast", "us-east", "us-west", "eu", "asia", "us", "global"]) return false unless default_region_validator.valid?(@default_region) return false if @domains.nil? return false if @id.nil? return false if @label.nil? return false if @providers.nil? true end |